@@ -2,17 +2,17 @@
 # MediaWiki web-based config/installation
 # Copyright (C) 2004 Brion Vibber <brion@pobox.com>
 # http://www.mediawiki.org/
-# 
+#
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or 
+# the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License along
 # with this program; if not, write to the Free Software Foundation, Inc.,
 # 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -40,7 +40,7 @@ header( "Content-type: text/html; charset=utf-8" );
 		padding: 8px;
 		margin-left: 8px;
 	}
-	
+
 	dl.setup dd {
 		margin-left: 0;
 	}
@@ -75,30 +75,30 @@ header( "Content-type: text/html; charset=utf-8" );
 <div id="credit">
  <center>
   <a href="http://www.mediawiki.org/"><img
-    src="../stylesheets/images/wiki.png" width="135" height="135" alt="" border="0" /></a>
+    src="../skins/common/images/wiki.png" width="135" height="135" alt="" border="0" /></a>
  </center>
- 
+
  <b><a href="http://www.mediawiki.org/">MediaWiki</a></b> is
  Copyright (C) 2001-2004 by Magnus Manske, Brion Vibber, Lee Daniel Crocker,
  Tim Starling, Erik M&ouml;ller, Gabriel Wicke and others.</p>
- 
+
  <ul>
  <li><a href="../README">Readme</a></li>
  <li><a href="../RELEASE-NOTES">Release notes</a></li>
  <li><a href="../docs/">doc/</a></li>
  <li><a href="http://meta.wikipedia.org/wiki/MediaWiki_User's_Guide">User's Guide</a></li>
  </ul>
- 
+
  <p>This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.</p>
- 
+
  <p>This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.</p>
- 
+
  <p>You should have received <a href="../COPYING">a copy of the GNU General Public License</a>
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
@@ -107,12 +107,21 @@ header( "Content-type: text/html; charset=utf-8" );
 
 <?php
 
-$IP = ".."; # Just to suppress notices, not for anything useful
+# Relative includes seem to break if a parent directory is not readable;
+# this is common for public_html subdirs under user home directories.
+#
+# As a dirty hack, we'll try to set up the include path first.
+#
+$IP = dirname( dirname( __FILE__ ) );
+$sep = (DIRECTORY_SEPARATOR == "\\") ? ";" : ":";
+ini_set( "include_path", ".$sep$IP$sep$IP/includes$sep$IP/languages" );
+
 define( "MEDIAWIKI", true );
 define( "MEDIAWIKI_INSTALL", true );
-require_once( "../includes/DefaultSettings.php" );
-require_once( "../includes/MagicWord.php" );
-require_once( "../includes/Namespace.php" );
+require_once( "includes/Defines.php" );
+require_once( "includes/DefaultSettings.php" );
+require_once( "includes/MagicWord.php" );
+require_once( "includes/Namespace.php" );
 ?>
 
 <h1>MediaWiki <?php print $wgVersion ?> installation</h1>
@@ -124,15 +133,15 @@ require_once( "../includes/Namespace.php" );
 
 if( file_exists( "../LocalSettings.php" ) || file_exists( "../AdminSettings.php" ) ) {
 	dieout( "<h2>Wiki is configured.</h2>
-	
+
 	<p>Already configured... <a href='../index.php'>return to the wiki</a>.</p>
-	
+
 	<p>(You should probably remove this directory for added security.)</p>" );
 }
 
 if( file_exists( "./LocalSettings.php" ) || file_exists( "./AdminSettings.php" ) ) {
 	dieout( "<h2>You're configured!</h2>
-	
+
 	<p>Please move <tt>LocalSettings.php</tt> to the parent directory, then
 	<a href='../index.php'>try out your wiki</a>.
 	(You should remove this config directory for added security once you're done.)</p>" );
@@ -140,14 +149,14 @@ if( file_exists( "./LocalSettings.php" ) || file_exists( "./AdminSettings.php" )
 
 if( !is_writable( "." ) ) {
 	dieout( "<h2>Can't write config file, aborting</h2>
-	
+
 	<p>In order to configure the wiki you have to make the <tt>config</tt> subdirectory
 	writable by the web server. Once configuration is done you'll move the created
 	<tt>LocalSettings.php</tt> to the parent directory, and for added safety you can
 	then remove the <tt>config</tt> subdirectory entirely.</p>
-	
+
 	<p>To make the directory writable on a Unix/Linux system:</p>
-	
+
 	<pre>
 	cd <i>/path/to/wiki</i>
 	chmod a+w config
@@ -155,10 +164,10 @@ if( !is_writable( "." ) ) {
 }
 
 
-require_once( "../install-utils.inc" );
-require_once( "../maintenance/updaters.inc" );
-require_once( "../maintenance/convertLinks.inc" );
-require_once( "../maintenance/archives/moveCustomMessages.inc" );
+require_once( "install-utils.inc" );
+require_once( "maintenance/updaters.inc" );
+require_once( "maintenance/convertLinks.inc" );
+require_once( "maintenance/archives/moveCustomMessages.inc" );
 
 class ConfigData {
 	function getEncoded( $data ) {
@@ -184,19 +193,12 @@ class ConfigData {
 <?php
 $endl = "
 ";
+$wgConfiguring = true;
 $conf = new ConfigData;
 
 install_version_checks();
 
-print "<li>PHP " . phpversion() . ": ";
-if( version_compare( phpversion(), "5.0", "lt" ) ) {
- 	print "ok";
-} else {
-	print " <b>the MonoBook skin will be disabled due to an incompatibility
-		between the PHPTAL template library and PHP 5</b>. The wiki should
-		function normally, but with the older look and feel.";
-}
-print "</li>\n";
+print "<li>PHP " . phpversion() . ": ok</li>\n";
 
 if( ini_get( "register_globals" ) ) {
 	?>
@@ -212,13 +214,33 @@ if( ini_get( "safe_mode" ) ) {
 	?>
 	<li class='error'><b>Warning: PHP's
 	<a href='http://www.php.net/features.safe-mode'>safe mode</a> is active!</b>
-	You will likely have problems caused by this. You may need to make the
-	'images' subdirectory writable or specify a TMP environment variable pointing to
-	a writable temporary directory owned by you, since safe mode breaks the system
-	temporary directory.</li>
+	You may have problems caused by this, particularly if using image uploads.
+	</li>
 	<?php
 }
 
+$fatal = false;
+
+if( ini_get( "magic_quotes_runtime" ) ) {
+	$fatal = true;
+	?><li class='error'><b>Fatal: <a href='http://www.php.net/manual/en/ref.info.php#ini.magic-quotes-runtime'>magic_quotes_runtime</a> is active!</b>
+	This option corrupts data input unpredictably; you cannot install or use
+	MediaWiki unless this option is disabled.
+	<?php
+}
+
+if( ini_get( "magic_quotes_sybase" ) ) {
+	$fatal = true;
+	?><li class='error'><b>Fatal: <a href='http://www.php.net/manual/en/ref.sybase.php#ini.magic-quotes-sybase'>magic_quotes_sybase</a> is active!</b>
+	This option corrupts data input unpredictably; you cannot install or use
+	MediaWiki unless this option is disabled.
+	<?php
+}
+
+if( $fatal ) {
+	dieout( "</ul><p>Cannot install wiki.</p>" );
+}
+
 $sapi = php_sapi_name();
 $conf->prettyURLs = true;
 print "<li>PHP server API is $sapi; ";
@@ -276,21 +298,33 @@ if( $conf->zlib ) {
 	print "<li>No zlib support.</li>\n";
 }
 
+$conf->turck = function_exists( 'mmcache_get' );
+if ( $conf->turck ) {
+	print "<li><a href=\"http://turck-mmcache.sourceforge.net/\">Turck MMCache</a> installed</li>\n";
+} else {
+	print "<li><a href=\"http://turck-mmcache.sourceforge.net/\">Turck MMCache</a> not installed, " .
+	  "can't use object caching functions</li>\n";
+}
+
 $conf->ImageMagick = false;
+$imcheck = array( "/usr/bin", "/usr/local/bin", "/sw/bin", "/opt/local/bin" );
+foreach( $imcheck as $dir ) {
+	$im = "$dir/convert";
+	if( file_exists( $im ) ) {
+		print "<li>Found ImageMagick: <tt>$im</tt>; image thumbnailing will be enabled if you enable uploads.</li>\n";
+		$conf->ImageMagick = $im;
+		break;
+	}
+}
 
 $conf->HaveGD = function_exists( "imagejpeg" );
 if( $conf->HaveGD ) {
-	print "<li>Found GD graphics library built-in, image thumbnailing will be enabled if you enable uploads.</li>\n";
-} else {
-	$imcheck = array( "/usr/bin", "/usr/local/bin", "/sw/bin" );
-	foreach( $imcheck as $dir ) {
-		$im = "$dir/convert";
-		if( file_exists( $im ) ) {
-			print "<li>Found ImageMagick: <tt>$im</tt>; image thumbnailing will be enabled if you enable uploads.</li>\n";
-			$conf->ImageMagick = $im;
-			break;
-		}
+	print "<li>Found GD graphics library built-in";
+	if( !$conf->ImageMagick ) {
+		print ", image thumbnailing will be enabled if you enable uploads";
 	}
+	print ".</li>\n";
+} else {
 	if( !$conf->ImageMagick ) {
 		print "<li>Couldn't find GD library or ImageMagick; image thumbnailing disabled.</li>\n";
 	}
@@ -303,18 +337,22 @@ $conf->IP = dirname( dirname( __FILE__ ) );
 print "<li>Installation directory: <tt>" . htmlspecialchars( $conf->IP ) . "</tt></li>\n";
 
 # $conf->ScriptPath = "/~brion/inplace";
-$conf->ScriptPath = preg_replace( '{^(.*)/config.*$}', '$1', $_SERVER["REQUEST_URI"] );
+$conf->ScriptPath = preg_replace( '{^(.*)/config.*$}', '$1', $_SERVER["SCRIPT_NAME"] );
 print "<li>Script URI path: <tt>" . htmlspecialchars( $conf->ScriptPath ) . "</tt></li>\n";
 
 	$conf->posted = ($_SERVER["REQUEST_METHOD"] == "POST");
-	
+
 	$conf->Sitename = ucfirst( importPost( "Sitename", "" ) );
-	$conf->EmergencyContact = importPost( "EmergencyContact", $_SERVER["SERVER_ADMIN"] );
+	$defaultEmail = empty( $_SERVER["SERVER_ADMIN"] )
+		? 'root@localhost'
+		: $_SERVER["SERVER_ADMIN"];
+	$conf->EmergencyContact = importPost( "EmergencyContact", $defaultEmail );
 	$conf->DBserver = importPost( "DBserver", "localhost" );
 	$conf->DBname = importPost( "DBname", "wikidb" );
 	$conf->DBuser = importPost( "DBuser", "wikiuser" );
 	$conf->DBpassword = importPost( "DBpassword" );
 	$conf->DBpassword2 = importPost( "DBpassword2" );
+	$conf->DBprefix = importPost( "DBprefix" );
 	$conf->RootPW = importPost( "RootPW" );
 	$conf->LanguageCode = importPost( "LanguageCode", "en" );
 	$conf->SysopName = importPost( "SysopName", "WikiSysop" );
@@ -336,6 +374,9 @@ if( $conf->DBpassword == "" ) {
 if( $conf->DBpassword != $conf->DBpassword2 ) {
 	$errs["DBpassword2"] = "Passwords don't match!";
 }
+if( !preg_match( '/^[A-Za-z_0-9]*$/', $conf->DBprefix ) ) {
+	$errs["DBprefix"] = "Invalid table prefix";
+}
 
 if( $conf->SysopPass == "" ) {
 	$errs["SysopPass"] = "Must not be blank";
@@ -349,7 +390,7 @@ if( $conf->License == "gfdl" ) {
 	$conf->RightsUrl = "http://www.gnu.org/copyleft/fdl.html";
 	$conf->RightsText = "GNU Free Documentation License 1.2";
 	$conf->RightsCode = "gfdl";
-	$conf->RightsIcon = '${wgStylePath}/images/gnu-fdl.png';
+	$conf->RightsIcon = '${wgStylePath}/common/images/gnu-fdl.png';
 } elseif( $conf->License == "none" ) {
 	$conf->RightsUrl = $conf->RightsText = $conf->RightsCode = $conf->RightsIcon = "";
 } else {
@@ -359,10 +400,28 @@ if( $conf->License == "gfdl" ) {
 	$conf->RightsIcon = importRequest( "RightsIcon", "" );
 }
 
+$conf->Shm = importRequest( "Shm", "none" );
+$conf->MCServers = importRequest( "MCServers" );
+
+/* Test memcached servers */
+
+if ( $conf->Shm == 'memcached' && $conf->MCServers ) {
+	$conf->MCServerArray = array_map( 'trim', explode( ',', $conf->MCServers ) );
+	foreach ( $conf->MCServerArray as $server ) {
+		$error = testMemcachedServer( $server );
+		if ( $error ) {
+			$errs["MCServers"] = $error;
+			break;
+		}
+	}
+} else if ( $conf->Shm == 'memcached' ) {
+	$errs["MCServers"] = "Please specify at least one server if you wish to use memcached";
+}
+
 if( $conf->posted && ( 0 == count( $errs ) ) ) {
 	do { /* So we can 'continue' to end prematurely */
 		$conf->Root = ($conf->RootPW != "");
-		
+
 		/* Load up the settings and get installin' */
 		$local = writeLocalSettings( $conf );
 		$wgCommandLineMode = false;
@@ -370,17 +429,18 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 		eval($local);
 		$wgDBadminuser = "root";
 		$wgDBadminpassword = $conf->RootPW;
+		$wgDBprefix = $conf->DBprefix;
 		$wgCommandLineMode = true;
 		$wgUseDatabaseMessages = false;	/* FIXME: For database failure */
 		require_once( "includes/Setup.php" );
 		chdir( "config" );
 
-		require_once( "../maintenance/InitialiseMessages.inc" );
+		require_once( "maintenance/InitialiseMessages.inc" );
 
 		$wgTitle = Title::newFromText( "Installation script" );
 		$wgDatabase = Database::newFromParams( $wgDBserver, "root", $conf->RootPW, "", 1 );
-		$wgDatabase->mIgnoreErrors = true;
-		
+		$wgDatabase->ignoreErrors(true);
+
 		@$myver = mysql_get_server_info( $wgDatabase->mConn );
 		if( $myver ) {
 			$conf->Root = true;
@@ -401,7 +461,7 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 					$wgDBadminpassword = $wgDBpassword;
 					$wgDatabase = Database::newFromParams( $wgDBserver, $wgDBuser, $wgDBpassword, "", 1 );
 					$wgDatabase->isOpen();
-					$wgDatabase->mIgnoreErrors = true;
+					$wgDatabase->ignoreErrors(true);
 					@$myver = mysql_get_server_info( $wgDatabase->mConn );
 					if( !$myver ) {
 						$errs["DBuser"] = "Check name/pass";
@@ -428,7 +488,7 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 			}
 			if( !$ok ) continue;
 		}
-		
+
 		if ( !$wgDatabase->isOpen() ) {
 			$errs["DBserver"] = "Couldn't connect to database";
 			continue;
@@ -441,7 +501,7 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 			$local = writeLocalSettings( $conf );
 		}
 		print "</li>\n";
-		
+
 		@$sel = mysql_select_db( $wgDBname, $wgDatabase->mConn );
 		if( $sel ) {
 			print "<li>Database <tt>" . htmlspecialchars( $wgDBname ) . "</tt> exists</li>\n";
@@ -456,38 +516,29 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 			}
 			print "<li>Created database <tt>" . htmlspecialchars( $wgDBname ) . "</tt></li>\n";
 		}
-		
+
 		$wgDatabase->selectDB( $wgDBname );
-		
+
 		if( $wgDatabase->tableExists( "cur" ) ) {
-			print "<li>There are already MediaWiki tables in this database. Checking if updates are needed...</li>\n<pre>";
+			print "<li>There are already MediaWiki tables in this database. Checking if updates are needed...</li>\n";
 			
+			# Create user if required
+			if ( $conf->Root ) {
+				$conn = Database::newFromParams( $wgDBserver, $wgDBuser, $wgDBpassword, $wgDBname, 1 );
+				if ( $conn->isOpen() ) {
+					print "<li>DB user account ok</li>\n";
+					$conn->close();
+				} else {
+					print "<li>Granting user permissions...</li>\n";
+					dbsource( "../maintenance/users.sql", $wgDatabase );
+				}
+			}
+			print "<pre>\n";
 			chdir( ".." );
 			flush();
-			do_ipblocks_update(); flush();
-			do_interwiki_update(); flush();
-			do_index_update(); flush();
-			do_linkscc_update(); flush();
-			do_linkscc_1_3_update(); flush();
-			do_hitcounter_update(); flush();
-			do_recentchanges_update(); flush();
-			convertLinks(); flush();
-			do_user_real_name_update(); flush();
-			do_querycache_update(); flush();
-			do_objectcache_update(); flush();
-			do_categorylinks_update(); flush();
-			
-			if ( isTemplateInitialised() ) {
-				print "Template namespace already initialised\n";
-			} else {
-				moveCustomMessages( 1 ); flush();
-				moveCustomMessages( 2 ); flush();
-				moveCustomMessages( 3 ); flush();
-			}
-
-			initialiseMessages(); flush();
+			do_all_updates();
 			chdir( "config" );
-			
+
 			print "</pre>\n";
 			print "<li>Finished update checks.</li>\n";
 		} else {
@@ -495,18 +546,20 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 			print "<li>Creating tables...";
 			dbsource( "../maintenance/tables.sql", $wgDatabase );
 			dbsource( "../maintenance/interwiki.sql", $wgDatabase );
-			dbsource( "../maintenance/indexes.sql", $wgDatabase );
 			print " done.</li>\n";
-			
+
 			print "<li>Initializing data...";
-			$wgDatabase->query( "INSERT INTO site_stats (ss_row_id,ss_total_views," .
-				"ss_total_edits,ss_good_articles) VALUES (1,0,0,0)" );
-			# setting up the db user	
+			$wgDatabase->insert( 'site_stats',
+				array( 'ss_row_id'        => 1,
+				       'ss_total_views'   => 0,
+				       'ss_total_edits'   => 0,
+				       'ss_good_articles' => 0 ) );
+			# setting up the db user
 			if( $conf->Root ) {
 				print "<li>Granting user permissions...</li>\n";
 				dbsource( "../maintenance/users.sql", $wgDatabase );
 			}
-			
+
 			if( $conf->SysopName ) {
 				$u = User::newFromName( $conf->getSysopName() );
 				if ( 0 == $u->idForName() ) {
@@ -523,34 +576,21 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 			} else {
 				print "<li>Skipped sysop account creation, no name given.</li>\n";
 			}
-			
-			print "<li>Initialising log pages...";
-			$logs = array(
-				"uploadlogpage" => "uploadlogpagetext",
-				"dellogpage" => "dellogpagetext",
-				"protectlogpage" => "protectlogtext",
-				"blocklogpage" => "blocklogtext"
-			);
-			$metaNamespace = Namespace::getWikipedia();
+
+			$titleobj = Title::newFromText( wfMsgNoDB( "mainpage" ) );
 			$now = wfTimestampNow();
 			$won = wfInvertTimestamp( $now );
-			foreach( $logs as $page => $text ) {
-				$logTitle = wfStrencode( $wgLang->ucfirst( str_replace( " ", "_", wfMsgNoDB( $page ) ) ) );
-				$logText = wfStrencode( wfMsgNoDB( $text ) );
-				$wgDatabase->query( "INSERT INTO cur (cur_namespace,cur_title,cur_text," .
-				  "cur_restrictions,cur_timestamp,inverse_timestamp,cur_touched) " .
-				  "VALUES ($metaNamespace,'$logTitle','$logText','sysop','$now','$won','$now')" );
-			}
-			print "</li>\n";
-			
-			$titleobj = Title::newFromText( wfMsgNoDB( "mainpage" ) );
-			$title = $titleobj->getDBkey();
-			$sql = "INSERT INTO cur (cur_namespace,cur_title,cur_text,cur_timestamp,inverse_timestamp,cur_touched,cur_user,cur_user_text) " .
-			  "VALUES (0,'$title','" .
-			  wfStrencode( wfMsg( "mainpagetext" ) . "\n\n" . wfMsg( "mainpagedocfooter" ) ) .
-			  "','$now','$won','$now',0,'MediaWiki default')";
-			$wgDatabase->query( $sql, $fname );
-			
+			$wgDatabase->insert( 'cur',
+				array( 'cur_namespace'     => $titleobj->getNamespace(),
+				       'cur_title'         => $titleobj->getDBkey(),
+				       'cur_text'          => wfMsg( 'mainpagetext' ) . "\n\n" .
+				                              wfMsg( 'mainpagedocfooter' ),
+				       'cur_timestamp'     => $now,
+				       'inverse_timestamp' => $won,
+				       'cur_touched'       => $now,
+				       'cur_user'          => 0,
+				       'cur_user_text'     => 'MediaWiki default' ) );
+
 			print "<li><pre>";
 			initialiseMessages();
 			print "</pre></li>\n";
@@ -559,25 +599,30 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 		/* Write out the config file now that all is well */
 		print "<p>Creating LocalSettings.php...</p>\n\n";
 		$localSettings =  "<" . "?php$endl$local$endl?" . ">";
-		
+
 		if( version_compare( phpversion(), "4.3.2" ) >= 0 ) {
 			$xt = "xt"; # Refuse to overwrite an existing file
 		} else {
 			$xt = "wt"; # 'x' is not available prior to PHP 4.3.2. We did check above, but race conditions blah blah
 		}
 		$f = fopen( "LocalSettings.php", $xt );
-		
+
 		if( $f == false ) {
 			dieout( "<p>Couldn't write out LocalSettings.php. Check that the directory permissions are correct and that there isn't already a file of that name here...</p>\n" .
 			"<p>Here's the file that would have been written, try to paste it into place manually:</p>\n" .
 			"<pre>\n" . htmlspecialchars( $localSettings ) . "</pre>\n" );
 		}
-		fwrite( $f, $localSettings );
-		fclose( $f );
-		
-		print "<p>Success! Move the LocalSettings.php file into the parent directory, then follow
-		<a href='{$conf->ScriptPath}/index.php'>this link</a> to your wiki.</p>\n";
-		
+		if(fwrite( $f, $localSettings ) ) {
+			fclose( $f );
+
+			print "<p>Success! Move the config/LocalSettings.php file into the parent directory, then follow
+			<a href='{$conf->ScriptPath}/index.php'>this link</a> to your wiki.</p>\n";
+		} else {
+			fclose( $f );
+			die("<p class='error'>An error occured while writing the config/LocalSettings.php file. Check user rights and disk space then try again.</p>\n");
+			 
+		}
+
 	} while( false );
 }
 ?>
@@ -588,7 +633,7 @@ if( $conf->posted && ( 0 == count( $errs ) ) ) {
 
 if( count( $errs ) ) {
 	/* Display options form */
-	
+
 	if( $conf->posted ) {
 		echo "<p class='error'>Something's not quite right yet; make sure everything below is filled out correctly.</p>\n";
 	}
@@ -630,7 +675,7 @@ if( count( $errs ) ) {
 		<?php
 			$list = getLanguageList();
 			foreach( $list as $code => $name ) {
-				$sel = ($code == $conf->LanguageCode) ? "selected" : "";
+				$sel = ($code == $conf->LanguageCode) ? 'selected="selected"' : '';
 				echo "\t\t<option value=\"$code\" $sel>$name</option>\n";
 			}
 		?>
@@ -643,7 +688,7 @@ if( count( $errs ) ) {
 		more compatible with older browsers for some languages. Unicode will
 		be used where not specified otherwise.
 	</dt>
-	
+
 	<dd>
 		<label class='column'>Copyright/license metadata</label>
 		<div>Select one:</div>
@@ -652,7 +697,7 @@ if( count( $errs ) ) {
 		<li><?php aField( $conf, "License", "no license metadata", "radio", "none" ); ?></li>
 		<li><?php aField( $conf, "License", "GNU Free Documentation License 1.2 (Wikipedia-compatible)", "radio", "gfdl" ); ?></li>
 		<li><?php
-			aField( $conf, "License", "a Creative Commons license...", "radio", "cc" ); 
+			aField( $conf, "License", "a Creative Commons license...", "radio", "cc" );
 			$partner = "MediaWiki";
 			$exit = urlencode( "$wgServer{$conf->ScriptPath}/config/index.php?License=cc&RightsUrl=[license_url]&RightsText=[license_name]&RightsCode=[license_code]&RightsIcon=[license_button]" );
 			$icon = urlencode( "$wgServer$wgUploadPath/wiki.png" );
@@ -676,8 +721,8 @@ if( count( $errs ) ) {
 		the GNU FDL or a Creative Commons license. If you're not sure, leave
 		it at "none".
 	</dt>
-	
-	
+
+
 	<dd>
 		<?php aField( $conf, "SysopName", "Sysop account name:", "" ) ?>
 	</dd>
@@ -693,7 +738,30 @@ if( count( $errs ) ) {
 		wiki database, a sysop account will be created with the given name
 		and password.
 	</dt>
-</dl>
+
+	<dd>
+		<label class='column'>Shared memory caching</label>
+		<div>Select one:</div>
+
+		<ul class="plain">
+		<li><?php aField( $conf, "Shm", "no caching", "radio", "none" ); ?></li>
+		<?php 
+			if ( $conf->turck ) {
+				echo "<li>";
+				aField( $conf, "Shm", "Turck MMCache", "radio", "turck" );
+				echo "</li>";
+			}
+		?>
+		<li><?php aField( $conf, "Shm", "Memcached", "radio", "memcached" ); ?></li>
+		<li><?php aField( $conf, "MCServers", "Memcached servers", "" ) ?></li>
+		</ul>
+	</dd>
+	<dt>
+		Using a shared memory system such as Turck MMCache or Memcached will speed
+		up MediaWiki significantly. Memcached is the best solution but needs to be 
+		installed. Specify the server addresses and ports in a comma-separted list. Only 
+		use Turck shared memory if the wiki will be running on a single Apache server.
+	</dl>
 
 <h2>Database config</h2>
 
@@ -724,6 +792,16 @@ if( count( $errs ) ) {
 		you can specify new accounts/databases to be created.
 	</dt>
 
+	<dd><?php
+		aField( $conf, "DBprefix", "Database table prefix" );
+	?></dd>
+	<dt>
+		<p>If you need to share one database between multiple wikis, or
+		MediaWiki and another web application, you may choose to
+		add a prefix to all the table names to avoid conflicts.</p>
+		
+		<p>Avoid exotic characters; something like <tt>mw_</tt> is good.</p>
+	</dt>
 
 	<dd>
 		<?php
@@ -788,22 +866,43 @@ function writeLocalSettings( $conf ) {
 	$ugly = ($conf->prettyURLs ? "# " : "");
 	$rights = ($conf->RightsUrl) ? "" : "# ";
 	
+	switch ( $conf->Shm ) {
+		case 'memcached':
+			$memcached = 'true';
+			$turck = '#';
+			$mcservers = var_export( $conf->MCServerArray, true );
+			break;
+		case 'turck':
+			$memcached = 'false';
+			$mcservers = 'array()';
+			$turck = '';
+			break;
+		default:
+			$memcached = 'false';
+			$mcservers = 'array()';
+			$turck = '#';
+	}
+
+
 	$file = @fopen( "/dev/urandom", "r" );
 	if ( $file ) {
-		$proxyKey = bin2hex( fread( $file, 32 ) );
+		$secretKey = bin2hex( fread( $file, 32 ) );
 		fclose( $file );
 	} else {
-		$proxyKey = "";
+		$secretKey = "";
 		for ( $i=0; $i<8; $i++ ) {
-			$proxyKey .= dechex(mt_rand(0, 0x7fffffff));
+			$secretKey .= dechex(mt_rand(0, 0x7fffffff));
 		}
-		print "Warning: \$wgProxyKey is insecure\n";
+		print "<li>Warning: \$wgSecretKey key is insecure, generated with mt_rand(). Consider changing it manually.</li>\n";
 	}
 
 	# Add slashes to strings for double quoting
 	$slconf = array_map( "escapePhpString", get_object_vars( $conf ) );
+	if( $conf->License == 'gfdl' ) {
+		# Needs literal string interpolation for the current style path
+		$slconf['RightsIcon'] = $conf->RightsIcon;
+	}
 
-	
 	$sep = (DIRECTORY_SEPARATOR == "\\") ? ";" : ":";
 	return "
 # This file was automatically generated by the MediaWiki installer.
@@ -812,7 +911,7 @@ function writeLocalSettings( $conf ) {
 
 \$IP = \"{$slconf['IP']}\";
 ini_set( \"include_path\", \".$sep\$IP$sep\$IP/includes$sep\$IP/languages\" );
-require_once( \"DefaultSettings.php\" );
+require_once( \"includes/DefaultSettings.php\" );
 
 # If PHP's memory limit is very low, some operations may fail.
 " . ($conf->raiseMemory ? '' : '# ' ) . "ini_set( 'memory_limit', '20M' );" . "
@@ -821,7 +920,7 @@ if ( \$wgCommandLineMode ) {
 	if ( isset( \$_SERVER ) && array_key_exists( 'REQUEST_METHOD', \$_SERVER ) ) {
 		die( \"This script must be run from the command line\\n\" );
 	}
-} else {
+} elseif ( empty( \$wgConfiguring ) ) {
 	## Compress output if the browser supports it
 	{$zlib}if( !ini_get( 'zlib.output_compression' ) ) @ob_start( 'ob_gzhandler' );
 }
@@ -836,9 +935,9 @@ if ( \$wgCommandLineMode ) {
 {$pretty}\$wgArticlePath      = \"\$wgScript/\$1\";
 {$ugly}\$wgArticlePath      = \"\$wgScript?title=\$1\";
 
-\$wgStylePath        = \"\$wgScriptPath/stylesheets\";
-\$wgStyleDirectory   = \"\$IP/stylesheets\";
-\$wgLogo             = \"\$wgStylePath/images/wiki.png\";
+\$wgStylePath        = \"\$wgScriptPath/skins\";
+\$wgStyleDirectory   = \"\$IP/skins\";
+\$wgLogo             = \"\$wgStylePath/common/images/wiki.png\";
 
 \$wgUploadPath       = \"\$wgScriptPath/images\";
 \$wgUploadDirectory  = \"\$IP/images\";
@@ -850,6 +949,7 @@ if ( \$wgCommandLineMode ) {
 \$wgDBname           = \"{$slconf['DBname']}\";
 \$wgDBuser           = \"{$slconf['DBuser']}\";
 \$wgDBpassword       = \"{$slconf['DBpassword']}\";
+\$wgDBprefix         = \"{$slconf['DBprefix']}\";
 
 ## To allow SQL queries through the wiki's Special:Askaql page,
 ## uncomment the next lines. THIS IS VERY INSECURE. If you want
@@ -861,8 +961,14 @@ if ( \$wgCommandLineMode ) {
 # \$wgDBsqluser        = \"sqluser\";
 # \$wgDBsqlpassword    = \"sqlpass\";
 
+# If you're on MySQL 3.x, this next line must be FALSE:
 \$wgDBmysql4 = \$wgEnablePersistentLC = {$conf->DBmysql4};
 
+## Shared memory settings
+\$wgUseMemCached = $memcached;
+\$wgMemCachedServers = $mcservers;
+{$turck}\$wgUseTurckShm = function_exists( 'mmcache_get' ) && php_sapi_name() == 'apache';
+
 ## To enable image uploads, make sure the 'images' directory
 ## is writable, then uncomment this:
 # \$wgDisableUploads		= false;
@@ -882,7 +988,7 @@ if ( \$wgCommandLineMode ) {
 \$wgLanguageCode = \"{$slconf['LanguageCode']}\";
 \$wgUseLatin1 = " . ($conf->Latin1 ? 'true' : 'false') . ";\n
 
-\$wgProxyKey = \"$proxyKey\";
+\$wgProxyKey = \"$secretKey\";
 
 ## Default skin: you can change the default skin. Use the internal symbolic
 ## names, ie 'standard', 'nostalgia', 'cologneblue', 'monobook':
@@ -893,10 +999,10 @@ if ( \$wgCommandLineMode ) {
 ## License and Creative Commons licenses are supported so far.
 {$rights}\$wgEnableCreativeCommonsRdf = true;
 \$wgRightsPage = \"\"; # Set to the title of a wiki page that describes your license/copyright
-\$wgRightsUrl = \"{$conf->RightsUrl}\";
-\$wgRightsText = \"{$conf->RightsText}\";
-\$wgRightsIcon = \"{$conf->RightsIcon}\";
-# \$wgRightsCode = \"{$conf->RightsCode}\"; # Not yet used
+\$wgRightsUrl = \"{$slconf['RightsUrl']}\";
+\$wgRightsText = \"{$slconf['RightsText']}\";
+\$wgRightsIcon = \"{$slconf['RightsIcon']}\";
+# \$wgRightsCode = \"{$slconf['RightsCode']}\"; # Not yet used
 ";
 }
 
@@ -930,7 +1036,7 @@ function aField( &$conf, $field, $text, $type = "", $value = "" ) {
 	} else {
 		$xtype = "";
 	}
-	
+
 	if(!(isset($id)) or ($id == "") ) $id = $field;
 	$nolabel = ($type == "radio") || ($type == "hidden");
 	if( $nolabel ) {
@@ -938,7 +1044,7 @@ function aField( &$conf, $field, $text, $type = "", $value = "" ) {
 	} else {
 		echo "\t\t<label class='column' for=\"$id\">$text</label>\n";
 	}
-	
+
 	if( $type == "radio" && $value == $conf->$field ) {
 		$checked = "checked='checked'";
 	} else {
@@ -954,7 +1060,7 @@ function aField( &$conf, $field, $text, $type = "", $value = "" ) {
 	if( $nolabel ) {
 		echo " $text</label>\n";
 	}
-	
+
 	global $errs;
 	if(isset($errs[$field])) echo "<span class='error'>" . $errs[$field] . "</span>\n";
 }
@@ -962,26 +1068,29 @@ function aField( &$conf, $field, $text, $type = "", $value = "" ) {
 function getLanguageList() {
 	global $wgLanguageNames;
 	if( !isset( $wgLanguageNames ) ) {
-		$wgLanguageCode = "xxx";
+		$wgContLanguageCode = "xxx";
 		function wfLocalUrl( $x ) { return $x; }
 		function wfLocalUrlE( $x ) { return $x; }
-		require_once( "../languages/Names.php" );
+		require_once( "languages/Names.php" );
 	}
-	
+
 	$codes = array();
 	$latin1 = array( "da", "de", "en", "es", "fr", "nl", "sv" );
-	
+
 	$d = opendir( "../languages" );
 	while( false !== ($f = readdir( $d ) ) ) {
 		if( preg_match( '/Language([A-Z][a-z_]+)\.php$/', $f, $m ) ) {
 			$code = str_replace( '_', '-', strtolower( $m[1] ) );
-			if ( array_key_exists( $code, $wgLanguageNames ) ) {
-				if( in_array( $code, $latin1 ) ) {
-					$codes[$code] = "$code - " . $wgLanguageNames[$code] . " - Unicode";
-					$codes[$code.'-latin1'] = "$code - " . $wgLanguageNames[$code] . " - Latin-1";
-				} else {
-					$codes[$code] = "$code - " . $wgLanguageNames[$code];
-				}
+			if( isset( $wgLanguageNames[$code] ) ) {
+				$name = $code . ' - ' . $wgLanguageNames[$code];
+			} else {
+				$name = $code;
+			}
+			if( in_array( $code, $latin1 ) ) {
+				$codes[$code] = $name . " - Unicode";
+				$codes[$code.'-latin1'] = $name . " - Latin-1";
+			} else {
+				$codes[$code] = $name;
 			}
 		}
 	}
@@ -990,6 +1099,50 @@ function getLanguageList() {
 	return $codes;
 }
 
+# Test a memcached server
+function testMemcachedServer( $server ) {
+	$hostport = explode(":", $server);
+	$errstr = false;
+	$fp = false;
+	if ( !function_exists( 'fsockopen' ) ) {
+		$errstr = "Can't connect to memcached, fsockopen() not present";
+	}
+	if ( !$errstr &&  count( $hostport ) != 2 ) {
+		$errstr = 'Please specify host and port';
+		var_dump( $hostport );
+	}
+	if ( !$errstr ) {
+		list( $host, $port ) = $hostport;
+		$errno = 0;
+		$fsockerr = '';
+
+		$fp = @fsockopen( $host, $port, $errno, $fsockerr, 1.0 );
+		if ( $fp === false ) {
+			$errstr = "Cannot connect to memcached on $host:$port : $fsockerr";
+		}
+	}
+	if ( !$errstr ) {
+		$command = "version\r\n";
+		$bytes = fwrite( $fp, $command );
+		if ( $bytes != strlen( $command ) ) {
+			$errstr = "Cannot write to memcached socket on $host:$port";
+		}
+	}
+	if ( !$errstr ) {
+		$expected = "VERSION ";
+		$response = fread( $fp, strlen( $expected ) );
+		if ( $response != $expected ) {
+			$errstr = "Didn't get correct memcached response from $host:$port";
+		}
+	}
+	if ( $fp ) {
+		fclose( $fp );
+	}
+	if ( !$errstr ) {
+		echo "<li>Connected to memcached on $host:$port successfully";
+	}
+	return $errstr;
+}
 ?>
 
 </body>
