@@ -1,18 +1,29 @@
 <?php
-if( defined( "MEDIAWIKI" ) ) {
+/**
+ * @package MediaWiki
+ */
+
+/**
+ * This is not a valid entry point, perform no further processing unless MEDIAWIKI is defined
+ */
+if( defined( 'MEDIAWIKI' ) ) {
 
 # See design.doc
 
-if($wgUseTeX) require_once( "Math.php" );
+if($wgUseTeX) require_once( 'Math.php' );
 
+/**
+ * @todo document
+ * @package MediaWiki
+ */
 class OutputPage {
 	var $mHeaders, $mCookies, $mMetatags, $mKeywords;
 	var $mLinktags, $mPagetitle, $mBodytext, $mDebugtext;
 	var $mHTMLtitle, $mRobotpolicy, $mIsarticle, $mPrintable;
 	var $mSubtitle, $mRedirect;
 	var $mLastModified, $mCategoryLinks;
-	var $mScripts;
-
+	var $mScripts, $mLinkColours;
+	
 	var $mSuppressQuickbar;
 	var $mOnloadHandler;
 	var $mDoNothing;
@@ -22,14 +33,17 @@ class OutputPage {
 	var $mShowFeedLinks = false;
 	var $mEnableClientCache = true;
 
-	function OutputPage()
-	{
+	/**
+	 * Constructor
+	 * Initialise private variables
+	 */
+	function OutputPage() {
 		$this->mHeaders = $this->mCookies = $this->mMetatags =
 		$this->mKeywords = $this->mLinktags = array();
 		$this->mHTMLtitle = $this->mPagetitle = $this->mBodytext =
 		$this->mRedirect = $this->mLastModified =
 		$this->mSubtitle = $this->mDebugtext = $this->mRobotpolicy =
-		$this->mOnloadHandler = "";
+		$this->mOnloadHandler = '';
 		$this->mIsArticleRelated = $this->mIsarticle = $this->mPrintable = true;
 		$this->mSuppressQuickbar = $this->mPrintable = false;
 		$this->mLanguageLinks = array();
@@ -38,10 +52,10 @@ class OutputPage {
 		$this->mContainsOldMagic = $this->mContainsNewMagic = 0;
 		$this->mParserOptions = ParserOptions::newFromUser( $temp = NULL );
 		$this->mSquidMaxage = 0;
-		$this->mScripts = "";
+		$this->mScripts = '';
 	}
 
-	function addHeader( $name, $val ) { array_push( $this->mHeaders, "$name: $val" ) ; }
+	function addHeader( $name, $val ) { array_push( $this->mHeaders, $name.': '.$val ) ; }
 	function addCookie( $name, $val ) { array_push( $this->mCookies, array( $name, $val ) ); }
 	function redirect( $url, $responsecode = '302' ) { $this->mRedirect = $url; $this->mRedirectCode = $responsecode; }
 
@@ -59,44 +73,40 @@ class OutputPage {
 	function addMetadataLink( $linkarr ) {
 		# note: buggy CC software only reads first "meta" link
 		static $haveMeta = false;
-		$linkarr["rel"] = ($haveMeta) ? "alternate meta" : "meta";
+		$linkarr['rel'] = ($haveMeta) ? 'alternate meta' : 'meta';
 		$this->addLink( $linkarr );
 		$haveMeta = true;
 	}
 
-	# checkLastModified tells the client to use the client-cached page if
-	# possible. If sucessful, the OutputPage is disabled so that
-	# any future call to OutputPage->output() have no effect. The method
-	# returns true iff cache-ok headers was sent.
-	function checkLastModified ( $timestamp )
-	{
+	/**
+	 * checkLastModified tells the client to use the client-cached page if
+	 * possible. If sucessful, the OutputPage is disabled so that
+	 * any future call to OutputPage->output() have no effect. The method
+	 * returns true iff cache-ok headers was sent.
+	 */
+	function checkLastModified ( $timestamp ) {
 		global $wgLang, $wgCachePages, $wgUser;
+		$timestamp=wfTimestamp(TS_MW,$timestamp);
 		if( !$wgCachePages ) {
 			wfDebug( "CACHE DISABLED\n", false );
 			return;
 		}
-		if( preg_match( '/MSIE ([1-4]|5\.0)/', $_SERVER["HTTP_USER_AGENT"] ) ) {
-			# IE 5.0 has probs with our caching
-			wfDebug( "-- bad client, not caching\n", false );
-			return;
-		}
-		if( $wgUser->getOption( "nocache" ) ) {
+		if( $wgUser->getOption( 'nocache' ) ) {
 			wfDebug( "USER DISABLED CACHE\n", false );
 			return;
 		}
 
-		$lastmod = gmdate( "D, j M Y H:i:s", wfTimestamp2Unix( max( $timestamp, $wgUser->mTouched ) ) ) . " GMT";
+		$lastmod = gmdate( 'D, j M Y H:i:s', wfTimestamp(TS_UNIX, max( $timestamp, $wgUser->mTouched ) ) ) . ' GMT';
 
-		if( !empty( $_SERVER["HTTP_IF_MODIFIED_SINCE"] ) ) {
+		if( !empty( $_SERVER['HTTP_IF_MODIFIED_SINCE'] ) ) {
 			# IE sends sizes after the date like this:
 			# Wed, 20 Aug 2003 06:51:19 GMT; length=5202
 			# this breaks strtotime().
 			$modsince = preg_replace( '/;.*$/', '', $_SERVER["HTTP_IF_MODIFIED_SINCE"] );
-			$ismodsince = wfUnix2Timestamp( strtotime( $modsince ) );
+			$ismodsince = wfTimestamp( TS_MW, strtotime( $modsince ) );
 			wfDebug( "-- client send If-Modified-Since: " . $modsince . "\n", false );
 			wfDebug( "--  we might send Last-Modified : $lastmod\n", false );
-
-			if( ($ismodsince >= $timestamp ) and $wgUser->validateCache( $ismodsince ) ) {
+			if( ($ismodsince >= $timestamp ) && $wgUser->validateCache( $ismodsince ) ) {
 				# Make sure you're in a place you can leave when you call us!
 				header( "HTTP/1.0 304 Not Modified" );
 				$this->mLastModified = $lastmod;
@@ -139,18 +149,20 @@ class OutputPage {
 				return '';
 		}
 	}
+
 	function setRobotpolicy( $str ) { $this->mRobotpolicy = $str; }
 	function setHTMLTitle( $name ) {$this->mHTMLtitle = $name; }
 	function setPageTitle( $name ) {
-		global $action;
+		global $action, $wgContLang;
+		$name = $wgContLang->convert($name, true);
 		$this->mPagetitle = $name;
 		if(!empty($action)) {
 			$taction =  $this->getPageTitleActionText();
 			if( !empty( $taction ) ) {
-				$name .= " - $taction";
+				$name .= ' - '.$taction;
 			}
 		}
-		$this->setHTMLTitle( $name . " - " . wfMsg( "wikititlesuffix" ) );
+		$this->setHTMLTitle( $name . ' - ' . wfMsg( 'wikititlesuffix' ) );
 	}
 	function getHTMLTitle() { return $this->mHTMLtitle; }
 	function getPageTitle() { return $this->mPagetitle; }
@@ -165,8 +177,7 @@ class OutputPage {
 	function getOnloadHandler() { return $this->mOnloadHandler; }
 	function disable() { $this->mDoNothing = true; }
 
-	function setArticleRelated( $v )
-	{
+	function setArticleRelated( $v ) {
 		$this->mIsArticleRelated = $v;
 		if ( !$v ) {
 			$this->mIsarticle = false;
@@ -179,20 +190,16 @@ class OutputPage {
 		}
 	}
 
-	function isArticleRelated()
-	{
-		return $this->mIsArticleRelated;
-	}
+	function isArticleRelated() { return $this->mIsArticleRelated; }
 
-	function getLanguageLinks() {
-		return $this->mLanguageLinks;
-	}
+	function getLanguageLinks() { return $this->mLanguageLinks; }
 	function addLanguageLinks($newLinkArray) {
 		$this->mLanguageLinks += $newLinkArray;
 	}
 	function setLanguageLinks($newLinkArray) {
 		$this->mLanguageLinks = $newLinkArray;
 	}
+
 	function getCategoryLinks() {
 		return $this->mCategoryLinks;
 	}
@@ -207,32 +214,71 @@ class OutputPage {
 	function isQuickbarSuppressed() { return $this->mSuppressQuickbar; }
 
 	function addHTML( $text ) { $this->mBodytext .= $text; }
+	function clearHTML() { $this->mBodytext = ''; }
 	function debug( $text ) { $this->mDebugtext .= $text; }
 
-	function setParserOptions( $options )
-	{
+	function setParserOptions( $options ) {
 		return wfSetVar( $this->mParserOptions, $options );
 	}
 
-	# First pass--just handle <nowiki> sections, pass the rest off
-	# to doWikiPass2() which does all the real work.
-	#
-	# $cacheArticle - assume this text is the main text for the given article
-	#
-	function addWikiText( $text, $linestart = true, $cacheArticle = NULL )
-	{
-		global $wgParser, $wgParserCache, $wgUser, $wgTitle;
+	/**
+	 * Convert wikitext to HTML and add it to the buffer
+	 */
+	function addWikiText( $text, $linestart = true ) {
+		global $wgParser, $wgTitle, $wgUseTidy;
 
 		$parserOutput = $wgParser->parse( $text, $wgTitle, $this->mParserOptions, $linestart );
+		$this->mLanguageLinks += $parserOutput->getLanguageLinks();
+		$this->mCategoryLinks += $parserOutput->getCategoryLinks();
+		$this->addHTML( $parserOutput->getText() );
+	}
+
+	/**
+	 * Add wikitext to the buffer, assuming that this is the primary text for a page view
+	 * Saves the text into the parser cache if possible
+	 */
+	function addPrimaryWikiText( $text, $cacheArticle ) {
+		global $wgParser, $wgParserCache, $wgUser, $wgTitle, $wgUseTidy;
+
+		$parserOutput = $wgParser->parse( $text, $wgTitle, $this->mParserOptions, true );
+
+		$text = $parserOutput->getText();
+		
 		if ( $cacheArticle ) {
 			$wgParserCache->save( $parserOutput, $cacheArticle, $wgUser );
 		}
 
 		$this->mLanguageLinks += $parserOutput->getLanguageLinks();
 		$this->mCategoryLinks += $parserOutput->getCategoryLinks();
-		$this->addHTML( $parserOutput->getText() );
+		$this->addHTML( $text );
 	}
 
+	/**
+	 * Add the output of a QuickTemplate to the output buffer
+	 * @param QuickTemplate $template
+	 */
+	function addTemplate( &$template ) {
+		ob_start();
+		$template->execute();
+		$this->addHtml( ob_get_contents() );
+		ob_end_clean();
+	}
+
+	/**
+	 * Parse wikitext and return the HTML. This is for special pages that add the text later
+	 */
+	function parse( $text, $linestart = true ) {
+		global $wgParser, $wgTitle;
+		$parserOutput = $wgParser->parse( $text, $wgTitle, $this->mParserOptions, $linestart );
+		return $parserOutput->getText();
+	}
+	
+	/**
+	 * @param $article
+	 * @param $user
+	 *
+	 * @return bool
+	 */
 	function tryParserCache( $article, $user ) {
 		global $wgParserCache;
 		$parserOutput = $wgParserCache->get( $article, $user );
@@ -246,22 +292,29 @@ class OutputPage {
 		}
 	}
 
-	# Set the maximum cache time on the Squid in seconds
+	/**
+	 * Set the maximum cache time on the Squid in seconds
+	 * @param $maxage
+	 */
 	function setSquidMaxage( $maxage ) {
 		$this->mSquidMaxage = $maxage;
 	}
 
-	# Use enableClientCache(false) to force it to send nocache headers
+	/**
+	 * Use enableClientCache(false) to force it to send nocache headers
+	 * @param $state
+	 */
 	function enableClientCache( $state ) {
 		return wfSetVar( $this->mEnableClientCache, $state );
 	}
 
 	function sendCacheControl() {
 		global $wgUseSquid, $wgUseESI;
-		# FIXME: This header may cause trouble with some versions of Internet Explorer
-		header( "Vary: Accept-Encoding, Cookie" );
+		# don't serve compressed data to clients who can't handle it
+		# maintain different caches for logged-in users and non-logged in ones
+		header( 'Vary: Accept-Encoding, Cookie' );
 		if( $this->mEnableClientCache ) {
-			if( $wgUseSquid && ! isset( $_COOKIE[ini_get( "session.name") ] ) &&
+			if( $wgUseSquid && ! isset( $_COOKIE[ini_get( 'session.name') ] ) &&
 			  ! $this->isPrintable() && $this->mSquidMaxage != 0 )
 			{
 				if ( $wgUseESI ) {
@@ -296,30 +349,30 @@ class OutputPage {
 
 			# In general, the absence of a last modified header should be enough to prevent
 			# the client from using its cache. We send a few other things just to make sure.
-			header( "Expires: -1" );
-			header( "Cache-Control: no-cache, no-store, max-age=0, must-revalidate" );
-			header( "Pragma: no-cache" );
+			header( 'Expires: -1' );
+			header( 'Cache-Control: no-cache, no-store, max-age=0, must-revalidate' );
+			header( 'Pragma: no-cache' );
 		}
 	}
 
-	# Finally, all the text has been munged and accumulated into
-	# the object, let's actually output it:
-	#
-	function output()
-	{
+	/**
+	 * Finally, all the text has been munged and accumulated into
+	 * the object, let's actually output it:
+	 */
+	function output() {
 		global $wgUser, $wgLang, $wgDebugComments, $wgCookieExpiration;
-		global $wgInputEncoding, $wgOutputEncoding, $wgLanguageCode;
+		global $wgInputEncoding, $wgOutputEncoding, $wgContLanguageCode;
 		global $wgDebugRedirects, $wgMimeType, $wgProfiler;
+
 		if( $this->mDoNothing ){
 			return;
 		}
-		$fname = "OutputPage::output";
+		$fname = 'OutputPage::output';
 		wfProfileIn( $fname );
-
 		$sk = $wgUser->getSkin();
 
-		if ( "" != $this->mRedirect ) {
-			if( substr( $this->mRedirect, 0, 4 ) != "http" ) {
+		if ( '' != $this->mRedirect ) {
+			if( substr( $this->mRedirect, 0, 4 ) != 'http' ) {
 				# Standards require redirect URLs to be absolute
 				global $wgServer;
 				$this->mRedirect = $wgServer . $this->mRedirect;
@@ -328,7 +381,7 @@ class OutputPage {
 				if( !$wgDebugRedirects ) {
 					header("HTTP/1.1 {$this->mRedirectCode} Moved Permanently");
 				}
-				$this->mLastModified = gmdate( "D, j M Y H:i:s" ) . " GMT";
+				$this->mLastModified = gmdate( 'D, j M Y H:i:s' ) . ' GMT';
 			}
 
 			$this->sendCacheControl();
@@ -339,50 +392,58 @@ class OutputPage {
 				print "<p>Location: <a href=\"$url\">$url</a></p>\n";
 				print "</body>\n</html>\n";
 			} else {
-				header( "Location: {$this->mRedirect}" );
+				header( 'Location: '.$this->mRedirect );
 			}
 			if ( isset( $wgProfiler ) ) { wfDebug( $wgProfiler->getOutput() ); }
+			wfProfileOut( $fname );
 			return;
 		}
 
+
 		# Buffer output; final headers may depend on later processing
 		ob_start();
 
+		$this->transformBuffer();
+		
+		# Disable temporary placeholders, so that the skin produces HTML
+		$sk->postParseLinkColour( false );
+
 		header( "Content-type: $wgMimeType; charset={$wgOutputEncoding}" );
-		header( "Content-language: {$wgLanguageCode}" );
+		header( 'Content-language: '.$wgContLanguageCode );
 
 		$exp = time() + $wgCookieExpiration;
 		foreach( $this->mCookies as $name => $val ) {
-			setcookie( $name, $val, $exp, "/" );
+			setcookie( $name, $val, $exp, '/' );
 		}
 
+		wfProfileIn( 'Output-skin' );
 		$sk->outputPage( $this );
-
+		wfProfileOut( 'Output-skin' );
+		
 		$this->sendCacheControl();
 		ob_end_flush();
+		wfProfileOut( $fname );
 	}
 
-	function out( $ins )
-	{
-		global $wgInputEncoding, $wgOutputEncoding, $wgLang;
+	function out( $ins ) {
+		global $wgInputEncoding, $wgOutputEncoding, $wgContLang;
 		if ( 0 == strcmp( $wgInputEncoding, $wgOutputEncoding ) ) {
 			$outs = $ins;
 		} else {
-			$outs = $wgLang->iconv( $wgInputEncoding, $wgOutputEncoding, $ins );
+			$outs = $wgContLang->iconv( $wgInputEncoding, $wgOutputEncoding, $ins );
 			if ( false === $outs ) { $outs = $ins; }
 		}
 		print $outs;
 	}
 
-	function setEncodings()
-	{
+	function setEncodings() {
 		global $wgInputEncoding, $wgOutputEncoding;
-		global $wgUser, $wgLang;
+		global $wgUser, $wgContLang;
 
 		$wgInputEncoding = strtolower( $wgInputEncoding );
 
 		if( $wgUser->getOption( 'altencoding' ) ) {
-			$wgLang->setAltEncoding();
+			$wgContLang->setAltEncoding();
 			return;
 		}
 
@@ -422,20 +483,34 @@ class OutputPage {
 		$wgOutputEncoding = $wgInputEncoding;
 	}
 
-	# Returns a HTML comment with the elapsed time since request.
-	# This method has no side effects.
-	function reportTime()
-	{
-		global $wgRequestTime;
+	/**
+	 * Returns a HTML comment with the elapsed time since request.
+	 * This method has no side effects.
+	 */
+	function reportTime() {
+		global $wgRequestTime, $wgProfiling, $wgProfileToCommentUser, $wgUser;
+
+
+		if ( $wgProfiling && $wgUser && $wgProfileToCommentUser &&
+		  $wgProfileToCommentUser == $wgUser->getName() ) 
+		{
+			$prof = wfGetProfilingOutput();
+			// Strip end of comment
+			$prof = str_replace( '-->', '--&lt;', $prof );
+			$com = "<!--\n$prof\n-->\n";
+		} else {
+			$com = '';
+		}
+
 
 		$now = wfTime();
-		list( $usec, $sec ) = explode( " ", $wgRequestTime );
+		list( $usec, $sec ) = explode( ' ', $wgRequestTime );
 		$start = (float)$sec + (float)$usec;
 		$elapsed = $now - $start;
 
 		# Use real server name if available, so we know which machine
 		# in a server farm generated the current page.
-		if ( function_exists( "posix_uname" ) ) {
+		if ( function_exists( 'posix_uname' ) ) {
 			$uname = @posix_uname();
 		} else {
 			$uname = false;
@@ -446,140 +521,134 @@ class OutputPage {
 			# This may be a virtual server.
 			$hostname = $_SERVER['SERVER_NAME'];
 		}
-		$com = sprintf( "<!-- Served by %s in %01.2f secs. -->",
+		$com .= sprintf( "<!-- Served by %s in %01.2f secs. -->\n",
 		  $hostname, $elapsed );
 		return $com;
 	}
 
-	# Note: these arguments are keys into wfMsg(), not text!
-	#
-	function errorpage( $title, $msg )
-	{
+	/**
+	 * Note: these arguments are keys into wfMsg(), not text!
+	 */
+	function errorpage( $title, $msg ) {
 		global $wgTitle;
 
-		$this->mDebugtext .= "Original title: " .
+		$this->mDebugtext .= 'Original title: ' .
 		  $wgTitle->getPrefixedText() . "\n";
 		$this->setPageTitle( wfMsg( $title ) );
-		$this->setHTMLTitle( wfMsg( "errorpagetitle" ) );
-		$this->setRobotpolicy( "noindex,nofollow" );
+		$this->setHTMLTitle( wfMsg( 'errorpagetitle' ) );
+		$this->setRobotpolicy( 'noindex,nofollow' );
 		$this->setArticleRelated( false );
 		$this->enableClientCache( false );
+		$this->mRedirect = '';
 
-		$this->mBodytext = "";
-		$this->addHTML( "<p>" . wfMsg( $msg ) . "</p>\n" );
+		$this->mBodytext = '';
+		$this->addHTML( '<p>' . wfMsg( $msg ) . "</p>\n" );
 		$this->returnToMain( false );
 
 		$this->output();
-		wfAbruptExit();
+		wfErrorExit();
 	}
 
-	function sysopRequired()
-	{
+	function sysopRequired() {
 		global $wgUser;
 
-		$this->setPageTitle( wfMsg( "sysoptitle" ) );
-		$this->setHTMLTitle( wfMsg( "errorpagetitle" ) );
-		$this->setRobotpolicy( "noindex,nofollow" );
+		$this->setPageTitle( wfMsg( 'sysoptitle' ) );
+		$this->setHTMLTitle( wfMsg( 'errorpagetitle' ) );
+		$this->setRobotpolicy( 'noindex,nofollow' );
 		$this->setArticleRelated( false );
-		$this->mBodytext = "";
+		$this->mBodytext = '';
 
 		$sk = $wgUser->getSkin();
-		$ap = $sk->makeKnownLink( wfMsg( "administrators" ), "" );
-		$this->addHTML( wfMsg( "sysoptext", $ap ) );
+		$ap = $sk->makeKnownLink( wfMsgForContent( 'administrators' ), '' );
+		$this->addHTML( wfMsg( 'sysoptext', $ap ) );
 		$this->returnToMain();
 	}
 
-	function developerRequired()
-	{
+	function developerRequired() {
 		global $wgUser;
 
-		$this->setPageTitle( wfMsg( "developertitle" ) );
-		$this->setHTMLTitle( wfMsg( "errorpagetitle" ) );
-		$this->setRobotpolicy( "noindex,nofollow" );
+		$this->setPageTitle( wfMsg( 'developertitle' ) );
+		$this->setHTMLTitle( wfMsg( 'errorpagetitle' ) );
+		$this->setRobotpolicy( 'noindex,nofollow' );
 		$this->setArticleRelated( false );
-		$this->mBodytext = "";
+		$this->mBodytext = '';
 
 		$sk = $wgUser->getSkin();
-		$ap = $sk->makeKnownLink( wfMsg( "administrators" ), "" );
-		$this->addHTML( wfMsg( "developertext", $ap ) );
+		$ap = $sk->makeKnownLink( wfMsgForContent( 'administrators' ), '' );
+		$this->addHTML( wfMsg( 'developertext', $ap ) );
 		$this->returnToMain();
 	}
 
-	function loginToUse()
-	{
-		global $wgUser, $wgTitle, $wgLang;
+	function loginToUse() {
+		global $wgUser, $wgTitle, $wgContLang;
 
-		$this->setPageTitle( wfMsg( "loginreqtitle" ) );
-		$this->setHTMLTitle( wfMsg( "errorpagetitle" ) );
-		$this->setRobotpolicy( "noindex,nofollow" );
+		$this->setPageTitle( wfMsg( 'loginreqtitle' ) );
+		$this->setHTMLTitle( wfMsg( 'errorpagetitle' ) );
+		$this->setRobotpolicy( 'noindex,nofollow' );
 		$this->setArticleFlag( false );
-		$this->mBodytext = "";
-		$this->addWikiText( wfMsg( "loginreqtext" ) );
+		$this->mBodytext = '';
+		$this->addWikiText( wfMsg( 'loginreqtext' ) );
 
 		# We put a comment in the .html file so a Sysop can diagnose the page the
 		# user can't see.
 		$this->addHTML( "\n<!--" .
-						$wgLang->getNsText( $wgTitle->getNamespace() ) .
-						":" .
-						$wgTitle->getDBkey() . "-->" );
+						$wgContLang->getNsText( $wgTitle->getNamespace() ) .
+						':' .
+						$wgTitle->getDBkey() . '-->' );
 		$this->returnToMain();		# Flip back to the main page after 10 seconds.
 	}
 
-	function databaseError( $fname, $sql, $error, $errno )
-	{
-		global $wgUser, $wgCommandLineMode;
+	function databaseError( $fname, $sql, $error, $errno ) {
+		global $wgUser, $wgCommandLineMode, $wgShowSQLErrors;
 
-		$this->setPageTitle( wfMsgNoDB( "databaseerror" ) );
-		$this->setRobotpolicy( "noindex,nofollow" );
+		$this->setPageTitle( wfMsgNoDB( 'databaseerror' ) );
+		$this->setRobotpolicy( 'noindex,nofollow' );
 		$this->setArticleRelated( false );
 		$this->enableClientCache( false );
+		$this->mRedirect = '';
+
+		if( !$wgShowSQLErrors ) {
+			$sql = wfMsg( 'sqlhidden' );
+		}
 
 		if ( $wgCommandLineMode ) {
-			$msg = wfMsgNoDB( "dberrortextcl" );
+			$msg = wfMsgNoDB( 'dberrortextcl', htmlspecialchars( $sql ),
+						htmlspecialchars( $fname ), $errno, htmlspecialchars( $error ) );
 		} else {
-			$msg = wfMsgNoDB( "dberrortext" );
+			$msg = wfMsgNoDB( 'dberrortext', htmlspecialchars( $sql ),
+						htmlspecialchars( $fname ), $errno, htmlspecialchars( $error ) );
 		}
 
-		$msg = str_replace( "$1", htmlspecialchars( $sql ), $msg );
-		$msg = str_replace( "$2", htmlspecialchars( $fname ), $msg );
-		$msg = str_replace( "$3", $errno, $msg );
-		$msg = str_replace( "$4", htmlspecialchars( $error ), $msg );
-
 		if ( $wgCommandLineMode || !is_object( $wgUser )) {
-			print "$msg\n";
-			wfAbruptExit();
+			print $msg."\n";
+			wfErrorExit();
 		}
-		$sk = $wgUser->getSkin();
-		$shlink = $sk->makeKnownLink( wfMsgNoDB( "searchhelppage" ),
-		  wfMsgNoDB( "searchingwikipedia" ) );
-		$msg = str_replace( "$5", $shlink, $msg );
 		$this->mBodytext = $msg;
 		$this->output();
-		wfAbruptExit();
+		wfErrorExit();
 	}
 
-	function readOnlyPage( $source = null, $protected = false )
-	{
+	function readOnlyPage( $source = null, $protected = false ) {
 		global $wgUser, $wgReadOnlyFile;
 
-		$this->setRobotpolicy( "noindex,nofollow" );
+		$this->setRobotpolicy( 'noindex,nofollow' );
 		$this->setArticleRelated( false );
 
 		if( $protected ) {
-			$this->setPageTitle( wfMsg( "viewsource" ) );
-			$this->addWikiText( wfMsg( "protectedtext" ) );
+			$this->setPageTitle( wfMsg( 'viewsource' ) );
+			$this->addWikiText( wfMsg( 'protectedtext' ) );
 		} else {
-			$this->setPageTitle( wfMsg( "readonly" ) );
+			$this->setPageTitle( wfMsg( 'readonly' ) );
 			$reason = file_get_contents( $wgReadOnlyFile );
-			$this->addWikiText( wfMsg( "readonlytext", $reason ) );
+			$this->addWikiText( wfMsg( 'readonlytext', $reason ) );
 		}
 
 		if( is_string( $source ) ) {
-			if( strcmp( $source, "" ) == 0 ) {
-				$source = wfMsg( "noarticletext" );
+			if( strcmp( $source, '' ) == 0 ) {
+				$source = wfMsg( 'noarticletext' );
 			}
-			$rows = $wgUser->getOption( "rows" );
-			$cols = $wgUser->getOption( "cols" );
+			$rows = $wgUser->getOption( 'rows' );
+			$cols = $wgUser->getOption( 'cols' );
 			$text = "\n<textarea cols='$cols' rows='$rows' readonly='readonly'>" .
 				htmlspecialchars( $source ) . "\n</textarea>";
 			$this->addHTML( $text );
@@ -588,48 +657,44 @@ class OutputPage {
 		$this->returnToMain( false );
 	}
 
-	function fatalError( $message )
-	{
+	function fatalError( $message ) {
 		$this->setPageTitle( wfMsg( "internalerror" ) );
 		$this->setRobotpolicy( "noindex,nofollow" );
 		$this->setArticleRelated( false );
 		$this->enableClientCache( false );
+		$this->mRedirect = '';
 
 		$this->mBodytext = $message;
 		$this->output();
-		wfAbruptExit();
+		wfErrorExit();
 	}
 
-	function unexpectedValueError( $name, $val )
-	{
-		$this->fatalError( wfMsg( "unexpected", $name, $val ) );
+	function unexpectedValueError( $name, $val ) {
+		$this->fatalError( wfMsg( 'unexpected', $name, $val ) );
 	}
 
-	function fileCopyError( $old, $new )
-	{
-		$this->fatalError( wfMsg( "filecopyerror", $old, $new ) );
+	function fileCopyError( $old, $new ) {
+		$this->fatalError( wfMsg( 'filecopyerror', $old, $new ) );
 	}
 
-	function fileRenameError( $old, $new )
-	{
-		$this->fatalError( wfMsg( "filerenameerror", $old, $new ) );
+	function fileRenameError( $old, $new ) {
+		$this->fatalError( wfMsg( 'filerenameerror', $old, $new ) );
 	}
 
-	function fileDeleteError( $name )
-	{
-		$this->fatalError( wfMsg( "filedeleteerror", $name ) );
+	function fileDeleteError( $name ) {
+		$this->fatalError( wfMsg( 'filedeleteerror', $name ) );
 	}
 
-	function fileNotFoundError( $name )
-	{
-		$this->fatalError( wfMsg( "filenotfound", $name ) );
+	function fileNotFoundError( $name ) {
+		$this->fatalError( wfMsg( 'filenotfound', $name ) );
 	}
 
-	// return from error messages or notes
-	//   auto: 	automatically redirect the user after 10 seconds
-	//   returnto:	page title to return to. Default is Main Page.
-	function returnToMain( $auto = true, $returnto = NULL )
-	{
+	/**
+	 * return from error messages or notes
+	 * @param $auto automatically redirect the user after 10 seconds
+	 * @param $returnto page title to return to. Default is Main Page.
+	 */
+	function returnToMain( $auto = true, $returnto = NULL ) {
 		global $wgUser, $wgOut, $wgRequest;
 
 		if ( $returnto == NULL ) {
@@ -638,48 +703,50 @@ class OutputPage {
 		$returnto = htmlspecialchars( $returnto );
 
 		$sk = $wgUser->getSkin();
-		if ( "" == $returnto ) {
-			$returnto = wfMsg( "mainpage" );
+		if ( '' == $returnto ) {
+			$returnto = wfMsgForContent( 'mainpage' );
 		}
-		$link = $sk->makeKnownLink( $returnto, "" );
+		$link = $sk->makeKnownLink( $returnto, '' );
 
-		$r = wfMsg( "returnto", $link );
+		$r = wfMsg( 'returnto', $link );
 		if ( $auto ) {
 			$titleObj = Title::newFromText( $returnto );
-			$wgOut->addMeta( "http:Refresh", "10;url=" . $titleObj->escapeFullURL() );
+			$wgOut->addMeta( 'http:Refresh', '10;url=' . $titleObj->escapeFullURL() );
 		}
 		$wgOut->addHTML( "\n<p>$r</p>\n" );
 	}
 
-	# This function takes the existing and broken links for the page
-	# and uses the first 10 of them for META keywords
-	function addMetaTags ()
-	{
+	/**
+	 * This function takes the existing and broken links for the page
+	 * and uses the first 10 of them for META keywords
+	 */
+	function addMetaTags () {
 		global $wgLinkCache , $wgOut ;
 		$good = array_keys ( $wgLinkCache->mGoodLinks ) ;
 		$bad = array_keys ( $wgLinkCache->mBadLinks ) ;
 		$a = array_merge ( $good , $bad ) ;
 		$a = array_slice ( $a , 0 , 10 ) ; # 10 keywords max
-		$a = implode ( "," , $a ) ;
+		$a = implode ( ',' , $a ) ;
 		$strip = array(
-			"/<.*?>/" => '',
+			"/<.*?" . ">/" => '',
 			"/[_]/" => ' '
 		);
 		$a = htmlspecialchars(preg_replace(array_keys($strip), array_values($strip),$a ));
 
-		$wgOut->addMeta ( "KEYWORDS" , $a ) ;
+		$wgOut->addMeta ( 'KEYWORDS' , $a ) ;
 	}
 
-	/* private */ function headElement()
-	{
-		global $wgDocType, $wgDTD, $wgLanguageCode, $wgOutputEncoding, $wgMimeType;
-		global $wgUser, $wgLang, $wgRequest;
+	/**
+ 	 * @private
+	 */
+	function headElement() {
+		global $wgDocType, $wgDTD, $wgContLanguageCode, $wgOutputEncoding, $wgMimeType;
+		global $wgUser, $wgContLang, $wgRequest;
 
-		$xml = ($wgMimeType == 'text/xml');
-		if( $xml ) {
-			$ret = "<" . "?xml version=\"1.0\" encoding=\"$wgOutputEncoding\" ?" . ">\n";
+		if( $wgMimeType == 'text/xml' || $wgMimeType == 'application/xhtml+xml' || $wgMimeType == 'application/xml' ) {
+			$ret = "<?xml version=\"1.0\" encoding=\"$wgOutputEncoding\" ?>\n";
 		} else {
-			$ret = "";
+			$ret = '';
 		}
 
 		$ret .= "<!DOCTYPE html PUBLIC \"$wgDocType\"\n        \"$wgDTD\">\n";
@@ -687,24 +754,20 @@ class OutputPage {
 		if ( "" == $this->mHTMLtitle ) {
 			$this->mHTMLtitle = wfMsg( "pagetitle", $this->mPagetitle );
 		}
-		if( $xml ) {
-			$xmlbits = "xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"en\"";
-		} else {
-			$xmlbits = "";
-		}
-		$rtl = $wgLang->isRTL() ? " dir='RTL'" : "";
-		$ret .= "<html $xmlbits lang=\"$wgLanguageCode\" $rtl>\n";
+
+		$rtl = $wgContLang->isRTL() ? " dir='RTL'" : '';
+		$ret .= "<html xmlns=\"http://www.w3.org/1999/xhtml\" xml:lang=\"$wgContLanguageCode\" lang=\"$wgContLanguageCode\" $rtl>\n";
 		$ret .= "<head>\n<title>" . htmlspecialchars( $this->mHTMLtitle ) . "</title>\n";
 		array_push( $this->mMetatags, array( "http:Content-type", "$wgMimeType; charset={$wgOutputEncoding}" ) );
 
 		$ret .= $this->getHeadLinks();
 		global $wgStylePath;
 		if( $this->isPrintable() ) {
-			$media = "";
+			$media = '';
 		} else {
 			$media = "media='print'";
 		}
-		$printsheet = htmlspecialchars( "$wgStylePath/wikiprintable.css" );
+		$printsheet = htmlspecialchars( "$wgStylePath/common/wikiprintable.css" );
 		$ret .= "<link rel='stylesheet' type='text/css' $media href='$printsheet' />\n";
 
 		$sk = $wgUser->getSkin();
@@ -718,30 +781,30 @@ class OutputPage {
 
 	function getHeadLinks() {
 		global $wgRequest, $wgStylePath;
-		$ret = "";
+		$ret = '';
 		foreach ( $this->mMetatags as $tag ) {
-			if ( 0 == strcasecmp( "http:", substr( $tag[0], 0, 5 ) ) ) {
-				$a = "http-equiv";
+			if ( 0 == strcasecmp( 'http:', substr( $tag[0], 0, 5 ) ) ) {
+				$a = 'http-equiv';
 				$tag[0] = substr( $tag[0], 5 );
 			} else {
-				$a = "name";
+				$a = 'name';
 			}
 			$ret .= "<meta $a=\"{$tag[0]}\" content=\"{$tag[1]}\" />\n";
 		}
 		$p = $this->mRobotpolicy;
-		if ( "" == $p ) { $p = "index,follow"; }
+		if ( '' == $p ) { $p = 'index,follow'; }
 		$ret .= "<meta name=\"robots\" content=\"$p\" />\n";
 
 		if ( count( $this->mKeywords ) > 0 ) {
 			$strip = array(
-				"/<.*?>/" => '',
+				"/<.*?" . ">/" => '',
 				"/[_]/" => ' '
 			);
 			$ret .= "<meta name=\"keywords\" content=\"" .
 			  htmlspecialchars(preg_replace(array_keys($strip), array_values($strip),implode( ",", $this->mKeywords ))) . "\" />\n";
 		}
 		foreach ( $this->mLinktags as $tag ) {
-			$ret .= "<link";
+			$ret .= '<link';
 			foreach( $tag as $attr => $val ) {
 				$ret .= " $attr=\"" . htmlspecialchars( $val ) . "\"";
 			}
@@ -749,42 +812,23 @@ class OutputPage {
 		}
 		if( $this->isSyndicated() ) {
 			# FIXME: centralize the mime-type and name information in Feed.php
-			$link = $wgRequest->escapeAppendQuery( "feed=rss" );
+			$link = $wgRequest->escapeAppendQuery( 'feed=rss' );
 			$ret .= "<link rel='alternate' type='application/rss+xml' title='RSS 2.0' href='$link' />\n";
-			$link = $wgRequest->escapeAppendQuery( "feed=atom" );
+			$link = $wgRequest->escapeAppendQuery( 'feed=atom' );
 			$ret .= "<link rel='alternate' type='application/rss+atom' title='Atom 0.3' href='$link' />\n";
 		}
-		# FIXME: get these working
-		# $fix = htmlspecialchars( $wgStylePath . "/ie-png-fix.js" );
-		# $ret .= "<!--[if gte IE 5.5000]><script type='text/javascript' src='$fix'></script><![endif]-->";
+
 		return $ret;
 	}
-
-	function blockedIPpage()
-	{
-		global $wgUser, $wgLang, $wgIP;
-
-		$this->setPageTitle( wfMsg( "blockedtitle" ) );
-		$this->setRobotpolicy( "noindex,nofollow" );
-		$this->setArticleRelated( false );
-
-		$id = $wgUser->blockedBy();
-		$reason = $wgUser->blockedFor();
-                $ip = $wgIP;
-		
-		if ( is_numeric( $id ) ) {
-	                $name = User::whoIs( $id );
-		} else {
-			$name = $id;
-		}
-		$link = "[[" . $wgLang->getNsText( Namespace::getUser() ) .
-		  ":{$name}|{$name}]]";
-
-		$this->addWikiText( wfMsg( "blockedtext", $link, $reason, $ip, $name ) );
-		$this->returnToMain( false );
-	}
 	
+	/**
+	 * Run any necessary pre-output transformations on the buffer text
+	 */
+	function transformBuffer( $options = 0 ) {
+	}
+
 }
 
 }
+
 ?>
