@@ -73,9 +73,9 @@ class UploadForm {
 			/**
 			 *Check for a newly uploaded file.
 			 */
-			$this->mUploadTempName = @$_FILES['wpUploadFile']['tmp_name'];
-			$this->mUploadSize     = @$_FILES['wpUploadFile']['size'];
-			$this->mOname          = $request->getGPCVal( $_FILES['wpUploadFile'], 'name', "" );
+			$this->mUploadTempName = $request->getFileTempName( 'wpUploadFile' );
+			$this->mUploadSize     = $request->getFileSize( 'wpUploadFile' );
+			$this->mOname          = $request->getFileName( 'wpUploadFile' );
 			$this->mSessionKey     = false;
 		}
 	}
@@ -123,7 +123,7 @@ class UploadForm {
 	 * @access private
 	 */
 	function processUpload() {
-		global $wgUser, $wgOut, $wgLang;
+		global $wgUser, $wgOut, $wgLang, $wgContLang;
 		global $wgUploadDirectory;
 		global $wgUseCopyrightUpload, $wgCheckCopyrightUpload;
 
@@ -182,7 +182,7 @@ class UploadForm {
 		if( is_null( $nt ) ) {
 			return $this->uploadError( wfMsg( 'illegalfilename', htmlspecialchars( $filtered ) ) );
 		}
-		$nt->setNamespace( NS_IMAGE );
+		$nt =& Title::makeTitle( NS_IMAGE, $nt->getDBkey() );
 		$this->mUploadSaveName = $nt->getDBkey();
 		
 		/**
@@ -268,6 +268,10 @@ class UploadForm {
 			                $this->mUploadDescription,
 			                $this->mUploadCopyStatus,
 			                $this->mUploadSource );
+
+			/* refresh image metadata cache */
+			new Image( $this->mUploadSaveName, true );
+
 			$this->showSuccess();
 		}
 	}
@@ -387,11 +391,11 @@ class UploadForm {
 	 * @access private
 	 */
 	function showSuccess() {
-		global $wgUser, $wgOut, $wgLang;
+		global $wgUser, $wgOut, $wgContLang;
 		
 		$sk = $wgUser->getSkin();
 		$ilink = $sk->makeMediaLink( $this->mUploadSaveName, Image::wfImageUrl( $this->mUploadSaveName ) );
-		$dname = $wgLang->getNsText( Namespace::getImage() ) . ':'.$this->mUploadSaveName;
+		$dname = $wgContLang->getNsText( Namespace::getImage() ) . ':'.$this->mUploadSaveName;
 		$dlink = $sk->makeKnownLink( $dname, $dname );
 
 		$wgOut->addHTML( '<h2>' . wfMsg( 'successfulupload' ) . "</h2>\n" );
@@ -477,7 +481,12 @@ class UploadForm {
 	function mainUploadForm( $msg='' ) {
 		global $wgOut, $wgUser, $wgLang, $wgUploadDirectory, $wgRequest;
 		global $wgUseCopyrightUpload;
-
+		
+		$cols = intval($wgUser->getOption( 'cols' ));
+		$ew = $wgUser->getOption( 'editwidth' );
+		if ( $ew ) $ew = " style=\"width:100%\"";
+		else $ew = '';
+		
 		if ( '' != $msg ) {
 			$sub = wfMsg( 'uploaderror' );
 			$wgOut->addHTML( "<h2>{$sub}</h2>\n" .
@@ -486,14 +495,14 @@ class UploadForm {
 			$sub = wfMsg( 'uploadfile' );
 			$wgOut->addHTML( "<h2>{$sub}</h2>\n" );
 		}
-		$wgOut->addHTML( "<p>" . wfMsg( 'uploadtext' ) );
+		$wgOut->addWikiText( wfMsg( 'uploadtext' ) );
 		$sk = $wgUser->getSkin();
 
 		$fn = wfMsg( 'filename' );
 		$fd = wfMsg( 'filedesc' );
 		$ulb = wfMsg( 'uploadbtn' );
 
-		$clink = $sk->makeKnownLink( wfMsg( 'copyrightpage' ),
+		$clink = $sk->makeKnownLink( wfMsgForContent( 'copyrightpage' ),
 		  wfMsg( 'copyrightpagename' ) );
 		$ca = wfMsg( 'affirmation', $clink );
 		$iw = wfMsg( 'ignorewarning' );
@@ -527,8 +536,9 @@ class UploadForm {
 	<input tabindex='1' type='file' name=\"wpUploadFile\" size='40' />
 	</td></tr><tr>
 	<td align='right'>{$fd}:</td><td align='left'>
-	<input tabindex='2' type='text' name=\"wpUploadDescription\" value=\""
-	  . htmlspecialchars( $this->mUploadDescription ) . "\" size='40' />
+	<textarea tabindex='2' name=\"wpUploadDescription\" rows='6' cols='{$cols}'{$ew}>"	
+	  . htmlspecialchars( $this->mUploadDescription ) .
+	"</textarea>	
 	</td></tr><tr>
 	{$source}
 	</tr>
@@ -593,7 +603,8 @@ class UploadForm {
 	 * @return bool
 	 */
 	function verify( $tmpfile, $extension ) {
-		if( $this->triggersIEbug( $tmpfile ) ) {
+		if( $this->triggersIEbug( $tmpfile ) ||
+		    $this->triggersSafariBug( $tmpfile ) ) {
 			return false;
 		}
 		
@@ -679,10 +690,18 @@ class UploadForm {
 	 */
 	function triggersIEbug( $filename ) {
 		$file = fopen( $filename, 'rb' );
-		$chunk = strtolower( fread( $file, 200 ) );
+		$chunk = strtolower( fread( $file, 256 ) );
 		fclose( $file );
 		
-		$tags = array( '<html', '<head', '<body', '<script' );
+		$tags = array(
+			'<body',
+			'<head',
+			'<html',
+			'<img',
+			'<pre',
+			'<script',
+			'<table',
+			'<title' );
 		foreach( $tags as $tag ) {
 			if( false !== strpos( $chunk, $tag ) ) {
 				return true;
@@ -690,5 +709,35 @@ class UploadForm {
 		}
 		return false;
 	}
+
+	/**
+	 * Apple's Safari browser performs some unsafe file type autodetection
+	 * which can cause legitimate files to be interpreted as HTML if the
+	 * web server is not correctly configured to send the right content-type
+	 * (or if you're really uploading plain text and octet streams!)
+	 *
+	 * Returns true if Safari would mistake the given file for HTML
+	 * when served with a generic content-type.
+	 *
+	 * @param string $filename
+	 * @return bool
+	 */
+	function triggersSafariBug( $filename ) {
+		$file = fopen( $filename, 'rb' );
+		$chunk = strtolower( fread( $file, 1024 ) );
+		fclose( $file );
+		
+		$tags = array(
+			'<html',
+			'<script',
+			'<title' );
+		foreach( $tags as $tag ) {
+			if( false !== strpos( $chunk, $tag ) ) {
+				return true;
+			}
+		}
+		return false;
+	}
+	
 }
 ?>
