@@ -24,8 +24,8 @@ require_once( "LanguageUtf8.php" );
 	NS_TALK				=> 'Diskussion',
 	NS_USER				=> 'Bruger',
 	NS_USER_TALK		=> 'Bruger_diskussion',
-	NS_WIKIPEDIA		=> $wgMetaNamespace,
-	NS_WIKIPEDIA_TALK	=> $wgMetaNamespace.'_diskussion',
+	NS_PROJECT			=> $wgMetaNamespace,
+	NS_PROJECT_TALK		=> $wgMetaNamespace.'_diskussion',
 	NS_IMAGE			=> 'Billede',
 	NS_IMAGE_TALK		=> 'Billede_diskussion',
 	NS_MEDIAWIKI		=> 'MediaWiki',
@@ -55,15 +55,6 @@ require_once( "LanguageUtf8.php" );
  "myskin" => "MySkin" 
 );
 
-/* private */ $wgMathNamesDa = array(
-	MW_MATH_PNG => "Vis altid som PNG",
-	MW_MATH_SIMPLE => "HTML hvis meget simpel ellers PNG",
-	MW_MATH_HTML => "HTML hvis muligt ellers PNG",
-	MW_MATH_SOURCE => "Lad være som TeX (for tekstbrowsere)",
-    MW_MATH_MODERN => "Anbefalet til moderne browsere",
-	MW_MATH_MATHML => "MathML hvis muligt",
-);
-
 /* private */ $wgDateFormatsDa = array(
 	"Ingen foretrukken",
 	"januar 15, 2001",
@@ -72,26 +63,6 @@ require_once( "LanguageUtf8.php" );
 	"2001-01-15"
 );
 
-/* private */ $wgUserTogglesDa = array(
-	"hover"		=> "Vis svævende tekst over wikihenvisninger",
-	"underline" => "Understreg henvisninger",
-	"highlightbroken" => "Brug røde henvisninger til tomme sider",
-	"justify"	=> "Justér afsnit",
-	"hideminor" => "Skjul mindre ændringer i seneste ændringer listen",
-	"usenewrc" => "Udvidet seneste ændringer liste<br>(ikke for alle browsere)",
-	"numberheadings" => "Automatisk nummerering af overskrifter",
-	"showtoolbar" => "Vis værktøjslinje til redigering",
-	"editondblclick" => "Redigér sider med dobbeltklik (JavaScript)",
-	"editsection"=>"Redigér afsnit ved hjælp af [redigér]-henvisning",
-	"editsectiononrightclick"=>"Redigér afsnit ved at højreklikke<br> på afsnittets titel (JavaScript)",
- 	"showtoc"=>"Vis indholdsfortegnelse<br>(for artikler med mere end tre afsnit)",
-	"rememberpassword" => "Husk adgangskode til næste besøg",
-	"editwidth" => "Redigeringsboksen har fuld bredde",
-	"watchdefault" => "Overvåg nye og ændrede artikler",
-	"minordefault" => "Markér som standard alle ændringer som mindre",
-	"previewontop" => "Vis forhåndsvisning før redigeringsboksen",
-	"nocache" => "Husk ikke siderne til næste besøg"
-);
 
 /* private */ $wgBookstoreListDa = array(
 	"Bibliotek.dk" => "http://bibliotek.dk/vis.php?base=dfa&origin=kommando&field1=ccl&term1=is=$1&element=L&start=1&step=10",
@@ -102,21 +73,6 @@ require_once( "LanguageUtf8.php" );
 	"Amazon.com" => "http://www.amazon.com/exec/obidos/ISBN=$1"
 );
 
-/* private */ $wgWeekdayNamesDa = array(
-	"søndag", "mandag", "tirsdag", "onsdag", "torsdag",
-	"fredag", "lørdag"
-);
-
-/* private */ $wgMonthNamesDa = array(
-	"januar", "februar", "marts", "april", "maj", "juni",
-	"juli", "august", "september", "oktober", "november",
-	"december"
-);
-
-/* private */ $wgMonthAbbreviationsDa = array(
-	"jan", "feb", "mar", "apr", "maj", "jun", "jul", "aug",
-	"sep", "okt", "nov", "dec"
-);
 
 # All special pages have to be listed here: a description of ""
 # will make them not show up on the "Special Pages" page, which
@@ -190,6 +146,62 @@ require_once( "LanguageUtf8.php" );
 
 
 /* private */ $wgAllMessagesDa = array(
+'special_version_prefix' => '',
+'special_version_postfix' => '',
+# User Toggles
+"tog-hover"		=> "Vis svævende tekst over wikihenvisninger",
+"tog-underline" => "Understreg henvisninger",
+"tog-highlightbroken" => "Brug røde henvisninger til tomme sider",
+"tog-justify"	=> "Justér afsnit",
+"tog-hideminor" => "Skjul mindre ændringer i seneste ændringer listen",
+"tog-usenewrc" => "Udvidet seneste ændringer liste<br />(ikke for alle browsere)",
+"tog-numberheadings" => "Automatisk nummerering af overskrifter",
+"tog-showtoolbar" => "Vis værktøjslinje til redigering",
+"tog-editondblclick" => "Redigér sider med dobbeltklik (JavaScript)",
+"tog-editsection"=>"Redigér afsnit ved hjælp af [redigér]-henvisning",
+"tog-editsectiononrightclick"=>"Redigér afsnit ved at højreklikke<br /> på afsnittets titel (JavaScript)",
+"tog-showtoc"=>"Vis indholdsfortegnelse<br />(for artikler med mere end tre afsnit)",
+"tog-rememberpassword" => "Husk adgangskode til næste besøg",
+"tog-editwidth" => "Redigeringsboksen har fuld bredde",
+"tog-watchdefault" => "Overvåg nye og ændrede artikler",
+"tog-minordefault" => "Markér som standard alle ændringer som mindre",
+"tog-previewontop" => "Vis forhåndsvisning før redigeringsboksen",
+"tog-nocache" => "Husk ikke siderne til næste besøg",
+
+# Dates
+
+'sunday' => 'søndag',
+'monday' => 'mandag',
+'tuesday' => 'tirsdag',
+'wednesday' => 'onsdag',
+'thursday' => 'torsdag',
+'friday' => 'fredag',
+'saturday' => 'lørdag',
+'january' => 'januar',
+'february' => 'februar',
+'march' => 'marts',
+'april' => 'april',
+'may_long' => 'maj',
+'june' => 'juni',
+'july' => 'juli',
+'august' => 'august',
+'september' => 'september',
+'october' => 'oktober',
+'november' => 'november',
+'december' => 'december',
+'jan' => 'jan',
+'feb' => 'feb',
+'mar' => 'mar',
+'apr' => 'apr',
+'may' => 'maj',
+'jun' => 'jun',
+'jul' => 'jul',
+'aug' => 'aug',
+'sep' => 'sep',
+'oct' => 'okt',
+'nov' => 'nov',
+'dec' => 'dec',
+
 
 # Bits of text used by many pages:
 #
@@ -202,7 +214,7 @@ require_once( "LanguageUtf8.php" );
 "mainpage"		=> "Forside",
 "mainpagetext"	=> "Wiki-software er nu installeret.",
 "about"			=> "Om",
-"aboutwikipedia" => "Om Wikipedia",
+"aboutsite"      => "Om Wikipedia",
 "aboutpage"		=> "Wikipedia:Om",
 "help"			=> "Hjælp",
 "helppage"		=> "Wikipedia:Hjælp",
@@ -227,7 +239,7 @@ require_once( "LanguageUtf8.php" );
 "currentevents" => "Aktuelle begivenheder",
 "errorpagetitle" => "Fejl",
 "returnto"		=> "Tilbage til $1.",
-"fromwikipedia"	=> "Fra Wikipedia, den frie encyklopædi",
+"tagline"      	=> "Fra Wikipedia, den frie encyklopædi",
 "whatlinkshere"	=> "Sider med en henvisning hertil",
 "help"			=> "Hjælp",
 "search"		=> "Søg",
@@ -290,8 +302,6 @@ kan genkendes af Wikipediasoftwaren.",
 "error"			=> "Fejl",
 "databaseerror" => "Databasefejl",
 "dberrortext"	=> "Der er sket en syntaksfejl i en databaseforespørgsel.
-Dette kan være på grund af en illegal forespørgsel (se $5),
-eller det kan betyde en fejl i softwaren.
 Den sidst forsøgte databaseforespørgsel var:
 <blockquote><tt>$1</tt></blockquote>
 fra funktionen \"<tt>$2</tt>\".
@@ -354,9 +364,9 @@ oprettet. Glem ikke at personliggøre dine Wikipedia-indstillinger.",
 "newusersonly"	=> " (kun nye brugere)",
 "remembermypassword" => "Husk min adgangskode til næste gang.",
 "loginproblem"	=> "<b>Der har været et problem med at få dig logget  
-på.</b><br>Prøv igen!",
+på.</b><br />Prøv igen!",
 "alreadyloggedin" => "<font color=red><b>Bruger $1, du er allerede logget 
-på!</b></font><br>\n",
+på!</b></font><br />\n",
 
 "login"			=> "Log på",
 "userlogin"		=> "Log på",
@@ -402,16 +412,16 @@ Du bør logge på og ændre din adgangskode straks efter, du har modtaget den.",
 "showpreview"	=> "Forhåndsvisning",
 "blockedtitle"	=> "Brugeren er blokeret",
 "blockedtext"	=> "Dit brugernavn eller din IP-adresse er blevet blokeret af 
-$1. Begrundelsen er denne:<br>$2<p>Du kan kontakte $1
+$1. Begrundelsen er denne:<br />$2<p>Du kan kontakte $1
 eller en af de andre [[Wikipedia:Administratorer|administratorer]] for at diskutere blokeringen.
 
 Din IP-adresse er $3.
 Sørg venligst for at inkludere dette nummer i alle henvendelser til en administrator.
 ",
 "newarticle"	=> "(Ny)",
-"newarticletext" => "Der er på nuværende tidspunkt ingen tekst på denne side.<br>
+"newarticletext" => "Der er på nuværende tidspunkt ingen tekst på denne side.<br />
 Du kan begynde en artikel ved at skrive i boksen herunder. 
-(se [[Wikipedia:Hjælp|hjælpen]] for yderligere information).<br>
+(se [[Wikipedia:Hjælp|hjælpen]] for yderligere information).<br />
 Hvis det ikke var din mening, så tryk på '''Tilbage''' eller '''Back''' knappen.",
 "anontalkpagetext" => "---- ''Dette er en diskussionsside for en anonym bruger der 
 ikke har oprettet en konto endnu eller ikke bruger den. Vi er derfor nødt til at 
@@ -430,8 +440,8 @@ gemt endnu!",
 redigérbare tekst ovenfor,
 sådan vil det komme til at se ud hvis du vælger at gemme teksten.",
 "editing"		=> "Redigerer $1",
-"sectionedit"	=> " (afsnit)",
-"commentedit"	=> " (kommentar)",
+"editingsection"	=> "Redigerer $1 (afsnit)",
+"editingcomment"	=> "Redigerer $1 (kommentar)",
 "editconflict"	=> "Redigeringskonflikt: $1",
 "explainconflict" => "Nogen har ændret denne side, efter du
 startede på at redigere den.
@@ -451,7 +461,7 @@ overskrevet.</strong>\n",
 at betragte som udgivet under GNU Free Documentation License
 (se $1 for detaljer).
 Hvis du ikke vil have din tekst redigeret uden nåde og kopieret efter
-forgodtbefindene, så skal du ikke lægge det her.<br>
+forgodtbefindene, så skal du ikke lægge det her.<br />
 Du lover os også, at du skrev teksten selv, kopierede fra en
 public domain eller lignende fri ressource.
 <strong>LÆG ALDRIG MATERIALE HER SOM ER BESKYTTET AF ANDRES OPHAVSRET UDEN 
@@ -494,9 +504,7 @@ version, (forrige) = forskel til den forrige version, M = mindre ændring",
 # Search results
 #
 "searchresults" => "Søgeresultater",
-"searchhelppage" => "Wikipedia:Søgning",
-"searchingwikipedia" => "Søgning på Wikipedia",
-"searchresulttext" => "For mere information om søgning på Wikipedia, se $1.",
+"searchresulttext" => "For mere information om søgning på {{SITENAME}}, se [[Project:Søgning|Søgning på {{SITENAME}}]].",
 "searchquery"	=> "For forespørgsel \"$1\"",
 "badquery"		=> "Forkert udformet forespørgsel",
 "badquerytext"	=> "Vi kunne ikke udføre din forespørgsel.
@@ -525,34 +533,13 @@ der ikke er indekseret, eller ved at specificere mere end et søgeord (da kun
 sider der indeholder alle søgeordene vil blive fundet).",
 "powersearch" => "Søg",
 "powersearchtext" => "
-Søg i navnerum :<br>
-$1<br>
+Søg i navnerum :<br />
+$1<br />
 $2 List omdirigeringer &nbsp; Søg efter $3 $9",
 "searchdisabled" => "<p>Søgefunktionen er midlertidigt afbrudt på grund af
 for stort pres på serveren; vi håber vi kan sætte den på igen når vi har
 opgraderet softwaren. I mellemtiden kan du søge via google:</p>
                                                                                                                                                         
-",
-"googlesearch" => "<!-- SiteSearch Google -->
-<FORM method=GET action=\"http://www.google.com/search\">
-<TABLE bgcolor=\"#FFFFFF\"><tr><td>
-<A HREF=\"http://www.google.com/\">
-<IMG SRC=\"http://www.google.com/logos/Logo_40wht.gif\"
-border=\"0\" ALT=\"Google\"></A>
-</td>
-<td>
-<INPUT TYPE=text name=q size=31 maxlength=255 value=\"$1\">
-<INPUT type=submit name=btnG VALUE=\"Google Search\">
-<font size=-1>
-<input type=hidden name=domains value=\"{$wgServer}\"><br><input type=radio
-name=sitesearch value=\"\"> WWW <input type=radio name=sitesearch
-value=\"{$wgServer}\" checked> {$wgServer} <br>
-<input type='hidden' name='ie' value='$2'>
-<input type='hidden' name='oe' value='$2'>
-</font>
-</td></tr></TABLE>
-</FORM>
-<!-- SiteSearch Google -->
 ",
 "blanknamespace" => "(Hoved)",
 
@@ -561,7 +548,7 @@ value=\"{$wgServer}\" checked> {$wgServer} <br>
 "preferences"	=> "Indstillinger",
 "prefsnologin" => "Ikke logget på",
 "prefsnologintext"	=> "Du skal være <a href=\"" .
-  wfLocalUrl( "Speciel:Userlogin" ) . "\">logget på</a>
+  "{{localurle:Speciel:Userlogin}}\">logget på</a>
 for at ændre brugerindstillinger.",
 "prefslogintext" => "Du logget på som \"$1\".
 Dit interne ID-nummer er $2.
@@ -637,20 +624,20 @@ sidste <strong>$2</strong> dage.",
 "reuploaddesc"	=> "Tilbage til formularen til at lægge filer op.",
 "uploadnologin" => "Ikke logget på",
 "uploadnologintext"	=> "Du skal være <a href=\"" .
-  wfLocalUrl( "Speciel:Userlogin" ) . "\">logget på</a>
+  "{{localurle:Speciel:Userlogin}}\">logget på</a>
 for at kunne lægge filer op.",
 "uploadfile"	=> "Læg filen op",
 "uploaderror"	=> "Fejl under oplægning af fil",
-"uploadtext"	=> "<strong>STOP!</strong> Før du lægger filer op her,
-så vær sikker på du har læst og følger Wikipedias <a href=\"" .
-wfLocalUrlE( "Wikipedia:Politik om brug af billeder" ) . "\">politik om brug 
-af billeder</a>.
-<p>For at se eller søge i billeder, som tidligere er lagt op,
-gå til <a href=\"" . wfLocalUrlE( "Speciel:Imagelist" ) .
-"\">listen over billeder</a>.
-Oplægning og sletninger er registreret i <a href=\"" .
-wfLocalUrlE( "Wikipedia:Upload_log" ) . "\">log over oplagte filer</a>.
-<p>Brug formularen herunder til at lægge nye billeder op, der kan bruges
+"uploadtext"	=> "'''STOP!''' Før du lægger filer op her,
+så vær sikker på du har læst og følger Wikipedias
+[[Project:Politik om brug af billeder|politik om brug af billeder]].
+
+For at se eller søge i billeder, som tidligere er lagt op,
+gå til [[Speciel:Imagelist|listen over billeder]].
+Oplægning og sletninger er registreret i
+[[Project:Upload_log|log over oplagte filer]].
+
+Brug formularen herunder til at lægge nye billeder op, der kan bruges
 som illustration i dine artikler.
 På de fleste browsere vil du se en \"Browse...\" knap eller en 
 \"Gennemse...\" knap, som vil
@@ -661,14 +648,17 @@ Du skal også verificere, at du ikke er ved at bryde nogens ophavsret.
 Det gør du ved at sætte et mærke i checkboksen.
 Tryk på \"Læg op\"-knappen for at lægge filen op.
 Dette kan godt tage lidt tid hvis du har en langsom internetforbindelse.
-<p>De foretrukne formater er JPEG til fotografiske billeder, PNG
+
+De foretrukne formater er JPEG til fotografiske billeder, PNG
 til tegninger og andre små billeder, og OGG til lyd.
 Sørg for at navngive din fil med et beskrivende navn for at undgå 
 forvirring om indholdet.
 For at bruge billedet i en artikel, så brug et link af denne slags
-<b>[[billede:fil.jpg]]</b> eller <b>[[billede:fil.png|alternativ tekst]]</b>
-eller <b>[[media:fil.ogg]]</b> for lyd.
-<p>Læg mærke til at præcis som med Wikipedia-sider, så kan og må andre gerne 
+'''<nowiki>[[billede:fil.jpg]]</nowiki>''' eller
+'''<nowiki>[[billede:fil.png|alternativ tekst]]</nowiki>''' eller
+'''<nowiki>[[media:fil.ogg]]</nowiki>''' for lyd.
+
+Læg mærke til at præcis som med Wikipedia-sider, så kan og må andre gerne 
 redigere eller
 slette de filer, du har lagt op, hvis de mener det hjælper encyklopædien, og
 du kan blive blokeret fra at lægge op hvis du misbruger systemet.",
@@ -676,8 +666,6 @@ du kan blive blokeret fra at lægge op hvis du misbruger systemet.",
 "uploadlogpage" => "Upload_log",
 "uploadlogpagetext" => "Herunder er der en liste med de filer, som er lagt 
 op senest. Alle de viste tider er serverens tid (UTC).
-<ul>
-</ul>
 ",
 "filename"		=> "Filnavn",
 "filedesc"		=> "Beskrivelse",
@@ -724,7 +712,7 @@ og af hvem, og andre ting du ved om filen.",
 "deleteimgcompletely"		=> "slet",
 "imghistlegend" => "Forklaring: (nuværende) = dette er det nuværende billede, 
 (slet) = slet denne gamle version, (gendan) = gendan en gammel version.
-<br><i>Klik på en dato for at se billedet, som er lagt op den dag</i>.",
+<br /><i>Klik på en dato for at se billedet, som er lagt op den dag</i>.",
 "imagelinks"	=> "Billedehenvisninger",
 "linkstoimage"	=> "De følgende sider henviser til dette billede:",
 "nolinkstoimage" => "Der er ingen sider der henviser til dette billede.",
@@ -759,12 +747,12 @@ hver gang du har rettet en enkelt ting ;-)",
 "disambiguationspage"	=> "Wikipedia:Henvisninger til artikler med flertydige titler",
 "disambiguationstext"	=> "De følgende artikler henviser til 
 <i>artikler med flertydige titler</i>. De skulle henvise til en ikke-flertydig 
-titel i stedet for.<br>En artikel bliver behandlet som flertydig, hvis den er
-henvist fra $1.<br>Henvisninger fra andre navnerum er <i>ikke</i> listet her.",
+titel i stedet for.<br />En artikel bliver behandlet som flertydig, hvis den er
+henvist fra $1.<br />Henvisninger fra andre navnerum er <i>ikke</i> listet her.",
 "doubleredirects"	=> "Dobbelte omdirigeringer",
 "doubleredirectstext"	=> "<b>Bemærk:</b> Denne liste kan indeholde forkerte 
 resultater. Det er som regel, fordi siden indeholder ekstra tekst under den
-første #REDIRECT.<br>\nHver linje indeholder henvisninger til den første og den 
+første #REDIRECT.<br />\nHver linje indeholder henvisninger til den første og den 
 anden omdirigering, og den første linje fra den anden omdirigeringstekst, 
 det giver som regel den \"rigtige\" målartikel, som den første omdirigering 
 skulle have peget på.",
@@ -815,7 +803,7 @@ henvisning til den samme artikel i $1. Omdirigeringer og underartikler er
 "unusedimagestext" => "<p>Læg mærke til, at andre websider
 såsom de andre internationale Wikipediaer måske henviser til et billede med
 en direkte URL, så det kan stadig være listet her, selvom det er
-i aktivt brug.",
+i aktivt brug.</p>",
 "booksources"	=> "Bogkilder",
 "booksourcetext" => "Herunder er en liste af henvisninger til steder der
 udlåner og/eller sælger nye og brugte bøger, og som måske også har 
@@ -828,9 +816,9 @@ og denne liste skal ikke ses som en anbefaling af disse.",
 #
 "mailnologin"	=> "Ingen afsenderadresse",
 "mailnologintext" => "Du skal være <a href=\"" .
-  wfLocalUrl( "Speciel:Userlogin" ) . "\">logget på</a>
+  "{{localurle:Speciel:Userlogin}}\">logget på</a>
 og have en gyldig e-mailadresse sat i dine <a href=\"" .
-  wfLocalUrl( "Speciel:Preferences" ) . "\">indstillinger</a>
+  "{{localurle:Speciel:Preferences}}\">indstillinger</a>
 for at sende e-mail til andre brugere.",
 "emailuser"		=> "E-mail til denne bruger",
 "emailpage"		=> "E-mail bruger",
@@ -857,14 +845,14 @@ eller har valgt ikke at modtage e-mail fra andre brugere.",
 "nowatchlist"	=> "Du har ingenting i din overvågningsliste.",
 "watchnologin"	=> "Ikke logget på",
 "watchnologintext"	=> "Du skal være <a href=\"" .
-  wfLocalUrl( "Speciel:Userlogin" ) . "\">logget på</a>
+  "{{localurle:Speciel:Userlogin}}\">logget på</a>
 for at kunne ændre din overvågningsliste.",
 "addedwatch"	=> "Tilføjet til din overvågningsliste",
 "addedwatchtext" => "Siden \"$1\" er blevet tilføjet til din <a href=\"" .
-  wfLocalUrl( "Speciel:Watchlist" ) . "\">overvågningsliste</a>.
+  "{{localurle:Speciel:Watchlist}}\">overvågningsliste</a>.
 Fremtidige ændringer til denne side og den tilhørende diskussionsside vil 
 blive listet her, og siden vil fremstå <b>fremhævet</b> i <a href=\"" .
-  wfLocalUrl( "Speciel:Recentchanges" ) . "\">listen med de seneste 
+  "{{localurle:Speciel:Recentchanges}}\">listen med de seneste 
 ændringer</a> for at gøre det lettere at finde den.</p>
 
 <p>Hvis du senere vil fjerne siden fra din overvågningsliste, så klik 
@@ -917,8 +905,6 @@ Se $2 for en fortegnelse over de nyeste sletninger.",
 "dellogpage"	=> "Sletningslog",
 "dellogpagetext" => "Herunder er en liste over de nyeste sletninger.
 Alle tider er serverens tid (UTC).
-<ul>
-</ul>
 ",
 "deletionlog"	=> "sletningslog",
 "reverted"		=> "Gendannet en tidligere version",
@@ -941,8 +927,8 @@ Den seneste redigering er foretaget af [[Bruger:$3|$3]] ([[Bruger diskussion:$3|
 "protectlogpage" => "Liste_over_beskyttede_sider",
 "protectlogtext" => "Herunder er en liste over sider der er blevet beskyttet/har fået fjernet beskyttelsen.
 Se [[Wikipedia:Beskyttet side]] for mere information.",
-"protectedarticle" => "beskyttet [[:$1]]",
-"unprotectedarticle" => "fjernet beskyttelse [[:$1]]",
+"protectedarticle" => "beskyttet $1",
+"unprotectedarticle" => "fjernet beskyttelse $1",
 
 # Undelete
 "undelete" => "Gendan en slettet side",
@@ -1001,7 +987,7 @@ sider der har været udsat for vandalisme).",
 "noblockreason" => "Du skal angive en begrundelse for denne blokering.",
 "blockipsuccesssub" => "Blokering udført med success",
 "blockipsuccesstext" => "\"$1\" er blevet blokeret.
-<br>Se [[Speciel:Ipblocklist|IP blokeringslisten]] for alle blokeringer.",
+<br />Se [[Speciel:Ipblocklist|IP blokeringslisten]] for alle blokeringer.",
 "unblockip"		=> "Ophæv blokering af bruger",
 "unblockiptext"	=> "Brug formularen herunder for at gendanne skriveadgangen
 for en tidligere blokeret IP-adresse eller bruger.",
@@ -1035,7 +1021,7 @@ Bekræft venligst at du har til hensigt at gøre dette.",
 "lockdbsuccesssub" => "Databasen er nu låst",
 "unlockdbsuccesssub" => "Databasen er nu låst op",
 "lockdbsuccesstext" => "Wikipediadatabasen er låst.
-<br>Husk at fjerne låsen når du er færdig med din vedligeholdelse.",
+<br />Husk at fjerne låsen når du er færdig med din vedligeholdelse.",
 "unlockdbsuccesstext" => "Wikipediadatabasen er låst op.",
 
 # SQL query
@@ -1083,7 +1069,7 @@ I disse tilfælde er du nødt til at flytte eller sammenflette siden manuelt.",
 "movearticle"	=> "Flyt side",
 "movenologin"	=> "Ikke logget på",
 "movenologintext" => "Du skal være registreret bruger og være <a href=\"" .
-  wfLocalUrl( "Speciel:Userlogin" ) . "\">logget på</a>
+  "{{localurle:Speciel:Userlogin}}\">logget på</a>
 for at flytte en side.",
 "newtitle"		=> "Til ny titel",
 "movepagebtn"	=> "Flyt side",
@@ -1099,16 +1085,18 @@ med den nye titel. Du er nødt til at flette dem sammen manuelt.",
 "talkpagemoved" => "Den tilhørende diskussionsside blev også flyttet.",
 "talkpagenotmoved" => "Den tilhørende diskussionsside blev 
 <strong>ikke</strong> flyttet.",
+# Math
+	'mw_math_png' => "Vis altid som PNG",
+	'mw_math_simple' => "HTML hvis meget simpel ellers PNG",
+	'mw_math_html' => "HTML hvis muligt ellers PNG",
+	'mw_math_source' => "Lad være som TeX (for tekstbrowsere)",
+        'mw_math_modern' => "Anbefalet til moderne browsere",
+	'mw_math_mathml' => "MathML hvis muligt",
 
 );
 
 class LanguageDa extends LanguageUtf8 {
 
-        function getDefaultUserOptions () {
-                $opt = Language::getDefaultUserOptions();
-                return $opt;
-                }
-
 	function getBookstoreList () {
 		global $wgBookstoreListDa ;
 		return $wgBookstoreListDa ;
@@ -1133,10 +1121,6 @@ class LanguageDa extends LanguageUtf8 {
 		return false;
 	}
 
-	function specialPage( $name ) {
-		return $this->getNsText( Namespace::getSpecial() ) . ":" . $name;
-	}
-
 	function getQuickbarSettings() {
 		global $wgQuickbarSettingsDa;
 		return $wgQuickbarSettingsDa;
@@ -1147,44 +1131,11 @@ class LanguageDa extends LanguageUtf8 {
 		return $wgSkinNamesDa;
 	}
 
-	function getMathNames() {
-		global $wgMathNamesDa;
-		return $wgMathNamesDa;
-	}
-
 	function getDateFormats() {
 		global $wgDateFormatsDa;
 		return $wgDateFormatsDa;
 	}
 
-	function getUserToggles() {
-		global $wgUserTogglesDa;
-		return $wgUserTogglesDa;
-	}
-
-	function getMonthName( $key ) {
-		global $wgMonthNamesDa;
-		return $wgMonthNamesDa[$key-1];
-	}
-
-	/* by default we just return base form */
-	function getMonthNameGen( $key ) {
-		global $wgMonthNamesDa;
-		return $wgMonthNamesDa[$key-1];
-	}
-
-	function getMonthAbbreviation( $key ) {
-		global $wgMonthAbbreviationsDa;
-		return $wgMonthAbbreviationsDa[$key-1];
-	}
-
-	function getWeekdayName( $key ) {
-		global $wgWeekdayNamesDa;
-		return $wgWeekdayNamesDa[$key-1];
-	}
-
-	# Inherit userAdjust()
-
 	function date( $ts, $adj = false ) {
 		if ( $adj ) { $ts = $this->userAdjust( $ts ); }
 
@@ -1194,19 +1145,10 @@ class LanguageDa extends LanguageUtf8 {
 		return $d;
 	}
 
-	function time( $ts, $adj = false ) {
-		if ( $adj ) { $ts = $this->userAdjust( $ts ); }
-
-		$t = substr( $ts, 8, 2 ) . ":" . substr( $ts, 10, 2 );
-		return $t;
-	}
-
 	function timeanddate( $ts, $adj = false ) {
 		return $this->date( $ts, $adj ) . " kl. " . $this->time( $ts, $adj );
 	}
 
-	# Inherit rfc1123()
-
 	function getValidSpecialPages() {
 		global $wgValidSpecialPagesDa;
 		return $wgValidSpecialPagesDa;
@@ -1224,30 +1166,17 @@ class LanguageDa extends LanguageUtf8 {
 
 	function getMessage( $key ) {
 		global $wgAllMessagesDa;
-		if( isset( $wgAllMessagesDa[$key] ) )
+		if( isset( $wgAllMessagesDa[$key] ) ) {
 			return $wgAllMessagesDa[$key];
-		return "";
+		} else {
+			return Language::getMessage( $key );
+		}
 	}
 
-	# Inherit iconv()
-
-	# Inherit ucfirst()
-
-	# Inherit lcfirst()
-	
-	# Inherit checkTitleEncoding()
-	
-	# Inherit stripForSearch()
-	
-	# Inherit setAltEncoding()
-	
-	# Inherit recodeForEdit()
-	
-	# Inherit recodeInput()
-
-	# Inherit isRTL()
-	
-	# Inherit getMagicWords()
+	function formatNum( $number ) {
+		global $wgTranslateNumerals;
+		return $wgTranslateNumerals ? strtr($number, '.,', ',.' ) : $number;
+	}
 
 }
 
