@@ -1,126 +1,82 @@
 <?php
 
-// $Id: LanguageFr.php,v 1.58.2.8 2004/11/04 02:42:06 vibber Exp $
-
 // The names of the namespaces can be set here, but the numbers
 // are magical, so don't change or move them!  The Namespace class
 // encapsulates some of the magic-ness.
 require_once( "LanguageUtf8.php" );
 
 /* private */ $wgNamespaceNamesFr = array(
-	NS_MEDIA		=> "Media",
-	NS_SPECIAL		=> "Special",
-	NS_MAIN			=> "",
-	NS_TALK			=> "Discuter",
-	NS_USER			=> "Utilisateur",
+	NS_MEDIA			=> "Media",
+	NS_SPECIAL			=> "Special",
+	NS_MAIN				=> "",
+	NS_TALK				=> "Discuter",
+	NS_USER				=> "Utilisateur",
 	NS_USER_TALK		=> "Discussion_Utilisateur",
-	NS_WIKIPEDIA		=> $wgMetaNamespace,
-	NS_WIKIPEDIA_TALK	=> "Discussion_".$wgMetaNamespace,
-	NS_IMAGE		=> "Image",
+	NS_PROJECT			=> $wgMetaNamespace,
+	NS_PROJECT_TALK		=> "Discussion_".$wgMetaNamespace,
+	NS_IMAGE			=> "Image",
 	NS_IMAGE_TALK		=> "Discussion_Image",
 	NS_MEDIAWIKI		=> "MediaWiki",
 	NS_MEDIAWIKI_TALK	=> "Discussion_MediaWiki",
-	NS_TEMPLATE		=> "Modèle",
+	NS_TEMPLATE			=> "Modèle",
 	NS_TEMPLATE_TALK	=> "Discussion_Modèle",
-	NS_HELP			=> "Aide",
+	NS_HELP				=> "Aide",
 	NS_HELP_TALK		=> "Discussion_Aide",
-	NS_CATEGORY		=> "Catégorie",
+	NS_CATEGORY			=> "Catégorie",
 	NS_CATEGORY_TALK	=> "Discussion_Catégorie"
 ) + $wgNamespaceNamesEn;
 
 /* private */ $wgQuickbarSettingsFr = array(
-	"Aucune", "Gauche", "Droite", "Flottante à gauche"
+	'Aucune', 'Gauche', 'Droite', 'Flottante à gauche'
 );
 
 /* private */ $wgSkinNamesFr = array(
-	'standard' => "Standard",
-	'nostalgia' => "Nostalgie",
-	'cologneblue' => "Cologne Blue",
-	'smarty' => "Paddington",
-	'montparnasse' => "Montparnasse",
-	'davinci' => "DaVinci",
-	'mono' => "Mono",
-	'monobook' => "MonoBook",
- "myskin" => "MySkin" 
+	'standard'		=> 'Standard',
+	'nostalgia'		=> 'Nostalgie',
+	'cologneblue'	=> 'Cologne Blue',
+	'smarty'		=> 'Paddington',
+	'montparnasse'	=> 'Montparnasse',
+	'davinci'		=> 'DaVinci',
+	'mono'			=> 'Mono',
+	'monobook'		=> 'MonoBook',
+	'myskin'		=> 'MySkin'
 );
 
-/* private */ $wgMathNamesFr = array(
-	"Toujours produire une image PNG",  
-	"HTML si très simple, autrement PNG", 
-	"HTML si possible, autrement PNG", 
-	"Laisser le code TeX original",
-	"Pour les navigateurs modernes"
-);
 
-/* private */ $wgUserTogglesFr = array(
-	"hover"  => "Afficher des info-bulles sur les liens wiki",
-	"underline" => "Liens soulignés",
-	"highlightbroken" => "Liens vers les sujets non existants en rouge",
-	"justify" => "Paragraphes justifiés",
-	"hideminor" => "Cacher les <i>Modifications récentes</i> mineures",
-	"usenewrc" => "Modifications récentes améliorées<br /> (certains navigateurs seulement)",
-	"numberheadings" => "Numérotation automatique des titres",
-	"showtoolbar" => "Show edit toolbar",
-	"editondblclick" => "Double cliquer pour éditer une page (JavaScript)",
-	"editsection"	=> "Éditer une section via les liens [éditer]",
-	"editsectiononrightclick"	=> "Éditer une section en cliquant à droite<br /> sur le titre de la section",
-	"showtoc"	=> "Afficher la table des matières<br /> (pour les articles ayant plus de 3 sections)",
-	"rememberpassword" => "Se souvenir de mon mot de passe (cookie)",
-	"editwidth" => "La fenêtre d'édition s'affiche en pleine largeur",
-	"watchdefault" => "Suivre les articles que je crée ou modifie",
-	"minordefault" => "Mes modifications sont considérées<br /> comme mineures par défaut",
-	"previewontop" => "La prévisualisation s'affiche au<br /> dessus de la boite de rédaction",
-	"nocache" => "Désactiver le cache des pages"
-);
 
 /* private */ $wgBookstoreListFr = array(
-	"Amazon.fr" => "http://www.amazon.fr/exec/obidos/ISBN=$1",
-	"alapage.fr"	=> "http://www.alapage.com/mx/?tp=F&type=101&l_isbn=$1&donnee_appel=ALASQ&devise=&",
-	"fnac.com"	=> "http://www3.fnac.com/advanced/book.do?isbn=$1",
-	"chapitre.com"	=> "http://www.chapitre.com/frame_rec.asp?isbn=$1",
+	'Amazon.fr'		=> "http://www.amazon.fr/exec/obidos/ISBN=$1",
+	'alapage.fr'	=> "http://www.alapage.com/mx/?tp=F&type=101&l_isbn=$1&donnee_appel=ALASQ&devise=&",
+	'fnac.com'		=> "http://www3.fnac.com/advanced/book.do?isbn=$1",
+	'chapitre.com'	=> "http://www.chapitre.com/frame_rec.asp?isbn=$1",
 );
 
-/* private */ $wgWeekdayNamesFr = array(
-	"dimanche", "lundi", "mardi", "mercredi", "jeudi",
-	"vendredi", "samedi"
-);
-
-/* private */ $wgMonthNamesFr = array(
-	"janvier", "février", "mars", "avril", "mai", "juin",
-	"juillet", "août", "septembre", "octobre", "novembre",
-	"décembre"
-);
-
-/* private */ $wgMonthAbbreviationsFr = array(
-	"jan", "fév", "mar", "avr", "mai", "jun", "jul", "aoû",
-	"sep", "oct", "nov", "déc"
-);
 
 // All special pages have to be listed here: a description of ""
 // will make them not show up on the "Special Pages" page, which
 // is the right thing for some of them (such as the "targeted" ones).
 
 /* private */ $wgValidSpecialPagesFr = array(
-	"Userlogin"     => "",
-	"Userlogout"    => "",
-	"Preferences"   => "Préférences",
-	"Watchlist"     => "Liste de suivi",
-	"Recentchanges" => "Modifications récentes",
-	"Upload"        => "Copier un fichier",
-	"Imagelist"     => "Liste des images",
-	"Listusers"     => "Liste des participants",
-	"Statistics"    => "Statistiques",
-	"Randompage"    => "Une page au hasard",
+	'Userlogin'     => '',
+	'Userlogout'    => '',
+	'Preferences'   => 'Préférences',
+	'Watchlist'     => 'Liste de suivi',
+	'Recentchanges' => 'Modifications récentes',
+	'Upload'        => 'Copier un fichier',
+	'Imagelist'     => 'Liste des images',
+	'Listusers'     => 'Liste des participants',
+	'Statistics'    => 'Statistiques',
+	'Randompage'    => 'Une page au hasard',
 
-	"Lonelypages"   => "Pages orphelines",
-	"Unusedimages"  => "Images orphelines",
-	"Popularpages"  => "Les plus populaires",
-	"Wantedpages"   => "Les plus demandées",
-	"Shortpages"    => "Articles courts",
-	"Longpages"     => "Articles longs",
-	"Newpages"      => "Nouvelles pages",
-	"Ancientpages"	=> "Anciennes pages",
-	"Allpages"      => "Toutes les pages",
+	'Lonelypages'   => 'Pages orphelines',
+	'Unusedimages'  => 'Images orphelines',
+	'Popularpages'  => 'Les plus populaires',
+	'Wantedpages'   => 'Les plus demandées',
+	'Shortpages'    => 'Articles courts',
+	'Longpages'     => 'Articles longs',
+	'Newpages'      => 'Nouvelles pages',
+	'Ancientpages'	=> 'Anciennes pages',
+	'Allpages'      => 'Toutes les pages',
 
 	"Ipblocklist"   => "Adresses IP bloquées",
 	"Maintenance"   => "Page de maintenance",
@@ -140,10 +96,10 @@ require_once( "LanguageUtf8.php" );
 /* private */ $wgSysopSpecialPagesFr = array(
 	"Blockip"       => "Bloquer une adresse IP",
 	"Asksql"        => "Accès SQL",
-	"Makesysop"	=> "Donner les droits d'administrateur",
+	"Makesysop"		=> "Donner les droits d'administrateur",
 
 	"Undelete"      => "Gérer les pages effacées",
-	"Import"	=> "Importer une page avec l'historique"
+	"Import"		=> "Importer une page avec l'historique"
 );
 
 /* private */ $wgDeveloperSpecialPagesFr = array(
@@ -152,6 +108,63 @@ require_once( "LanguageUtf8.php" );
 );
 
 /* private */ $wgAllMessagesFr = array(
+'special_version_prefix' => '',
+'special_version_postfix' => '',
+
+# User Toggles
+
+"tog-hover" => "Afficher des info-bulles sur les liens wiki",
+"tog-underline" => "Liens soulignés",
+"tog-highlightbroken" => "Liens vers les sujets non existants en rouge",
+"tog-justify" => "Paragraphes justifiés",
+"tog-hideminor" => "Cacher les <i>Modifications récentes</i> mineures",
+"tog-usenewrc" => "Modifications récentes améliorées<br /> (certains navigateurs seulement)",
+"tog-numberheadings" => "Numérotation automatique des titres",
+"tog-showtoolbar" => "Show edit toolbar",
+"tog-editondblclick" => "Double cliquer pour éditer une page (JavaScript)",
+"tog-editsection"	=> "Éditer une section via les liens [éditer]",
+"tog-editsectiononrightclick"	=> "Éditer une section en cliquant à droite<br /> sur le titre de la section",
+"tog-showtoc"	=> "Afficher la table des matières<br /> (pour les articles ayant plus de 3 sections)",
+"tog-rememberpassword" => "Se souvenir de mon mot de passe (cookie)",
+"tog-editwidth" => "La fenêtre d'édition s'affiche en pleine largeur",
+"tog-watchdefault" => "Suivre les articles que je crée ou modifie",
+"tog-minordefault" => "Mes modifications sont considérées<br /> comme mineures par défaut",
+"tog-previewontop" => "La prévisualisation s'affiche au<br /> dessus de la boite de rédaction",
+"tog-nocache" => "Désactiver le cache des pages",
+# Dates
+
+'sunday' => "dimanche",
+'monday' => "lundi",
+'tuesday' => "mardi",
+'wednesday' => "mercredi",
+'thursday' => "jeudi",
+'friday' => "vendredi",
+'saturday' => "samedi",
+'january' => "janvier",
+'february' => "février",
+'march' => "mars",
+'april' => "avril",
+'may_long' => "mai",
+'june' => "juin",
+'july' => "juillet",
+'august' => "août",
+'september' => "septembre",
+'october' => "octobre",
+'november' => "novembre",
+'december' => "décembre",
+'jan' => "jan",
+'feb' => "fév",
+'mar' => "mar",
+'apr' => "avr",
+'may' => "mai",
+'jun' => "jun",
+'jul' => "jul",
+'aug' => "aoû",
+'sep' => "sep",
+'oct' => "oct",
+'nov' => "nov",
+'dec' => "déc",
+
 
 # Bits of text used by many pages:
 #
@@ -161,13 +174,13 @@ require_once( "LanguageUtf8.php" );
 "subcategories"	=> "Sous-catégories", // Looxix "Subcategories",
 
 
-"linktrail"     => "/^([a-zàâçéèêîôû]+)(.*)\$/sD",
+"linktrail"     => "/^([a-zàâçéèêîôûäëïöüùÇÉÂÊÎÔÛÄËÏÖÜÀÈÙ]+)(.*)$/sD",
 "mainpage"      => "Accueil",
 "mainpagetext"	=> "Logiciel {{SITENAME}} installé.",
 "portal"	=> "Accueil communauté",
 "portal-url"	=> "{{ns:4}}:Accueil",
 "about"         => "À propos",
-"aboutwikipedia" => "À propos de {{SITENAME}}",
+"aboutsite"      => "À propos de {{SITENAME}}",
 "aboutpage"     => "{{ns:4}}:À propos",
 "article"	=> "Article",
 "help"          => "Aide",
@@ -199,7 +212,7 @@ require_once( "LanguageUtf8.php" );
 "disclaimerpage" => "{{ns:4}}:Avertissements généraux",
 "errorpagetitle" => "Erreur",
 "returnto"      => "Revenir à la page $1.",
-"fromwikipedia" => "Un article de {{SITENAME}}, l'encyclopéde libre.",
+"tagline"       => "Un article de {{SITENAME}}, l'encyclopéde libre.",
 "whatlinkshere" => "Références à cette page",
 "help"          => "Aide",
 "search"        => "Rechercher",
@@ -219,6 +232,7 @@ require_once( "LanguageUtf8.php" );
 'specialpage'	=> 'Page Spéciale',
 'personaltools'	=> 'Outils personels',
 "postcomment"	=> "Ajouter un commentaire",
+'addsection'   => '+',
 "articlepage"	=> "Voir l'article",
 "subjectpage"   => "Page sujet",
 'talk'		=> 'Discussion',
@@ -262,6 +276,19 @@ Voir $1.",
 "thisisdeleted" => "Afficher ou restaurer $1?",
 "restorelink"	=> "$1 modifications effacées",
 'feedlinks'	=> 'Flux:',
+'sitenotice'	=> '-', # the equivalent to wgSiteNotice
+
+# Short words for each namespace, by default used in the 'article' tab in monobook
+'nstab-main' => 'Article',
+'nstab-user' => 'Page utilisateur',
+'nstab-media' => 'Média',
+'nstab-special' => 'Spécial',
+'nstab-wp' => 'A propos',
+'nstab-image' => 'Image',
+'nstab-mediawiki' => 'Message',
+'nstab-template' => 'Modèle',
+'nstab-help' => 'Aide',
+'nstab-category' => 'Catégorie',
 
 # Main script and global functions
 #
@@ -274,7 +301,7 @@ Voir $1.",
 #
 "error"		=> "Erreur",
 "databaseerror" => "Erreur base de données",
-"dberrortext"	=> "Erreur de syntaxe dans la base de données. Cette erreur peut être causée par une requête de recherche incorrecte (voir $5), ou une erreur dans le logiciel. La dernière requête traitée par la base de données était :
+"dberrortext"	=> "Erreur de syntaxe dans la base de données. La dernière requête traitée par la base de données était :
 <blockquote><tt>$1</tt></blockquote>
 depuis la fonction \"<tt>$2</tt>\".
 MySQL a renvoyé l'erreur \"<tt>$3: $4</tt>\".",
@@ -338,6 +365,8 @@ N'oubliez pas de personnaliser votre {{SITENAME}} en consultant la page Préfér
 "yournick"      => "Mon surnom (pour les signatures)",
 "yourrealname"	=> "Votre nom réél*",
 "emailforlost"  => "Si vous égarez votre mot de passe, vous pouvez demander à ce qu'un nouveau vous soit envoyé à votre adresse électronique.",
+'prefs-help-userdata' => "* <strong>Votre nom</strong> (facultatif): si vous le spécifiez, il sera utilisé pour l'attribution de vos contributions.<br />
+* <strong>Adresse électronique</strong> (facultatif): permet de vous contacter depuis le site sans dévoiler votre adresse, et utilisée pour vous envoyer un nouveau mot de passe si vous l'oubliez.",
 "loginerror"    => "Problème d'identification",
 "nocookiesnew"	=> "Le compte utilisateur a été créé, mais vous n'êtes pas connecté. {{SITENAME}} utilise des cookies pour la connexion mais vous avez les cookies désactives. Merci de les activer et de vous reconnecter.",
 "nocookieslogin" => "{{SITENAME}} utilise des cookies pour la connexion mais vous avez les cookies désactives. Merci de les activer et de vous reconnecter.",
@@ -357,6 +386,7 @@ Nous vous conseillons de vous connecter et de modifier ce mot de passe dès que
 Veuillez vous identifier dès que vous l'aurez reçu.",
 'loginend'	=> '&nbsp;',
 'mailerror'	=> 'Erreur lors de l\'envoi du mail: $1',
+'acct_creation_throttle_hit' => 'Désolé, vous avez déjà créé $1 compte(s). Vous ne pouvez pas en créer de nouveaux.',
 
 # Edit page toolbar
 "bold_sample"=>"Texte gras",
@@ -402,19 +432,20 @@ Veuillez vous identifier dès que vous l'aurez reçu.",
 'loginreqtitle'	=> 'Nom d\'utilisateur nécessaire',
 'loginreqtext'	=> "Vous devez vous [[Special:Userlogin|connecter]] pour voir les autres pages.",
 "accmailtitle" => "Mot de passe envoyé.",
-"accmailtext" => "Le mot de passe de '$1' a été envoyé à $2.",
+"accmailtext" => "Le mot de passe de « $1 » a été envoyé à $2.",
 
 "newarticle"   => "(Nouveau)",
 "newarticletext" => "Saisissez ici le texte de votre article.",
 "anontalkpagetext" => "---- ''Ceci est la page de discussion pour un utilisateur anonyme qui n'a pas encore créé un compte ou qui ne l'utilise pas. Pour cette raison, nous devons utiliser l'[[adresse IP]] numérique pour l'identifier. Une adresse de ce type peut être partagée entre plusieurs utilisateurs. Si vous êtes un utilisateur anonyme et si vous constatez que des commentaires qui ne vous concernent pas vous ont été adressés, vous pouvez [[Special:Userlogin|créer un compte ou vous connecter]] afin d'éviter toute future confusion à l'avenir.", 
 "noarticletext" => "(Il n'y a pour l'instant aucun texte sur cette page)",
+'clearyourcache'    => "'''Note:''' Après avoir sauvegardé, vous devez forcer le rechargement de la page pour voir les changements : Mozilla / Konqueror : ctrl-r, Firefox / IE / Opera : ctrl-f5, Safari : cmd-r.",
 "updated"      => "(Mis à jour)",
 "note"         => "<strong>Note :</strong> ",
 "previewnote"  => "Attention, ce texte n'est qu'une prévisualisation et n'a pas encore été sauvegardé!",
 "previewconflict" => "La prévisualisation montre le texte de cette page tel qu'il apparaîtra une fois sauvegardé.",
-"editing"      => "modification de $1",
-"sectionedit"	=> " (section)",
-"commentedit"	=> " (commentaire)",
+"editing"         => "modification de $1",
+"editingsection"  => "modification de $1 (section)",
+"editingcomment"  => "modification de $1 (commentaire)",
 "editconflict" => "Conflit de modification : $1",
 "explainconflict" => "<b>Cette page a été sauvegardée après que vous avez commencé à la modifier.
 La zone d'édition supérieure contient le texte tel qu'il est enregistré actuellement dans la base de données. Vos modifications apparaissent dans la zone d'édition inférieure. Vous allez devoir apporter vos modifications au texte existant. Seul le texte de la zone supérieure sera sauvegardé.\n<p>",
@@ -460,9 +491,7 @@ vous suivez les <a href='$wgScript/{{ns:4}}:Page_protégée'>directives concerna
 # Search results
 #
 "searchresults" => "Résultat de la recherche",
-"searchhelppage" => "{{ns:4}}:Recherche",
-"searchingwikipedia" => "Chercher dans {{SITENAME}}",
-"searchresulttext" => "Pour plus d'informations sur la recherche dans {{SITENAME}}, voir $1.",
+"searchresulttext" => "Pour plus d'informations sur la recherche dans {{SITENAME}}, voir [[Project:Recherche|Chercher dans {{SITENAME}}]].",
 "searchquery" => "Pour la requête \"$1\"",
 "badquery"  => "Requête mal formulée",
 "badquerytext" => "Nous n'avons pas pu traiter votre requête.
@@ -493,27 +522,6 @@ $1<br />
 $2 Inclure les page de redirections &nbsp; Rechercher $3 $9",
 "searchdisabled" => "<p>La fonction de recherche sur l'entièreté du texte a été temporairement désactivée à cause de la grande charge que cela impose au serveur. Nous espérons la rétablir prochainement lorsque nous disposerons d'un serveur plus puissant. En attendant, vous pouvez faire la recherche avec Google:</p>
                                                                                                                                                         
-",
-"googlesearch" => "<!-- SiteSearch Google -->
-<FORM method=GET action=\"http://www.google.com/search\">
-<TABLE bgcolor=\"#FFFFFF\"><tr><td>
-<A HREF=\"http://www.google.com/\">
-<IMG SRC=\"http://www.google.com/logos/Logo_40wht.gif\"
-border=\"0\" ALT=\"Google\"></A>
-</td>
-<td>
-<INPUT TYPE=text name=q size=31 maxlength=255 value=\"$1\">
-<INPUT type=submit name=btnG VALUE=\"Google Search\">
-<font size=-1>
-<input type=hidden name=domains value=\"{$wgServer}\"><br /><input type=radio
-name=sitesearch value=\"\"> WWW <input type=radio name=sitesearch
-value=\"{$wgServer}\" checked> {$wgServer} <br />
-<input type='hidden' name='ie' value='$2'>
-<input type='hidden' name='oe' value='$2'>
-</font>
-</td></tr></TABLE>
-</FORM>
-<!-- SiteSearch Google -->
 ",
 "blanknamespace" => "(Principal)",	// FIXME FvdP: trad de "(Main)"
 
@@ -528,9 +536,10 @@ pour modifier vos préférences d'utilisateur.",
 Voir [[{{ns:4}}:Aide pour les préférences]] pour les explications concernant les options.",
 "prefsreset"        => "Les préférences ont été rétablies à partir de la version enregistrée.",
 "qbsettings"        => "Personnalisation de la barre outils",
+'qbsettingsnote'	=> "Cette préférence ne fonctionne que pour les skins 'Standard' et 'CologneBlue'.",
 "changepassword"    => "Modification du mot de passe",
 "skin"              => "Apparence",
-"math"			=> "Rendu des maths",	// Looxix "Rendering math",
+"math"				=> "Rendu des maths",	// Looxix "Rendering math",
 "dateformat"		=> "Format de date",
 "math_failure"		=> "Erreur math",	// Looxix "Failure toparse",
 "math_unknown_error"	=> "erreur indéterminée",   // FvdP+Looxix "unknown error",
@@ -541,6 +550,9 @@ Voir [[{{ns:4}}:Aide pour les préférences]] pour les explications concernant l
 "math_bad_tmpdir"	=> "Ne peux pas crééer ou écrire dans le répertoire temporaire",
 "math_bad_output"	=> "Ne peux pas crééer ou écrire dans le répertoire de sortie",
 "math_notexvc"		=> "L'éxécutable 'texvc' est in trouvable. Lisez math/README pour le configurer.",
+'prefs-personal'    => 'Informations personnelles',
+'prefs-rc'          => 'Modifications récentes et affichage des ébauches',
+'prefs-misc'        => 'Préférences diverses',
 "saveprefs"         => "Enregistrer les préférences",
 "resetprefs"        => "Rétablir les préférences",
 "oldpassword"       => "Ancien mot de passe",
@@ -556,6 +568,7 @@ Voir [[{{ns:4}}:Aide pour les préférences]] pour les explications concernant l
 "stubthreshold"     => "Taille minimale des articles courts",
 "recentchangescount" => "Nombre de titres dans les modifications récentes",
 "savedprefs"        => "Les préférences ont été sauvegardées.",
+'timezonelegend'    => 'Zone horaire',
 "timezonetext"      => "Si vous ne précisez pas de décalage horaire, c'est l'heure de l'Europe de l'ouest qui sera utilisée.",
 "localtime"         => "Heure locale",
 "timezoneoffset"    => "Décalage horaire",
@@ -610,24 +623,30 @@ Si vous voulez que {{SITENAME}} connaisse le succès, merci de ne pas y inclure
 pour copier des fichiers sur le serveur.",
 "uploadfile"   => "Copier un fichier",
 "uploaderror"  => "Erreur",
-"uploadtext"   => "<strong>STOP !</strong> Avant de copier votre fichier sur le serveur,
-prenez connaissance des <a href=\"" .wfLocalUrlE( "{{ns:4}}:règles d'utilisation des images" ) . "\">règles d'utilisation des images</a> de {{SITENAME}} et assurez-vous que vous les respectez.<br />N'oubliez pas de remplir la <a href=\"" .wfLocalUrlE( "{{ns:4}}:Page de description d'une image" ). "\">page de description de l'image</a> quand celle-ci sera sur le serveur.
-<p>Pour voir les images déjà placées sur le serveur ou pour effectuer une recherche parmi celles-ci,
-allez à la <a href=\"" . wfLocalUrlE( "Special:Imagelist" ) ."\">liste des images</a>.
-Les uploads et les suppressions sont listés dans le <a href=\"" .wfLocalUrlE( "{{ns:4}}:Journal_des_uploads" ) . "\">journal des uploads</a>.
-<p>Utilisez le formulaire ci-dessous pour copier sur le serveur de nouvelles images destinées à illustrer vos articles.
+"uploadtext"   => "'''STOP !''' Avant de copier votre fichier sur le serveur,
+prenez connaissance des [[Project:règles d'utilisation des images|règles d'utilisation des images]] de {{SITENAME}} et assurez-vous que vous les respectez.<br />
+N'oubliez pas de remplir la [[Project:Page de description d'une image|page de description de l'image]] quand celle-ci sera sur le serveur.
+
+Pour voir les images déjà placées sur le serveur ou pour effectuer une recherche parmi celles-ci,
+allez à la [[Special:Imagelist|liste des images]].
+Les uploads et les suppressions sont listés dans le [[Project:Journal_des_uploads|journal des uploads]].
+
+Utilisez le formulaire ci-dessous pour copier sur le serveur de nouvelles images destinées à illustrer vos articles.
 Sur la plupart des navigateurs, vous verrez un bouton \"Browse...\" qui ouvre la fenêtre de dialogue standard de votre système d'exploitation pour l'ouverture des fichiers.
 Sélectionnez un fichier, son nom apparaîtra dans le champ situé à côté du bouton.
 Vous devez également confirmer, en cochant la case prévue à cet effet, que la copie de ce fichier ne viole aucun copyright.
 Cliquez sur le bouton \"Envoyer\" pour terminer.
 Si votre connexion est lente, l'opération peut prendre un certain temps.
-<p>Les formats recommandés sont JPEG pour les photos, PNG
+
+Les formats recommandés sont JPEG pour les photos, PNG
 pour les dessins et les autres images, et OGG pour les fichiers sonores.
 Donnez à vos fichiers des noms descriptifs clairs, afin d'éviter toute confusion.
 Pour incorporer l'image dans un article, placez dans celui-ci un lien rédigé comme suit:
-<b>[[image:nom_du_fichier.jpg]]</b> ou <b>[[image:nom_du_fichier.png|autre texte]]</b>
-ou <b>[[media:nom_du_fichier.ogg]]</b> pour les sons.
-<p>N'oubliez pas que, comme toutes les pages de {{SITENAME}}, les fichiers que vous copiez peuvent être modifiés ou supprimés par les autres utilisateurs s'ils estiment que cela est dans l'intérêt de l'encyclopédie. Sachez aussi que votre accès au serveur peut être bloqué si vous faites un mauvais usage du système.",
+'''<nowiki>[[image:nom_du_fichier.jpg]]</nowiki>''' ou
+'''<nowiki>[[image:nom_du_fichier.png|autre texte]]</nowiki>''' ou
+'''<nowiki>[[media:nom_du_fichier.ogg]]</nowiki>''' pour les sons.
+
+N'oubliez pas que, comme toutes les pages de {{SITENAME}}, les fichiers que vous copiez peuvent être modifiés ou supprimés par les autres utilisateurs s'ils estiment que cela est dans l'intérêt de l'encyclopédie. Sachez aussi que votre accès au serveur peut être bloqué si vous faites un mauvais usage du système.",
 "uploadlog"  => "log d'upload",		// FIXME
 "uploadlogpage" => "Log_d'upload",	// FIXME
 "uploadlogpagetext" => "Voici la liste des derniers fichiers copiés sur le serveur.
@@ -646,6 +665,7 @@ L'heure indiquée est celle du serveur (UTC).
 "noaffirmation" => "Vous devez confirmer que la copie de ce fichier ne viole aucun copyright.",
 "ignorewarning" => "Ignorer l'avertissement et copier le fichier quand même.",
 "minlength"	=> "Les noms des images doivent comporter au moins trois lettres.",
+'illegalfilename'	=> 'Le fichier "$1" contient des caractères qui ne sont pas autorisés dans le titre d\'une page. Veuillez renommer le fichier et le réenvoyer.',
 "badfilename" => "L'image a été renommée \"$1\".",
 "badfiletype" => "\".$1\" n'est pas un format recommandé pour les fichiers images.",
 "largefile"  => "La taille maximale conseillée pour les images est de 100Ko.",
@@ -856,8 +876,8 @@ La dernière modificaion était de [[User:$3|$3]] ([[User talk:$3|Talk]]). ", //
 "revertpage"	=> "restitution de la dernière modification de $1",
 "protectlogpage" => "Log_de_protection",
 "protectlogtext" => "Voir les [[{{ns:4}}:Page protégée|directives concernant les pages protégées]].",
-"protectedarticle" => "a protégée [[:$1]]",
-"unprotectedarticle" => "a déprotégé [[:$1]]",
+"protectedarticle" => "a protégée $1",
+"unprotectedarticle" => "a déprotégé $1",
 
 "protectsub" => "(Bloque \"$1\")",
 "confirmprotect" => "Confimer le bloquage",
@@ -994,6 +1014,28 @@ Tapez le nom de l'utilisateur dans la boite et pressez le bouton pour lui donner
 "set_rights_fail"	=> "<b>Les droits de l'utilisateur \"$1\" n'ont pas pu être mis en place. (Avez vous entré le nom correctement?)</b>",
 "makesysop"         => "Donner les droits d'adminitrateur à un utilisateur",
 
+# Validation
+'val_clear_old' => 'Supprimer mes données de validation pour $1',
+'val_merge_old' => 'Utiliser mes précédents choix pour les choix marqués \'Sans opinion\'',
+'val_noop' => 'Sans opinion',
+'val_percent' => '<b>$1%</b><br />($2 sur $3 points<br />par $4 utilisateurs)',
+'val_percent_single' => '<b>$1%</b><br />($2 sur $3 points<br />par un utilisateur)',
+'val_total' => 'Total',
+'val_version' => 'Version',
+'val_tab' => 'Valider',
+'val_this_is_current_version' => 'ceci est la dernière version',
+'val_version_of' => "Version de $1" ,
+'val_table_header' => "<tr><th>Class</th>$1<th colspan=4>Opinion</th>$1<th>Commentaire</th></tr>\n",
+'val_stat_link_text' => 'Statistiques de validation pour cet article',
+'val_view_version' => 'Voir cette version',
+'val_validate_version' => 'Valider cette version',
+'val_user_validations' => 'Cet utilisateur a validé $1 pages.',
+'val_no_anon_validation' => 'Vous devez être identifié pour valider un article.',
+'val_validate_article_namespace_only' => 'Seul les articles peuvent être validés. Cette page n\'est <i>pas</i> un article.',
+'val_validated' => 'Validation effectuée.',
+'val_article_lists' => 'List d\'articles validés',
+'val_page_validation_statistics' => 'Statistiques de validation pour $1',
+
 
 # Move page
 #
@@ -1055,50 +1097,52 @@ sous le nouveau nom. S'il vous plait, fusionnez les manuellement.",
 "importtext"	=> "Exportez un fichier depuis le wiki source en utilisant la fonction Special:Export, sauvez la page sur votre disque puis envoyez là ici.",
 
 # Keyboard access keys for power users
-'accesskey-anontalk' => 'n',
-'accesskey-anonuserpage' => '.',
-'accesskey-article' => 'a',
-'accesskey-contributions' => '',
-'accesskey-currentevents' => '',
-'accesskey-delete' => 'd',
-'accesskey-edit' => 'e',
-'accesskey-emailuser' => '',
-'accesskey-help' => '',
-'accesskey-history' => 'h',
-'accesskey-login' => 'o',
-'accesskey-logout' => 'o',
-'accesskey-mainpage' => 'z',
-'accesskey-minoredit' => 'i',
-'accesskey-move' => 'm',
-'accesskey-mycontris' => 'y',
-'accesskey-mytalk' => 'n',
-'accesskey-portal' => '',
-'accesskey-preferences' => '',
-'accesskey-preview' => 'p',
-'accesskey-protect' => '-',
-'accesskey-randompage' => 'x',
-'accesskey-recentchanges' => 'r',
+'accesskey-anontalk'		=> 'n',
+'accesskey-anonuserpage'	=> '.',
+'accesskey-article'			=> 'a',
+'accesskey-compareselectedversions' => 'v',
+'accesskey-contributions'	=> '',
+'accesskey-currentevents'	=> '',
+'accesskey-delete'			=> 'd',
+'accesskey-edit'			=> 'e',
+'accesskey-emailuser'		=> '',
+'accesskey-help'			=> '',
+'accesskey-history'			=> 'h',
+'accesskey-login'			=> 'o',
+'accesskey-logout'			=> 'o',
+'accesskey-mainpage'		=> 'z',
+'accesskey-minoredit'		=> 'i',
+'accesskey-move'			=> 'm',
+'accesskey-mycontris'		=> 'y',
+'accesskey-mytalk'			=> 'n',
+'accesskey-portal'			=> '',
+'accesskey-preferences'		=> '',
+'accesskey-preview'			=> 'p',
+'accesskey-protect'			=> '-',
+'accesskey-randompage'		=> 'x',
+'accesskey-recentchanges'	=> 'r',
 'accesskey-recentchangeslinked' => 'c',
-'accesskey-save' => 's',
-'accesskey-search' => 'f',
-'accesskey-sitesupport' => '',
-'accesskey-specialpage' => '',
-'accesskey-specialpages' => 'q',
-'accesskey-talk' => 't',
-'accesskey-undelete' => 'd',
-'accesskey-unwatch' => 'w',
-'accesskey-upload' => 'u',
-'accesskey-userpage' => '.',
-'accesskey-viewsource' => 'e',
-'accesskey-watch' => 'w',
-'accesskey-watchlist' => 'l',
-'accesskey-whatlinkshere' => 'b',
+'accesskey-save'			=> 's',
+'accesskey-search'			=> 'f',
+'accesskey-sitesupport'		=> '',
+'accesskey-specialpage'		=> '',
+'accesskey-specialpages'	=> 'q',
+'accesskey-talk'			=> 't',
+'accesskey-undelete'		=> 'd',
+'accesskey-unwatch'			=> 'w',
+'accesskey-upload'			=> 'u',
+'accesskey-userpage'		=> '.',
+'accesskey-viewsource'		=> 'e',
+'accesskey-watch'			=> 'w',
+'accesskey-watchlist'		=> 'l',
+'accesskey-whatlinkshere'	=> 'b',
 
 # tooltip help for the main actions
 'tooltip-anontalk' => 'Discussion des éditions faites à partir de cette adresse ip [alt-n]',
 'tooltip-anonuserpage' => 'La page d\'utilisateur pour l\'adresse ip depuis laquelle vous éditez [alt-.]',
 'tooltip-article' => 'Voir l\'article [alt-a]',
 'tooltip-atom' => 'Flux Atom pour cette page',
+'tooltip-compareselectedversions' => 'Voir les différences entre les deux versions séléctionnées de cette page. [alt-v]',
 'tooltip-contributions' => 'Voir la liste des contributions de cet utilisateur',
 'tooltip-currentevents' => 'Trouver des informations sur les évenements actuels',
 'tooltip-delete' => 'Supprimer cette page [alt-d]',
@@ -1148,42 +1192,38 @@ sous le nouveau nom. S'il vous plait, fusionnez les manuellement.",
 "lastmodifiedby" => "Cette page a été modifiée pour la dernière fois le $1 par $2",
 "and"	=> "et",
 "contributions" => "Basé sur le travail de $1.",
-"siteusers"	=> "Utilisateur(s) $1 de {{SITENAME}}"
+"siteusers"	=> "Utilisateur(s) $1 de {{SITENAME}}",
+
+# Math
+'mw_math_png' => "Toujours produire une image PNG",  
+'mw_math_simple' => "HTML si très simple, autrement PNG", 
+'mw_math_html' => "HTML si possible, autrement PNG", 
+'mw_math_source' => "Laisser le code TeX original",
+'mw_math_modern' => "Pour les navigateurs modernes",
+'mw_math_mathml' => 'MathML',
 );
 
-class LanguageFr extends LanguageUtf8
-{
+class LanguageFr extends LanguageUtf8 {
 
-	function getDefaultUserOptions()
-	{
-	        $opt = Language::getDefaultUserOptions();
-                return $opt;
+	function getBookstoreList () {
+		global $wgBookstoreListFr ;
+		return $wgBookstoreListFr ;
 	}
 
-        function getBookstoreList () {
-                global $wgBookstoreListFr ;
-                return $wgBookstoreListFr ;
-        }
-
-	function getNamespaces()
-	{
+	function getNamespaces() {
 		global $wgNamespaceNamesFr;
 		return $wgNamespaceNamesFr;
 	}
 
-
-	function getNsText( $index )
-	{
+	function getNsText( $index ) {
 		global $wgNamespaceNamesFr;
 		return $wgNamespaceNamesFr[$index];
 	}
 
-	function getNsIndex( $text ) 
-	{
+	function getNsIndex( $text ) {
 		global $wgNamespaceNamesFr, $wgSitename;
 
-		foreach ( $wgNamespaceNamesFr as $i => $n ) 
-		{
+		foreach ( $wgNamespaceNamesFr as $i => $n ) {
 			if ( 0 == strcasecmp( $n, $text ) ) { return $i; }
 		}
 		if( $wgSitename == "Wikipédia" ) {
@@ -1193,57 +1233,20 @@ class LanguageFr extends LanguageUtf8
 		return false;
 	}
 
-	function specialPage( $name ) 
-	{
-		return $this->getNsText( Namespace::getSpecial() ) . ":" . $name;
-	}
-
-	function getQuickbarSettings() 
-	{
+	function getQuickbarSettings() {
 		global $wgQuickbarSettingsFr;
 		return $wgQuickbarSettingsFr;
 	}
 
-	function getSkinNames()
-	{
+	function getSkinNames() {
 		global $wgSkinNamesFr;
 		return $wgSkinNamesFr;
 	}
 
-	function getMathNames() {
-		global $wgMathNamesFr;
-		return $wgMathNamesFr;
-	}
-
-
-	function getUserToggles()
-	{
-		global $wgUserTogglesFr;
-		return $wgUserTogglesFr;
-	}
-
-	function getMonthName( $key )
-	{
-		global $wgMonthNamesFr;
-		return $wgMonthNamesFr[$key-1];
-	}
-
-	function getMonthAbbreviation( $key )
-	{
-		global $wgMonthAbbreviationsFr;
-		return $wgMonthAbbreviationsFr[$key-1];
-	}
-
-	function getWeekdayName( $key )
-	{
-		global $wgWeekdayNamesFr;
-		return $wgWeekdayNamesFr[$key-1];
-	}
 
 	// Inherit userAdjust()
 
-	function date( $ts, $adj = false )
-	{
+	function date( $ts, $adj = false ) {
 		if ( $adj ) { $ts = $this->userAdjust( $ts ); }
 
 		$d = (0 + substr( $ts, 6, 2 )) . " " .
@@ -1252,48 +1255,45 @@ class LanguageFr extends LanguageUtf8
 		return $d;
 	}
 
-	function time( $ts, $adj = false )
-	{
-		if ( $adj ) { $ts = $this->userAdjust( $ts ); }
-
-		$t = substr( $ts, 8, 2 ) . ":" . substr( $ts, 10, 2 );
-		return $t;
-	}
-
-	function timeanddate( $ts, $adj = false )
-	{
+	function timeanddate( $ts, $adj = false ) {
 		return $this->date( $ts, $adj ) . " à " . $this->time( $ts, $adj );
 	}
 
-	function getValidSpecialPages()
-	{
+	var $digitTransTable = array(
+		',' => '&nbsp;',
+		'.' => ','
+	);
+	
+	function formatNum( $number ) {
+		global $wgTranslateNumerals;
+		return $wgTranslateNumerals ? strtr($number, $this->digitTransTable ) : $number;
+	}
+
+
+	function getValidSpecialPages() {
 		global $wgValidSpecialPagesFr;
 		return $wgValidSpecialPagesFr;
 	}
 
-	function getSysopSpecialPages()
-	{
+	function getSysopSpecialPages() {
 		global $wgSysopSpecialPagesFr;
 		return $wgSysopSpecialPagesFr;
 	}
 
-	function getDeveloperSpecialPages()
-	{
+	function getDeveloperSpecialPages() {
 		global $wgDeveloperSpecialPagesFr;
 		return $wgDeveloperSpecialPagesFr;
 	}
 
-	function getMessage( $key )
-	{
+	function getMessage( $key ) {
 		global $wgAllMessagesFr, $wgAllMessagesEn;
 		if( isset( $wgAllMessagesFr[$key] ) ) {
 			return $wgAllMessagesFr[$key];
 		} else {
-			return $wgAllMessagesEn[$key];
+			return Language::getMessage( $key );
 		}
 	}
 	
-	function isRTL() { return false; }
 }
 
 ?>
