@@ -18,8 +18,8 @@ if($wgMetaNamespace === FALSE)
 	-1	=> "Wiki",
 	0	=> "",
 	1	=> "Oerlis",
-	2	=> "Brûker",
-	3	=> "Brûker_oerlis",
+	2	=> "Meidogger",
+	3	=> "Meidogger_oerlis",
 	4	=> $wgMetaNamespace,
 	5	=> $wgMetaNamespace . "_oerlis",
 	6	=> "Ofbyld",
@@ -30,8 +30,8 @@ if($wgMetaNamespace === FALSE)
 	11  => "Berjocht_oerlis",
             12  => "Hulp",
             13  => "Hulp_oerlis",
-            14  => "Kategorie",
-            15  => "Kategorie_oerlis"
+            14  => "Kategory",
+            15  => "Kategory_oerlis"
 
 ) + $wgNamespaceNamesEn;
 
@@ -51,13 +51,6 @@ if($wgMetaNamespace === FALSE)
  "myskin" => "MySkin" 
 );
 
-/* private */ $wgMathNamesFy = array(
-           "Altiten as PNG ôfbyldzje",
-           "HTML foar ienfâldiche formules, oars PNG",
-           "HTML as mooglik, oars PNG",
-           "Lit de TeX ferzje stean (foar tekstblêdzjers)",
-           "Oanbefelle foar resinte blêdzjers"
-);
 
 /* private */ $wgDateFormatsFy = array(
 	"Gjin foarkar",
@@ -66,47 +59,9 @@ if($wgMetaNamespace === FALSE)
 	"2001 jannewaris 8"
 );
 
-/* private */ $wgUserTogglesFy = array(
-	"hover"		=> "Wiki-keppelings yn sweeffak sjen litte",
-	"underline"		=> "Keppelings ûnderstreekje",
-	"highlightbroken"	=> "Keppelings nei lege siden ta <a href=\"\" class=\"new\">read</a>
-					(oars mei in fraachteken<a href=\"\" class=\"internal\">?</a>).",
-	"justify"		=> "Paragrafen útfolje",
-	"hideminor"		=> "Tekstwizigings wei litte út 'Koarts feroare'",
-	"usenewrc"		=> "Utwreide ferzje fan 'Koarts feroare' brûke (net mei alle blêdzjers mooglik)",
-	"numberheadings"	=> "Koppen fansels nûmerje",
-	"showtoolbar" => "Show edit toolbar",
-	"editondblclick"	=> "Dûbelklik jout bewurkingsside (freget JavaScript)",
-	"editsection"	=> "Jou [bewurk]-keppelings foar seksjebewurking",
-	"editsectiononrightclick" => "Rjochtsklik op sekjsetitels jout seksjebewurking (freget JavaScript)",
- 	"showtoc"		=> "Ynhâldsopjefte, foar siden mei mear as twa koppen",
-	"rememberpassword" => "Oare kear fansels oanmelde",
-	"editwidth"		=> "Bewurkingsfjild sa breed as de side",
-	"watchdefault"	=> "Sides dy't jo feroare hawwe folgje",
-	"minordefault"	=> "Feroarings yn it earst oanjaan as tekstwizigings.",
-	"previewontop"	=> "By it neisjen, bewurkingsfjild ûnderoan sette",
-	"nocache"		=> "Gjin oerslag brûke"
-);
-
 /* private */ $wgBookstoreListFy = array(
 );
 
-/* private */ $wgWeekdayNamesFy = array(
-	"snein", "moandei", "tiisdei", "woansdei", "tongersdei",
-      "freed", "sneon"
-);
-
-/* private */ $wgMonthNamesFy = array(
-	 "jannewaris", "febrewaris", "maart", "april", "maaie", "juny",
-       "july", "augustus", "septimber", "oktober", "novimber",
-       "decimber"
-);
-
-/* private */ $wgMonthAbbreviationsFy = array(
-       "jan", "feb", "mar", "apr", "mai", "jun", "jul", "aug",
-       "sep", "okt", "nov", "dec"
-);
-
 # All special pages have to be listed here: a description of ""
 # will make them not show up on the "Special Pages" page, which
 # is the right thing for some of them (such as the "targeted" ones).
@@ -159,6 +114,61 @@ if($wgMetaNamespace === FALSE)
 );
 
 /* private */ $wgAllMessagesFy = array(
+'special_version_prefix' => '',
+'special_version_postfix' => '',
+# User Toggles
+
+"tog-hover"		=> "Wiki-keppelings yn sweeffak sjen litte",
+"tog-underline"		=> "Keppelings ûnderstreekje",
+"tog-highlightbroken"	=> "Keppelings nei lege siden ta <a href=\"\" class=\"new\">read</a> (oars mei in fraachteken<a href=\"\" class=\"internal\">?</a>).",
+"tog-justify"		=> "Paragrafen útfolje",
+"tog-hideminor"		=> "Tekstwizigings wei litte út 'Koarts feroare'",
+"tog-usenewrc"		=> "Utwreide ferzje fan 'Koarts feroare' brûke (net mei alle blêdzjers mooglik)",
+"tog-numberheadings"	=> "Koppen fansels nûmerje",
+"tog-showtoolbar" => "Show edit toolbar",
+"tog-editondblclick"	=> "Dûbelklik jout bewurkingsside (freget JavaScript)",
+"tog-editsection"	=> "Jou [bewurk]-keppelings foar seksjebewurking",
+"tog-editsectiononrightclick" => "Rjochtsklik op sekjsetitels jout seksjebewurking (freget JavaScript)",
+"tog-showtoc"		=> "Ynhâldsopjefte, foar siden mei mear as twa koppen",
+"tog-rememberpassword" => "Oare kear fansels oanmelde",
+"tog-editwidth"		=> "Bewurkingsfjild sa breed as de side",
+"tog-watchdefault"	=> "Sides dy't jo feroare hawwe folgje",
+"tog-minordefault"	=> "Feroarings yn it earst oanjaan as tekstwizigings.",
+"tog-previewontop"	=> "By it neisjen, bewurkingsfjild ûnderoan sette",
+"tog-nocache"		=> "Gjin oerslag brûke",
+# Dates
+'sunday' => 'snein',
+'monday' => 'moandei',
+'tuesday' => 'tiisdei',
+'wednesday' => 'woansdei',
+'thursday' => 'tongersdei',
+'friday' => 'freed',
+'saturday' => 'sneon',
+'january' => 'jannewaris',
+'february' => 'febrewaris',
+'march' => 'maart',
+'april' => 'april',
+'may_long' => 'maaie',
+'june' => 'juny',
+'july' => 'july',
+'august' => 'augustus',
+'september' => 'septimber',
+'october' => 'oktober',
+'november' => 'novimber',
+'december' => 'decimber',
+'jan' => 'jan',
+'feb' => 'feb',
+'mar' => 'mar',
+'apr' => 'apr',
+'may' => 'mai',
+'jun' => 'jun',
+'jul' => 'jul',
+'aug' => 'aug',
+'sep' => 'sep',
+'oct' => 'okt',
+'nov' => 'nov',
+'dec' => 'dec',
+
 
 # Bits of text used by many pages:
 #
@@ -167,7 +177,7 @@ if($wgMetaNamespace === FALSE)
 "mainpage"		=> "Haadside",
 "mainpagetext"	=> "Wiki-programma goed installearre.",
 "about"		=> "Ynfo",
-"aboutwikipedia" 	=> "Oer de $wgSitename",
+"aboutsite"      	=> "Oer de $wgSitename",
 "aboutpage"		=> "$wgMetaNamespace:Ynfo",
 "help"		=> "Help",
 "helppage"		=> "$wgMetaNamespace:Help",
@@ -190,7 +200,7 @@ if($wgMetaNamespace === FALSE)
 "currentevents" 	=> "Hjoeddeis",
 "errorpagetitle" 	=> "Fout",
 "returnto"		=> "Werom nei \"$1\".",
-"fromwikipedia"	=> "Fan $wgSitename, de frije ensyklopedy.", # FIXME
+"tagline"      	=> "Fan $wgSitename, de frije ensyklopedy.", # FIXME
 "whatlinkshere"	=> "Siden mei in keppeling hjirhinne",
 "help"		=> "Help",
 "search"		=> "Sykje",
@@ -250,8 +260,6 @@ if($wgMetaNamespace === FALSE)
 "error"			=> "Fout",
 "databaseerror" 		=> "Databankfout",
 "dberrortext"		=> "Sinboufout in databankfraach.
-Dit soe troch in ferkearde sykfraach komme kinne (sjoch \"$5\"),
-of it soe in brek yn it programma wêze kinne.
 De lêst besochte databankfraach wie:
 <blockquote><tt>$1</tt></blockquote>
 fan funksje \"<tt>$2</tt>\" út.
@@ -311,8 +319,8 @@ Ferjit net se oan jo foarkar oan te passen.",
 "yourpasswordagain" => "Jo wachtwurd (nochris)",
 "newusersonly" 	=> " (allinnich foar nije brûkers)",
 "remembermypassword" => "Oare kear fansels oanmelde.",
-"loginproblem" 	=> "<b>Der wie wat mis mei jo oanmelden.</b><br>Besykje it nochris, a.j.w.",
-"alreadyloggedin" => "<font color=red><b>Brûker $1, jo binne al oanmeld!</b></font><br>\n",
+"loginproblem" 	=> "<b>Der wie wat mis mei jo oanmelden.</b><br />Besykje it nochris, a.j.w.",
+"alreadyloggedin" => "<font color=red><b>Brûker $1, jo binne al oanmeld!</b></font><br />\n",
 "login"		=> "Oanmelde",
 "userlogin"		=> "Oanmelde",
 "logout"		=> "Ofmelde",
@@ -323,7 +331,7 @@ Ferjit net se oan jo foarkar oan te passen.",
 "userexists"	=> "Dy brûkersname wurdt al brûkt. Besykje in oarenien.",
 "youremail"		=> "Jo e-postadres (*).",
 "yournick"		=> "Jo alias (foar sinjaturen)",
-"emailforlost"	=> "* In e-postadres hoecht net.<br>
+"emailforlost"	=> "* In e-postadres hoecht net.<br />
 Mar it helpt, soenen jo jo wachtwurd ferjitte.
 En mei in e-postadres kinne oaren fan de web siden contact mei jo krije,
 sûnder dat se dat adres witte. (Dat leste kin ek wer útset by de instellings.)",
@@ -359,7 +367,7 @@ Please log in again after you receive it.",
 "showpreview"	=> "Oerlêze foar de side fêstlein is",
 "blockedtitle"	=> "Brûker is útsletten troch",
 "blockedtext"	=> "Jo brûkersname of Ynternet-adres is útsletten.
-As reden is opjûn:<br>''$2''<p>As jo wolle, kinne jo hjiroer kontakt op nimme meid de behearder. 
+As reden is opjûn:<br />''$2''<p>As jo wolle, kinne jo hjiroer kontakt op nimme meid de behearder. 
 
 (Om't in Ynternet-adressen faak mar foar ien sessie tawiisd wurde, kin it wêze
 dat it eins gjit om in oar dy't deselde tagongferskaffer hat as jo hawwe. As it jo
@@ -390,8 +398,8 @@ jo jo [[Wiki:Userlogin|oanmelde]], dat jo allinnich opmerkings foar josels krije
 "previewnote"	=> "Tink der om dat dizze side noch net fêstlein is!",
 "previewconflict" => "Dizze side belanget allinich it earste bewurkingsfjild oan.",
 "editing"		=> "Bewurkje \"$1\"",
-"sectionedit"	=> " (seksje)",
-"commentedit"	=> " (nije opmerking)",
+"editing"		=> "Bewurkje \"$1\" (seksje)",
+"editing"		=> "Bewurkje \"$1\" (nije opmerking)",
 "editconflict"	=> "Tagelyk bewurke: \"$1\"",
 "explainconflict" => "In oar hat de side feroare sûnt jo begûn binne mei it bewurkjen.
 It earste bewurkingsfjild is hoe't de tekst wilens wurde is. 
@@ -408,7 +416,7 @@ Soenen jo dizze fêstlizze, dan is al wat sûnt dy tiid feroare is kwyt.</strong
 as fallend ûnder de GNU Iepen Dokumentaasje Lisinsje
 (sjoch fierders: \"$1\").
 As jo net wolle dat jo skriuwen ûnferbidlik oanpast en frij ferspraat wurdt,
-dan is it baas, en set it net op de $wgSitename.<br>
+dan is it baas, en set it net op de $wgSitename.<br />
 Jo ferklare ek dat jo dit sels skreaun hawwe, of it oernaam hawwe út in
 publyk eigendom of in oare iepen boarne.
 <strong><big>Foeg gjin wurk ûnder auteursrjocht ta sûnder tastimming!</big></strong>",
@@ -450,9 +458,7 @@ Gean nei of de keppeling dy jo brûkt hawwe wol goed is.\n",
 # Search results
 #
 "searchresults" => "Sykresultaat",
-"searchhelppage" => "$wgMetaNamespace:Syk-rie|Ynformaasje oer it sykjen",
-"searchingwikipedia" => "Sykje troch de $wgSitename",
-"searchresulttext" => "\"$1\" troch de $wgSitename.",
+"searchresulttext" => "\"[[Project:Syk-rie|Ynformaasje oer it sykjen|Sykje troch de {{SITENAME}}]]\" troch de {{SITENAME}}.",
 "searchquery"	=> "Foar fraach \"$1\"",
 "badquery"		=> "Misfoarme sykfraach",
 "badquerytext"	=> "Jo fraach koe net ferwurke wurde.
@@ -475,8 +481,8 @@ wurden syke wurde, allinnich siden fûn wurde wêr't <b>alle</b> worden op fûn
 
 "powersearch" => "Sykje",
 "powersearchtext" => "
-Sykje in nammeromten :<br>
-$1<br>
+Sykje in nammeromten :<br />
+$1<br />
 $2 List trochferwizings &nbsp; Sykje nei \"$3\" \"$9\"",
 
 "searchdisabled" => "<p>Op it stuit stjit it trochsykjen fan tekst net oan, om't de 
@@ -484,28 +490,6 @@ tsjinner it net oankin. Mei't we nije apparatuer krije wurdt it nei alle gedanke
 mooglik. Foar now kinne jo sykje fia Google:</p>
                                                                                                                                                         
 ",
-"googlesearch" => "<!-- SiteSearch Google -->
-<FORM method=GET action=\"http://www.google.com/search\">
-<TABLE bgcolor=\"#FFFFFF\"><tr><td>
-<A HREF=\"http://www.google.com/\">
-<IMG SRC=\"http://www.google.com/logos/Logo_40wht.gif\"
-border=\"0\" ALT=\"Google\"></A>
-</td>
-<td>
-<INPUT TYPE=text name=q size=31 maxlength=255 value=\"$1\">
-<INPUT type=submit name=btnG VALUE=\"Sykje mei Google\">
-<font size=-1>
-<input type=hidden name=domains value=\"{$wgServer}\"><br><input type=radio
-name=sitesearch value=\"\"> WWW <input type=radio name=sitesearch
-value=\"{$wgServer}\" checked> $wgSitename <br>
-<input type='hidden' name='ie' value='$2'>
-<input type='hidden' name='oe' value='$2'>
-</font>
-</td></tr></TABLE>
-</FORM>
-<!-- SiteSearch Google -->
-",
-
 "blanknamespace" => "($wgSitename)",
 
 
@@ -514,7 +498,7 @@ value=\"{$wgServer}\" checked> $wgSitename <br>
 "preferences"		=> "Ynstellings",
 "prefsnologin" 		=> "Net oanmeld",
 "prefsnologintext"	=> "Jo moatte <a href=\""
-. wfLocalUrl( "Wiki:Userlogin" ) 
+. "{{localurle:Wiki:Userlogin}}" 
 . "\">oanmeld</a> wêze om jo ynstellings te feroarjen.",
 
 "prefslogintext" 		=> "Jo binne oanmeld, $1.
@@ -588,30 +572,34 @@ Jo Wiki-nûmer is $2.
 "reuploaddesc"	=> "Werom nei oanbied-side.",
 "uploadnologin" 	=> "Net oanmelde",
 "uploadnologintext" => "Jo moatte <a href=\""
-. wfLocalUrl( "Wiki:Userlogin" ) 
+. "{{localurle:Wiki:Userlogin}}" 
 . "\">oanmeld</a> wêze om in bestân oanbieden te kinnen.",
 
 "uploadfile"	=> "Bied ôfbylden, lûden, dokuminten ensfh. oan.",
 "uploaderror"	=> "Oanbied-fout",
-"uploadtext"	=> "<strong>STOP!</strong> Lês ear't jo eat oanbiede
-de <a href=\"" . wfLocalUrlE( "$wgMetaNamespace:Ofbyld-rie" )
-. "\">regels foar ôfbyldbrûk</a> foar de $wgSitename.
-<p>Earder oanbeane ôfbylden, kinne jo fine op de <a href=\"" 
-. wfLocalUrlE( "Wiki:Imagelist" ) 
-. "\">list of oanbeane ôfbylden</a>.
-Wat oanbean en wat wiske wurdt, wurdt delskreaun yn it <a href=\"" .
-wfLocalUrlE( "$wgMetaNamespace:Oanbied-loch" ) . "\">lochboek</a>.
-<p>Om't nije ôfbylden oan te bieden, kieze jo in bestân út sa't dat
+"uploadtext"	=> "'''STOP!''' Lês ear't jo eat oanbiede
+de [[Project:Ofbyld-rie|regels foar ôfbyldbrûk]] foar de {{SITENAME}}.
+
+Earder oanbeane ôfbylden, kinne jo fine op de
+[[Project:Imagelist|list of oanbeane ôfbylden]].
+Wat oanbean en wat wiske wurdt, wurdt delskreaun yn it
+[[Project:Oanbied-loch|lochboek]].
+
+Om't nije ôfbylden oan te bieden, kieze jo in bestân út sa't dat
 normaal is foar jo blêdzjer en bestjoersysteem.
 Dan jouwe jo oan jo gjin auteursrjocht skeine troch it oanbieden.
 Mei \"Bied oan\" begjinne jo dan it oanbieden.
 Dit kin efkes duorje as jo Ynternet-ferbining net sa flug is.
-<p>Foar de bestânsforam wurdt foto's JPEG oanret, foar tekenings ensfh. PNG, en foar
+
+Foar de bestânsforam wurdt foto's JPEG oanret, foar tekenings ensfh. PNG, en foar
 lûden OGG. Brûk in dúdlike bestânsnamme, sa't in oar ek wit wat it is.
-<P>Om it ôfbyld yn in side op te nimmen, meitsje jo dêr sa'n keppeling:<br>
-<b>[[ôfbyld:jo_foto.jpg|omskriuwing]]</b> of <b>[[ôfbyld:jo_logo.png|omskriuwing]]</b>;
-en foar lûden <b>[[media:jo_lûd.ogg]]</b>.
-<p>Tink derom dat oaren bewurkje kinne wat jo oanbiede, as dat better is foar de $wgSitename,
+
+Om it ôfbyld yn in side op te nimmen, meitsje jo dêr sa'n keppeling:<br />
+'''<nowiki>[[ôfbyld:jo_foto.jpg|omskriuwing]]</nowiki>''' of
+'''<nowiki>[[ôfbyld:jo_logo.png|omskriuwing]]</nowiki>''';
+en foar lûden '''<nowiki>[[media:jo_lûd.ogg]]</nowiki>'''.
+
+Tink derom dat oaren bewurkje kinne wat jo oanbiede, as dat better is foar de $wgSitename,
 krekt's sa't dat foar siden jildt, en dat jo útsletten wurde kinne as jo misbrûk
 meitsje fan it systeem..",
 
@@ -669,7 +657,7 @@ en wat jo fierder mar oan ynformaasje hawwe.",
 "deleteimgcompletely"		=> "wisk",
 "imghistlegend"	=> "Utlis: (no) = dit is it hjoeddeiske ôfbyld,
 (wisk) = wiskje dizze âldere ferzje, (tebek) = set ôfbyld tebek nei dizze âldere ferzje.
-<br><i>Fia de datum kinne jo it ôfbyld dat doe oanbean besjen</i>.",
+<br /><i>Fia de datum kinne jo it ôfbyld dat doe oanbean besjen</i>.",
 
 "imagelinks"	=> "Ofbyldkeppelings",
 "linkstoimage"	=> "Dizze siden binne keppele oan it ôfbyld:",
@@ -680,9 +668,9 @@ en wat jo fierder mar oan ynformaasje hawwe.",
 "statistics"	=> "Statistyk",
 "sitestats"		=> "Side statistyk",
 "userstats"		=> "Brûker statistyk",
-"sitestatstext" => "It tal fan siden in de $wgSitename is: <b>$2</b>.<br>
+"sitestatstext" => "It tal fan siden in de $wgSitename is: <b>$2</b>.<br />
 (Oerlissiden, siden oer de $wgSitename, oare bysûndere siden,  stobben en
-trochferwizings yn de databank binne dêrby net meiteld.)<br>
+trochferwizings yn de databank binne dêrby net meiteld.)<br />
 It tal fan siden in de databank is: <b>$1</b>.
 <p>
 Der is <b>$3</b> kear in side opfrege, en <b>$4</b> kear in side bewurke,
@@ -705,12 +693,12 @@ eltse oanpassing daalks in fernijde side op.",
 "disambiguationspage"	=> "$wgMetaNamespace:trochferwizing",
 "disambiguationstext"	=> "Dizze siden binne keppele fia in
 [[$wgMetaNamespace:trochferwizing]]. 
-Se soenen mei de side sels keppele wurde moatte.<br>
+Se soenen mei de side sels keppele wurde moatte.<br />
 (Allinnich siden út deselde nammeromte binne oanjûn.)",
 
 "doubleredirects"	=> "Dûbele trochverwizings",
 "doubleredirectstext"	=> "<b>Let op!</b> Der kinne missen yn dizze list stean!
-Dat komt dan ornaris troch oare keppelings ûnder de \"#REDIRECT\".<br>
+Dat komt dan ornaris troch oare keppelings ûnder de \"#REDIRECT\".<br />
 Eltse rigel jout keppelings nei de earste en twadde trochverwizing, en dan de earste regel fan
 de twadde trochferwizing, wat it \"echte\" doel wêze moat.",
 
@@ -766,9 +754,9 @@ an ôfbyld makke hawwe kinne. Dan wurde se noch brûke, mar stean al in dizze li
 #
 "mailnologin"	=> "Gjin adres beskikber",
 "mailnologintext" => "Jo moatte <a href=\""
-. wfLocalUrl( "Wiki:Userlogin" ) . "\">oanmeld</a>
+. "{{localurle:Wiki:Userlogin}}\">oanmeld</a>
 wêze, en in jildich e-postadres <a href=\"" .
-  wfLocalUrl( "Wiki:Preferences" ) . "\">ynsteld</a>
+  "{{localurle:Wiki:Preferences}}\">ynsteld</a>
 hawwe, om oan oare brûkers e-post stjoere te kinnen.",
 
 "emailuser"		=> "Skriuw dizze brûker",
@@ -795,15 +783,15 @@ of hat oanjaan gjin post fan oare brûkers krije te wollen.",
 "nowatchlist"	=> "Jo hawwe gjin siden op jo folchlist.",
 "watchnologin"	=> "Not oanmeld in",
 "watchnologintext"=> "Jo moatte <a href=\""
-. wfLocalUrl( "Wiki:Userlogin" ) 
+. "{{localurle:Wiki:Userlogin}}" 
 . "\">oanmeld</a> wêze om jo folchlist te feroarjen.",
 
 "addedwatch"	=> "Oan folchlist tafoege",
 "addedwatchtext"	=> "De side \"$1\" is tafoege oan jo <a href=\"" 
-. wfLocalUrl( "Wiki:Watchlist" ) . "\">folchlist</a>.
+. "{{localurle:Wiki:Watchlist}}\">folchlist</a>.
 As dizze side sels, of de oerlisside, feroare wurd, dan komt dat dêr yn,
 en de side stiet dan ek <b>fet</b> yn de <a href=\"" .
-  wfLocalUrl( "Wiki:Recentchanges" ) . "\">Koarts feroare</a> list.
+  "{{localurle:Wiki:Recentchanges}}\">Koarts feroare</a> list.
 
 <p>As jo letter in side net mear folgje wolle, dan brûke jo \"Ferjit dizze side\".",
 "removedwatch"	=> "Net mear folgje",
@@ -922,7 +910,7 @@ Meld de krekte reden! Begelyk, neam de siden dy't oantaaste waarden.",
 "badipaddress"	=> "Dy brûker bestiet net",
 "noblockreason"	=> "Jo moatte de krekte reden opjaan.",
 "blockipsuccesssub" => "Utsluting slagge",
-"blockipsuccesstext" => "Brûker \"$1\" is útsletten.<br>
+"blockipsuccesstext" => "Brûker \"$1\" is útsletten.<br />
 (List fan [[Wiki:Ipblocklist|útslette brûkers]].)",
 "unblockip"		=> "Lit brûker der wer yn",
 "unblockiptext"	=> "Brûk dizze fjilden om in brûker wer skriuwtagong te jaan.",
@@ -955,7 +943,7 @@ Befêstigje dat dit is wat jo wolle.",
 "lockdbsuccesssub" => "Databank is 'Net-skriuwe'",
 "unlockdbsuccesssub" => "Database is skriuwber",
 "lockdbsuccesstext" => "De $wgSitename databank is 'Net-skriuwe' makke.
-<br>Tink derom en meitsje de databank skriuwber as jo ûnderhâld ree is.",
+<br />Tink derom en meitsje de databank skriuwber as jo ûnderhâld ree is.",
 "unlockdbsuccesstext" => "De $wgSitename databank is skriuwber makke.",
 
 # SQL query
@@ -995,7 +983,7 @@ In dizze gefallen is it oan jo hoe't jo de oerlisside werneame of ynfoegje wolle
 "movearticle"	=> "Werneam side",
 "movenologin"	=> "Net oameld",
 "movenologintext" => "Jo moatte <a href=\""
-. wfLocalUrl( "Wiki:Userlogin" ) 
+. "{{localurle:Wiki:Userlogin}}" 
 . "\">oanmeld</a> wêze om in side wer te neamen.",
 
 "newtitle"		=> "As nij titel",
@@ -1014,6 +1002,13 @@ Gearfoegje de oerlissiden hânmjittig.",
 "moveoerlis"	=> "De oerlisside, as dy der is, moat oan de side keppele bliuwe.",
 "talkpagemoved"	=> "De oerlisside is al noch keppele.",
 "talkpagenotmoved" => "De oerlisside is <strong>net</strong> mear keppele.",
+# Math
+           'mw_math_png' => "Altiten as PNG ôfbyldzje",
+           'mw_math_simple' => "HTML foar ienfâldiche formules, oars PNG",
+           'mw_math_html' => "HTML as mooglik, oars PNG",
+           'mw_math_source' => "Lit de TeX ferzje stean (foar tekstblêdzjers)",
+           'mw_math_modern' => "Oanbefelle foar resinte blêdzjers",
+	   'mw_math_mathml' => 'MathML',
 
 );
 
@@ -1042,6 +1037,8 @@ class LanguageFy extends LanguageUtf8 {
 			if ( 0 == strcasecmp( $n, $text ) ) { return $i; }
 		}
 		if ( 0 == strcasecmp( "Special", $text ) ) return -1;
+		if ( 0 == strcasecmp( "Brûker", $text ) ) return 2;
+		if ( 0 == strcasecmp( "Brûker_oerlis", $text ) ) return 3;
 		return false;
 	}
 
@@ -1057,52 +1054,11 @@ class LanguageFy extends LanguageUtf8 {
 		return $wgSkinNamesFy;
 	}
 
-	function getMathNames() {
-		global $wgMathNamesFy;
-		return $wgMathNamesFy;
-	}
-	
 	function getDateFormats() {
 		global $wgDateFormatsFy;
 		return $wgDateFormatsFy;
 	}
 
-	function getUserToggles() {
-		global $wgUserTogglesFy;
-		return $wgUserTogglesFy;
-	}
-
-	function getMonthName( $key )
-	{
-		global $wgMonthNamesFy;
-		return $wgMonthNamesFy[$key-1];
-	}
-	
-	/* by default we just return base form */
-	function getMonthNameGen( $key )
-	{
-		global $wgMonthNamesFy;
-		return $wgMonthNamesFy[$key-1];
-	}
-	
-	function getMonthRegex()
-	{
-		global $wgMonthNamesFy;
-		return implode( "|", $wgMonthNamesFy );
-	}
-
-	function getMonthAbbreviation( $key )
-	{
-		global $wgMonthAbbreviationsFy;
-		return $wgMonthAbbreviationsFy[$key-1];
-	}
-
-	function getWeekdayName( $key )
-	{
-		global $wgWeekdayNamesFy;
-		return $wgWeekdayNamesFy[$key-1];
-	}
-
  # Inherit userAdjust()
  
 	function date( $ts, $adj = false )
@@ -1172,7 +1128,11 @@ class LanguageFy extends LanguageUtf8 {
 	function getMessage( $key )
 	{
 		global $wgAllMessagesFy;
-		return $wgAllMessagesFy[$key];
+		if( isset( $wgAllMessagesFy[$key] ) ) {
+			return $wgAllMessagesFy[$key];
+		} else {
+			return Language::getMessage( $key );
+		}
 	}
 	
 # Inherit iconv()
@@ -1196,4 +1156,3 @@ class LanguageFy extends LanguageUtf8 {
 }
 
 ?>
-
