@@ -29,20 +29,6 @@ require_once( "LanguageUtf8.php" );
 	"Standard", "Nostalgia", "Cologne Blue"
 );
 
-/* private */ $wgUserTogglesSc = array(
-	"hover"		=> "Mostra etichetta sui wiki-links",
-	"underline" => "Sottolinea links",
-	"highlightbroken" => "Evidenzia i links che puntano ad articoli ancora da scrivere",
-	"justify"	=> "Paragrafo: giustificato",
-	"hideminor" => "Nascondi le modifiche minori nella pagina \"Modifiche recenti\"",
-	"numberheadings" => "Auto-numerazione dei titoli di paragrafo",
-	"rememberpassword" => "Ricorda la password (non limitare a una sessione - richiede uso di cookies)",
-	"editwidth" => "Casella di edizione ampliata alla massima larghezza",
-	"editondblclick" => "Doppio click per modificare l'articolo (richiede JavaScript)",
-	"watchdefault" => "Notifica articoli nuovi e modificati",
-	"minordefault" => "Indica ogni modifica come minore (solo come predefinito)"
-	
-);
 
 /* These should be localized... any Italian online bookstores take ISBN searches? */
 /* private */ $wgBookstoreListSc = array(
@@ -55,21 +41,6 @@ require_once( "LanguageUtf8.php" );
 /* Just inherit the (mostly) native-language plus latinized formed */
 /* private */ $wgLanguageNamesSc = $wgLanguageNamesEn;
 
-/* private */ $wgWeekdayNamesSc = array(
-	"Domiga", "Lúnis", "Màrtis", "Mércuris", "Zóbia",
-	"Canàbara", "Sàudu"
-);
-
-/* private */ $wgMonthNamesSc = array(
-	"Ghenàlliu", "Fiàrzu", "Màrtu", "Abríli", "Màzu", "Làmparas",
-	"Luglio", "Agosto", "Settembre", "Ottobre", "Novembre",
-	"Dicembre"
-);
-
-/* private */ $wgMonthAbbreviationsSc = array(
-	"Gen", "Feb", "Mar", "Apr", "Mag", "Giu", "Lug", "Ago",
-	"Set", "Ott", "Nov", "Dic"
-);
 
 # All special pages have to be listed here: a description of ""
 # will make them not show up on the "Special Pages" page, which
@@ -120,13 +91,63 @@ require_once( "LanguageUtf8.php" );
 );
 
 /* private */ $wgAllMessagesSc = array(
+'special_version_prefix' => '',
+'special_version_postfix' => '',
+# User Toggles
+
+"tog-hover"		=> "Mostra etichetta sui wiki-links",
+"tog-underline" => "Sottolinea links",
+"tog-highlightbroken" => "Evidenzia i links che puntano ad articoli ancora da scrivere",
+"tog-justify"	=> "Paragrafo: giustificato",
+"tog-hideminor" => "Nascondi le modifiche minori nella pagina \"Modifiche recenti\"",
+"tog-numberheadings" => "Auto-numerazione dei titoli di paragrafo",
+"tog-rememberpassword" => "Ricorda la password (non limitare a una sessione - richiede uso di cookies)",
+"tog-editwidth" => "Casella di edizione ampliata alla massima larghezza",
+"tog-editondblclick" => "Doppio click per modificare l'articolo (richiede JavaScript)",
+"tog-watchdefault" => "Notifica articoli nuovi e modificati",
+"tog-minordefault" => "Indica ogni modifica come minore (solo come predefinito)",
+
+# Dates
+#
+
+'sunday' => "Domiga",
+'monday' => "Lúnis",
+'tuesday' => "Màrtis",
+'wednesday' => "Mércuris",
+'thursday' => "Zóbia",
+'friday' => "Canàbara",
+'saturday' => "Sàudu",
+'january' => "Ghenàlliu",
+'february' => "Fiàrzu",
+'march' => "Màrtu",
+'april' => "Abríli",
+'may_long' => "Màzu",
+'june' => "Làmparas",
+'july' => "Luglio",
+'august' => "Agosto",
+'september' => "Settembre",
+'october' => "Ottobre",
+'november' => "Novembre",
+'december' => "Dicembre",
+'jan' => "Gen",
+'feb' => "Feb",
+'mar' => "Mar",
+'apr' => "Apr",
+'may' => "Mag",
+'jun' => "Giu",
+'jul' => "Lug",
+'aug' => "Ago",
+'sep' => "Set",
+'oct' => "Ott",
+'nov' => "Nov",
+'dec' => "Dic",
 
 # Bits of text used by many pages:
 #
 "linktrail"		=> "/^([a-z]+)(.*)\$/sD",
 "mainpage"		=> "Wikipedia",
 "about"			=> "A proposito di ",
-"aboutwikipedia" => "A proposito di Wikipedia",
+"aboutsite"      => "A proposito di Wikipedia",
 "aboutpage"		=> "Wikipedia:About",
 "help"			=> "Aiuto",
 "helppage"		=> "Wikipedia:Aiuto",
@@ -149,7 +170,7 @@ require_once( "LanguageUtf8.php" );
 "currentevents" => "Attualità",
 "errorpagetitle" => "Errore",
 "returnto"		=> "Torna a $1.",
-"fromwikipedia"	=> "Da Wikipedia, l'enciclopedia libera.",
+"tagline"      	=> "Da Wikipedia, l'enciclopedia libera.",
 "whatlinkshere"	=> "Pagine che linkano questa",
 "help"			=> "Aiuto",
 "search"		=> "Cerca",
@@ -197,8 +218,7 @@ Vedi $1.",
 #
 "error"			=> "Errore",
 "databaseerror" => "Errore del database ",
-"dberrortext"	=> "Errore di sintassi nella richiesta inoltrata al database. Potrebbe trattarsi di una richiesta non consentita (vedi $5),
-oppure potrebbe esserci un errore software.
+"dberrortext"	=> "Errore di sintassi nella richiesta inoltrata al database.
 L'ultima richiesta inoltrata al database è stata:
 <blockquote><tt>$1</tt></blockquote>
 dalla funzione \"<tt>$2</tt>\".
@@ -232,7 +252,7 @@ Per favore, segnalate l'accaduto ad un administrator, segnalando la URL e l'ora
 "logouttext"	=> "Logout effettuato.
 Ora puoi continuare ad usare Wikipedia come utente anonimo (ma il tuo indirizzo IP resterà riconoscibile), oppure puoi nuovamente richiedere il login con il precedente username, oppure come uno diverso.\n",
 
-"welcomecreation" => "<h2>Benvenuto, $1!</h2><p>Il tuo account è stato creato con successo.<br>Grazie per aver scelto di far crescere Wikipedia con il tuo aiuto.<br>Per rendere Wikipedia più tua, e per usarla più scorrevolmente, non dimenticare di personalizzare le tue preferenze.",
+"welcomecreation" => "<h2>Benvenuto, $1!</h2><p>Il tuo account è stato creato con successo.<br />Grazie per aver scelto di far crescere Wikipedia con il tuo aiuto.<br />Per rendere Wikipedia più tua, e per usarla più scorrevolmente, non dimenticare di personalizzare le tue preferenze.",
 
 "loginpagetitle" => "Login",
 "yourname"		=> "Il tuo  user name",
@@ -240,11 +260,11 @@ Ora puoi continuare ad usare Wikipedia come utente anonimo (ma il tuo indirizzo
 "yourpasswordagain" => "Ripeti la password",
 "newusersonly"	=> " (solo per nuovi Utenti)",
 "remembermypassword" => "Ricorda la mia password per più sessioni (richiede uso dei cookies).",
-"loginproblem"	=> "<b>Si è verificato un errore durante il tuo tentativo di login.</b><br>Riprova, sarai più fortunato!",
-"alreadyloggedin" => "<font color=red><b>Ehi, Utente $1, hai già fatto il login, sei già connesso al nostro server!</b></font><br>\n",
+"loginproblem"	=> "<b>Si è verificato un errore durante il tuo tentativo di login.</b><br />Riprova, sarai più fortunato!",
+"alreadyloggedin" => "<font color=red><b>Ehi, Utente $1, hai già fatto il login, sei già connesso al nostro server!</b></font><br />\n",
 
-"areyounew"		=> "Se sei nuovo in Wikipedia e desideri creare un nuovo user account, immetti uno user name (che sarà il tuo nome per Wikipedia, poi digita una password e ripetila nella casella successiva.<br> 
-Indicare un indirizzo e-mail non è obbligatorio, solo facoltativo (sebbene consigliato).<br>Se per caso perdessi la tua password, potrai richiedere che ti sia rispedita alla casella di posta elettronica che ci fornirai.<br>\n",
+"areyounew"		=> "Se sei nuovo in Wikipedia e desideri creare un nuovo user account, immetti uno user name (che sarà il tuo nome per Wikipedia, poi digita una password e ripetila nella casella successiva.<br /> 
+Indicare un indirizzo e-mail non è obbligatorio, solo facoltativo (sebbene consigliato).<br />Se per caso perdessi la tua password, potrai richiedere che ti sia rispedita alla casella di posta elettronica che ci fornirai.<br />\n",
 
 "login"			=> "Log in",
 "userlogin"		=> "Log in",
@@ -260,9 +280,9 @@ Indicare un indirizzo e-mail non è obbligatorio, solo facoltativo (sebbene cons
 "noname"		=> "Lo user name indicato non è valido, non è possibile creare un account a questo nome.",
 "loginsuccesstitle" => "Login effettuato con successo!",
 "loginsuccess"	=> "Sei stato ammesso alla connessione al server di Wikipedia con il nome utente di \"$1\".",
-"nosuchuser"	=> "Attenzione<br><br>a seguito di verifica, non ci risulta alcun Utente con il nome di  \"$1\".<br><br>
+"nosuchuser"	=> "Attenzione<br /><br />a seguito di verifica, non ci risulta alcun Utente con il nome di  \"$1\".<br /><br />
 Controlla per favore il nome digitato, oppure usa il modulo qui sotto per creare un nuovo user account.",
-"wrongpassword"	=> "La password immessa non è corretta.<br><br>Riprova, per favore.",
+"wrongpassword"	=> "La password immessa non è corretta.<br /><br />Riprova, per favore.",
 "mailmypassword" => "Spediscimi una nuova password in posta elettronica",
 "passwordremindertitle" => "Servizio Password Reminder di Wikipedia",
 "passwordremindertext" => "Qualcuno (probabilmente tu, con indirizzo IP $1)
@@ -282,8 +302,8 @@ Per favore, fai subito un log in non appena la ricevi.",
 "preview"		=> "Anteprima",
 "showpreview"	=> "Visualizza Anteprima",
 "blockedtitle"	=> "Questo User name corrisponde purtroppo ad un Utente che è stato disabilitato alla modifica degli articoli.",
-"blockedtext"	=> "Il tuo User name o il tuo indirizzo IP sono stati bloccati da $1.<br>
-La motivazione del blocco è la seguente:<br>:''$2''<p>Se lo desideri, puoi contattare $1, o uno degli altri 
+"blockedtext"	=> "Il tuo User name o il tuo indirizzo IP sono stati bloccati da $1.<br />
+La motivazione del blocco è la seguente:<br />:''$2''<p>Se lo desideri, puoi contattare $1, o uno degli altri 
 [[Wikipedia:administrators|administrators]] per discutere del blocco.",
 "newarticle"	=> "(Nuovo)",
 "newarticletext" => "Scrivi qui il tuo testo.",
@@ -294,7 +314,7 @@ La motivazione del blocco è la seguente:<br>:''$2''<p>Se lo desideri, puoi cont
 "previewconflict" => "Questa anteprima rappresenta il testo nella casella di edizione di sopra, l'articolo apparirà n questa forma se sceglierai di salvare la pagina.",
 "editing"		=> "Modifica di $1",
 "editconflict"	=> "Conflitto di edizione: $1",
-"explainconflict" => "Qualcun altro ha salvato una sua versione dell'articolo nel tempo in cui tu stavi preparando la tua versione.<br>
+"explainconflict" => "Qualcun altro ha salvato una sua versione dell'articolo nel tempo in cui tu stavi preparando la tua versione.<br />
 La casella di modifica di sopra contiene il testo dell'articolo nella sua forma attuale (cioè il testo attualmente online). Le tue modifiche sono invece contenute nella casella di modifica inferiore. 
 Dovrai inserire, se lo desideri, le tue modifiche nel testo esistente, e perciò scriverle nella casella di sopra. 
 <b>Soltanto</b> il testo nella casella di sopra sarà sakvato se premerai il bottone \"Salva\".\n<p>",
@@ -305,7 +325,7 @@ Se la salvi così, tutti i cambiamenti apportati dopo questa revisione verranno
 "yourdiff"		=> "Differenze",
 "copyrightwarning" => "Nota, per favore, che tutti i contributi a Wikipedia si considerano rilasciati sotto licenza di tipo GNU Free Documentation License
 (vedi $1 per maggiori dettagli).
-Se non vuoi che il tuo testo possa essere modificato e ridistribuito da chiunque senza pietà e senza altri limiti, allora non inviarlo a Wikipedia, ma realizza piuttosto un tuo sito web personale.<br>
+Se non vuoi che il tuo testo possa essere modificato e ridistribuito da chiunque senza pietà e senza altri limiti, allora non inviarlo a Wikipedia, ma realizza piuttosto un tuo sito web personale.<br />
 Con l'invio di questo testo stai garantendo, a tua responsabilità, che il testo è stato scritto da te personalmente ed originalmente, oppure che è stato copiato da una fonte di publico dominio, o una simile fonte, oppure che hai ottenuto espressa autorizzazione ad usare questo testo e che puoi dimostrarlo.
 <strong>NON USARE MATERIALE COPERTO DA DIRITTO DI AUTORE (COPYRIGHT - (c)) IN MANCANZA DI ESPRESSA AUTORIZZAZIONE!!!</strong>",
 
@@ -337,16 +357,14 @@ Controlla per favore la URL che hai usato per accedere a questa pagina.\n",
 # Search results
 #
 "searchresults" => "Risultato della ricerca",
-"searchhelppage" => "Wikipedia:Ricerca",
-"searchingwikipedia" => "Ricerca in Wikipedia",
-"searchresulttext" => "Per maggiori informazioni sulla ricerca interna di Wikipedia, vedi $1.",
+"searchresulttext" => "Per maggiori informazioni sulla ricerca interna di {{SITENAME}}, vedi [[Project:Ricerca|Ricerca in {{SITENAME}}]].",
 "searchquery"	=> "Richiesta \"$1\"",
 "badquery"		=> "Richiesta mal inoltrata ",
 "badquerytext"	=> "La tua richiesta non ha potuto essere processata.
 Questo potrebbe dipendere dall'aver ricercato una parola di meno di tre caratteri.
 Oppure potresti aver scritto male la richiesta, per esempio \"pesce and and azzurro\".
 Per favore, riprova.",
-"matchtotals"	=> "La ricerca per la voce \"$1\" ha trovato<br>$2 riscontri nei titoli degli articoli e<br>$3 riscontri nei testi degli articoli.",
+"matchtotals"	=> "La ricerca per la voce \"$1\" ha trovato<br />$2 riscontri nei titoli degli articoli e<br />$3 riscontri nei testi degli articoli.",
 "titlematches"	=> "Nei titoli degli articoli",
 "notitlematches" => "Voce richiesta non trovata in titoli di articolo",
 "textmatches"	=> "Nel testo degli articoli ",
@@ -358,8 +376,8 @@ Per favore, riprova.",
 "nonefound"		=> "<strong>Nota</strong>: la ricerca di parole troppo comuni, come \"avere\" o \"essere\", che non sono indicizzate, può causare un esito negativo, così come indicare più di un termine da ricercare (solo le pagine che contengano tutti i termini ricercati verrebbero infatti visualizzate fra i risultati).",
 "powersearch" => "Ricerca",
 "powersearchtext" => "
-Cerca fra i campi :<br>
-$1<br>
+Cerca fra i campi :<br />
+$1<br />
 $2 Elenca i redirects &nbsp; cerca per $3 $9",
 
 
@@ -368,7 +386,7 @@ $2 Elenca i redirects &nbsp; cerca per $3 $9",
 "preferences"	=> "Preferenze",
 "prefsnologin" => "Non hai eseguito il login",
 "prefsnologintext"	=> "Devi avere eseguito il <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">login</a>
+  "{{localurle:Special:Userlogin}}\">login</a>
 per poter personalizzare le tue preferenze.",
 "prefslogintext" => "Sei connesso a Wikipedia come \"$1\".
 Il tuo numero identificativo (ID) interno è $2.",
@@ -435,29 +453,33 @@ Gli aspetti legali connessi potrebbero dare fastidio a noi ed a te personalmente
 "reuploaddesc"	=> "Torna al modulo per lo upload.",
 "uploadnologin" => "Devi fare il login per eseguire questa operazione.",
 "uploadnologintext"	=> "Devi eseguire  <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">il login</a>
+  "{{localurle:Special:Userlogin}}\">il login</a>
 per fare lo upload di files.",
 "uploadfile"	=> "Upload file",
 "uploaderror"	=> "Errore di Upload",
-"uploadtext"	=> "<strong>FERMA!</strong> Prima di effettuare un upload su Wikipedia, accertati di avere ben letto e soprattutto compreso <a href=\"" .
-wfLocalUrlE( "Wikipedia:Image_use_policy" ) . "\">le regole di Wikipedia sull'uso delle immagini</a>.
-<p>Per visualizzare o cercare immagini precedentemente caricate su Wikipedia, vai alla <a href=\"" . wfLocalUrlE( "Special:Imagelist" ) .
-"\">lista delle immagini già caricate</a>.
-Uploads e cancellazioni delle immagini sono registrati nello <a href=\"" .
-wfLocalUrlE( "Wikipedia:Upload_log" ) . "\">upload log</a>.
-<p>Usa il modulo sottostante per caricare nuovi files immagine da utilizzare per arricchire ed illustrare i tuoi articoli.
+"uploadtext"	=> "'''FERMA!''' Prima di effettuare un upload su Wikipedia, accertati di avere ben letto e soprattutto compreso
+[[Project:Image_use_policy|le regole di Wikipedia sull'uso delle immagini]].
+
+Per visualizzare o cercare immagini precedentemente caricate su Wikipedia, vai alla [[Special:Imagelist|lista delle immagini già caricate]].
+Uploads e cancellazioni delle immagini sono registrati nello
+[[Project:Upload_log|upload log]].
+
+Usa il modulo sottostante per caricare nuovi files immagine da utilizzare per arricchire ed illustrare i tuoi articoli.
 Sulla maggior parte dei browsers, dovresti vedere un bottone con la scritta \"Browse...\" (oppure \"Sfoglia...\", che aprirà una comune finestra di dialogo.
 Scegliendo uno dei files sul tuo PC, il nome di questo file verrà scritto in automatico nella casella di testo a fianco al bottone.
 Devi anche selezionare la casellina nella quale affermi che con questo upload non stai violando nessun copyright.
 Premi poi il bottone \"Upload\" per completare il caricamento.
 Il caricamento può richiedere qualche minuto se hai una connessione ad Internet lenta, o se l'immagine è eccessivamente pesante (sconsigliato).
-<p>I formati immagine preferibili sono il JPEG per immagini fotografiche, il PNG
+
+I formati immagine preferibili sono il JPEG per immagini fotografiche, il PNG
 per disegni ed altre immagini iconiche o simboliche, il OGG per i suoni.
 Per cortesia, rinomina i tuoi files, prima di caricarli, usando un nome il più possibile descrittivo del contenuto, così da evitare confusioni. 
 Per inserire la nuova immagine in un articolo, usa semplicemente un link nella forma
-<b>[[image:file.jpg]]</b> o <b>[[image:file.png|alt text, testo alternativo]]</b>
-o <b>[[media:file.ogg]]</b> per i suoni.
-<p>Tieni presente che, come per tutte le pagine di Wikipedia, chiunque può modificare o sostituire o cancellare i tuoi files ove ritenga che ciò sia negli interessi della nostra enciclopedia. Tieni anche presente che, in caso di abuso, o di sovraccarico sul sistema, potresti essere bloccato (oltre ad essere perseguito per le connesse responsabilità).",
+'''<nowiki>[[image:file.jpg]]</nowiki>''' o
+'''<nowiki>[[image:file.png|alt text, testo alternativo]]</nowiki>''' o
+'''<nowiki>[[media:file.ogg]]</nowiki>''' per i suoni.
+
+Tieni presente che, come per tutte le pagine di Wikipedia, chiunque può modificare o sostituire o cancellare i tuoi files ove ritenga che ciò sia negli interessi della nostra enciclopedia. Tieni anche presente che, in caso di abuso, o di sovraccarico sul sistema, potresti essere bloccato (oltre ad essere perseguito per le connesse responsabilità).",
 "uploadlog"		=> "upload log",
 "uploadlogpage" => "Upload_log",
 "uploadlogpagetext" => "Qui di seguito la lista degli ultimi files caricati sul server di Wikipedia.
@@ -504,7 +526,7 @@ Segui questo link: ($2) per modificare la pagina di descrizione del file che hai
 "deleteimg"		=> "canc",
 "deleteimgcompletely"		=> "canc",
 "imghistlegend" => "Legenda: (cur) = immagine corrente, (canc) = cancella questa vecchia versione, (ripr) = ripristina questa vecchia versione come versione attuale.
-<br><i>Clicca su una data per vedere tutte le immagini che sono state caricate in quella data </i>.",
+<br /><i>Clicca su una data per vedere tutte le immagini che sono state caricate in quella data </i>.",
 "imagelinks"	=> "Link alle immagini",
 "linkstoimage"	=> "Le pagine seguenti linkano questa immagine:",
 "nolinkstoimage" => "Nessuna pagina linka questa immagine.",
@@ -529,9 +551,9 @@ Questa media rivela che ci sono state una media di  <b>$5</b> modifiche per cias
 "maintenancebacklink"	=> "Torna alla pagina manutenzione",
 "disambiguations"	=> "Disambiguation pages",
 "disambiguationspage"	=> "Wikipedia:Links_to_disambiguating_pages",
-"disambiguationstext"	=> "The following articles link to a <i>disambiguation page</i>. They should link to the appropriate topic instead.<br>A page is treated as dismbiguation if it is linked from $1.<br>Links from other namespaces are <i>not</i> listed here.",
+"disambiguationstext"	=> "The following articles link to a <i>disambiguation page</i>. They should link to the appropriate topic instead.<br />A page is treated as dismbiguation if it is linked from $1.<br />Links from other namespaces are <i>not</i> listed here.",
 "doubleredirects"	=> "Doppi Redirects",
-"doubleredirectstext"	=> "<b>Attenzione:</b> Questa lista può talvolta contenere dei risultati non corretti. Ciò potrebbe magari accadere perchè vi sono del testo aggiuntivo o dei link dopo il tag #REDIRECT.<br>\nOgni riga contiene i link al primo ed al secondo redirect, oltre alla prima riga di testo del secondo redirect che di solito contiene il \"reale\" articolo di destinazione, quello al quale anche il primo redirect dovrebbe puntare.",
+"doubleredirectstext"	=> "<b>Attenzione:</b> Questa lista può talvolta contenere dei risultati non corretti. Ciò potrebbe magari accadere perchè vi sono del testo aggiuntivo o dei link dopo il tag #REDIRECT.<br />\nOgni riga contiene i link al primo ed al secondo redirect, oltre alla prima riga di testo del secondo redirect che di solito contiene il \"reale\" articolo di destinazione, quello al quale anche il primo redirect dovrebbe puntare.",
 "brokenredirects"	=> "Redirects errati",
 "brokenredirectstext"	=> "I seguenti redirects puntano ad articoli non ancora creati.",
 "selflinks"		=> "Pagine con Auto-Links",
@@ -580,9 +602,9 @@ this list should not be construed as an endorsement.",
 #
 "mailnologin"	=> "No send address",
 "mailnologintext" => "Devi fare il  <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">login</a>
+  "{{localurle:Special:Userlogin}}\">login</a>
 ed aver registrato una valida casella e-mail nelle tue <a href=\"" .
-  wfLocalUrl( "Special:Preferences" ) . "\">preferenze</a> per mandare posta elettronica ad altri Utenti.",
+  "{{localurle:Special:Preferences}}\">preferenze</a> per mandare posta elettronica ad altri Utenti.",
 "emailuser"		=> "Manda una E-mail a questo Utente",
 "emailpage"		=> "E-mail user",
 "emailpagetext"	=> "Se questo Utente ha registrato una valida casella e-mail, il modulo qui sotto ti consentirà di scrivergli un solo messaggio.
@@ -605,13 +627,13 @@ oppure ha scelto di non ricevere  posta elettronica dagli altri Utenti.",
 "nowatchlist"	=> "Non hai indicato articoli da tenere d'occhio.",
 "watchnologin"	=> "Manca il login",
 "watchnologintext"	=> "Devi prima fare il <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">login</a>
+  "{{localurle:Special:Userlogin}}\">login</a>
 per modificare la tua lista di osservati speciali.",
 "addedwatch"	=> "Aggiunto agli Osservati Speciali",
 "addedwatchtext" => " La pagina  \"$1\" è stata aggiunta alla tua <a href=\"" .
-  wfLocalUrl( "Special:Watchlist" ) . "\"> lista di osservati speciali </a>.
+  "{{localurle:Special:Watchlist}}\"> lista di osservati speciali </a>.
 Le future modifiche a questa pagina ed alla relativa pagina di discussione saranno elencate qui, e la pagina apparirà in <b>grassetto</b> nella pagina delle <a href=\"" .
-  wfLocalUrl( "Special:Recentchanges" ) . "\">modifiche recenti</a> per essere più facile da tener d'occhio.</p>
+  "{{localurle:Special:Recentchanges}}\">modifiche recenti</a> per essere più facile da tener d'occhio.</p>
 
 <p>Se in seguito vorrai togliere questo articolo dalla tua lista di osservati speciali, clicca \" Smetti di seguire \" nella barra dei menu.",
 "removedwatch"	=> "Rimosso dalla lista degli Osservati Speciali",
@@ -695,7 +717,7 @@ Scrivi un motivo specifico per il quale questo indirizzo IP dovrebbe a tuo avvis
 "noblockreason" => "Devi obbligatoriamente fornire una motivazione per il blocco.",
 "blockipsuccesssub" => "Blocco eseguito",
 "blockipsuccesstext" => " L'indirizzo IP \"$1\" è stato bloccato.
-<br>Vedi [[Special:Ipblocklist|lista IP bloccati]].",
+<br />Vedi [[Special:Ipblocklist|lista IP bloccati]].",
 "unblockip"		=> " Sblocca indirizzo IP",
 "unblockiptext"	=> "Usa il modulo sottostante per restituire il diritto di scrittura ad un indirizzo IP precedentemente bloccato.",
 "ipusubmit"		=> "Sblocca questo indirizzo IP",
@@ -710,7 +732,7 @@ Scrivi un motivo specifico per il quale questo indirizzo IP dovrebbe a tuo avvis
 #
 "lockdb"		=> "Blocca il database",
 "unlockdb"		=> "Sblocca il database",
-"lockdbtext"	=> "Bloccare il database sospenderà la possibilità per tutti gli Utenti di modificare le pagine o di crearne di nuove, di cambiare le loro preferenze, di modificare le loro liste di Osservati Speciali, ed in genere non consentirà a nessuno di eseguire operazioni che richiedano modifiche del database.<br><br>
+"lockdbtext"	=> "Bloccare il database sospenderà la possibilità per tutti gli Utenti di modificare le pagine o di crearne di nuove, di cambiare le loro preferenze, di modificare le loro liste di Osservati Speciali, ed in genere non consentirà a nessuno di eseguire operazioni che richiedano modifiche del database.<br /><br />
 Per cortesia, conferma che questo è effettivamente quanto tu intendi ora effettuare e, soprattutto, che il prima possibile sbloccherai nuovamente il database, ripristinandone la corretta funzionalità, non appena avrai terminato le tue manutenzioni.",
 "unlockdbtext"	=> "Sbloccare il database ripristinerà la possibilità per tutti gli Utenti di modificare le pagine o di crearne di nuove, di cambiare le loro preferenze, di modificare le loro liste di Osservati Speciali, ed in genere di eseguire operazioni che richiedano modifiche del database.
 Per cortesia, conferma che questo è effettivamente quanto tu intendi ora effettuare.",
@@ -722,7 +744,7 @@ Per cortesia, conferma che questo è effettivamente quanto tu intendi ora effett
 "lockdbsuccesssub" => "Blocco del database eseguito",
 "unlockdbsuccesssub" => "Sblocco del database eseguito, rimosso blocco",
 "lockdbsuccesstext" => "Il database di Wikipedia è stato bloccato.
-<br>Ricordati di rimuovere il blocco non appena avrai terminatoi le tue manutenzioni.",
+<br />Ricordati di rimuovere il blocco non appena avrai terminatoi le tue manutenzioni.",
 "unlockdbsuccesstext" => " Il database di Wikipedia è stato sbloccato.",
 
 # SQL query
@@ -757,13 +779,13 @@ In questi casi, se lo ritieni opportuno, dovrai spostare o aggiungere manualment
 "movearticle"	=> "Rinomina articolo",
 "movenologin"	=> "Non hai effettuato il login",
 "movenologintext" => "Devi essere un Utente registrato ed aver effettuato il <a href=\"" .
-  wfLocalUrl( "Special:Userlogin" ) . "\">login</a>
+  "{{localurle:Special:Userlogin}}\">login</a>
 per poter spostare una pagina.",
 "newtitle"		=> "Al nuovo titolo di ",
 "movepagebtn"	=> "Sposta questa pagina",
 "pagemovedsub"	=> "Spostamento effettuato con successo",
 "pagemovedtext" => "Pagina \"[[$1]]\" rinominata in \"[[$2]]\".",
-"articleexists" => "Una pagina con questo nome esiste già, oppure il nome che hai scelto non è valido.<br>
+"articleexists" => "Una pagina con questo nome esiste già, oppure il nome che hai scelto non è valido.<br />
 Scegli, per cortesia, un titolo diverso per l'articolo.",
 "talkexists"	=> "La pagina è stata spostata correttamente, ma la pagina di dicussione non poteva essere spostata perché ne esiste già un'altra con il nuovo titolo. Per favore, modifica manualmente i contenuti delle due pagine discussione, così da mantenerle entrambe per non perdere potenzialmente interessanti riflessioni.",
 "movedto"		=> "spostata a ",
@@ -809,11 +831,6 @@ class LanguageSc extends LanguageUtf8 {
 		return $wgSkinNamesSc;
 	}
 
-	function getUserToggles() {
-		global $wgUserTogglesSc;
-		return $wgUserTogglesSc;
-	}
-
 	function getLanguageNames() {
 		global $wgLanguageNamesSc;
 		return $wgLanguageNamesSc;
@@ -827,24 +844,6 @@ class LanguageSc extends LanguageUtf8 {
 		return $wgLanguageNamesSc[$code];
 	}
 
-	function getMonthName( $key )
-	{
-		global $wgMonthNamesSc;
-		return $wgMonthNamesSc[$key-1];
-	}
-
-	function getMonthAbbreviation( $key )
-	{
-		global $wgMonthAbbreviationsSc;
-		return $wgMonthAbbreviationsSc[$key-1];
-	}
-
-	function getWeekdayName( $key )
-	{
-		global $wgWeekdayNamesSc;
-		return $wgWeekdayNamesSc[$key-1];
-	}
-
 	function date( $ts, $adj = false )
 	{
 		if ( $adj ) { $ts = $this->userAdjust( $ts ); }
