@@ -5,8 +5,8 @@
 -- Note: math table has changed, and this script needs to be run again
 -- to create it. (2003-02-02)
 
-DROP TABLE IF EXISTS math;
-CREATE TABLE math (
+DROP TABLE IF EXISTS /*$wgDBprefix*/math;
+CREATE TABLE /*$wgDBprefix*/math (
     math_inputhash varchar(16) NOT NULL,
     math_outputhash varchar(16) NOT NULL,
     math_html_conservativeness tinyint(1) NOT NULL,
