@@ -2,11 +2,12 @@
 unset( $DP );
 unset( $IP );
 $wgCommandLineMode = false;
+define( "MEDIAWIKI", true );
 
 require_once( "./LocalSettings.php" );
 global $wgArticlePath;
 
-require_once( "WebRequest.php" );
+require_once( "includes/WebRequest.php" );
 $wgRequest = new WebRequest();
 
 $page = $wgRequest->getVal( "wpDropdown" );
